Class: Mudbase::AddParticipantRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AddParticipantRequest
- Defined in:
- lib/mudbase/models/add_participant_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#role ⇒ Object
Returns the value of attribute role.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddParticipantRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddParticipantRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/mudbase/models/add_participant_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AddParticipantRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AddParticipantRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'role') self.role = attributes[:'role'] end end |
Instance Attribute Details
#role ⇒ Object
Returns the value of attribute role.
20 21 22 |
# File 'lib/mudbase/models/add_participant_request.rb', line 20 def role @role end |
#user_id ⇒ Object
Returns the value of attribute user_id.
18 19 20 |
# File 'lib/mudbase/models/add_participant_request.rb', line 18 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/mudbase/models/add_participant_request.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/mudbase/models/add_participant_request.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 |
# File 'lib/mudbase/models/add_participant_request.rb', line 45 def self.attribute_map { :'user_id' => :'userId', :'role' => :'role' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/mudbase/models/add_participant_request.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/mudbase/models/add_participant_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 |
# File 'lib/mudbase/models/add_participant_request.rb', line 63 def self.openapi_types { :'user_id' => :'String', :'role' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 |
# File 'lib/mudbase/models/add_participant_request.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && role == o.role end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/mudbase/models/add_participant_request.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/mudbase/models/add_participant_request.rb', line 162 def hash [user_id, role].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 |
# File 'lib/mudbase/models/add_participant_request.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/mudbase/models/add_participant_request.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 122 123 |
# File 'lib/mudbase/models/add_participant_request.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user_id.nil? role_validator = EnumAttributeValidator.new('String', ["admin", "member"]) return false unless role_validator.valid?(@role) true end |