Class: Mudbase::ApiKey

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/api_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/mudbase/models/api_key.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ApiKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ApiKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'permissions')
    if (value = attributes[:'permissions']).is_a?(Array)
      self.permissions = value
    end
  end

  if attributes.key?(:'rate_limit')
    self.rate_limit = attributes[:'rate_limit']
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/api_key.rb', line 18

def _id
  @_id
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/mudbase/models/api_key.rb', line 36

def created_at
  @created_at
end

#created_byObject

Returns the value of attribute created_by.



34
35
36
# File 'lib/mudbase/models/api_key.rb', line 34

def created_by
  @created_by
end

#expires_atObject

Returns the value of attribute expires_at.



32
33
34
# File 'lib/mudbase/models/api_key.rb', line 32

def expires_at
  @expires_at
end

#is_activeObject

Returns the value of attribute is_active.



30
31
32
# File 'lib/mudbase/models/api_key.rb', line 30

def is_active
  @is_active
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/mudbase/models/api_key.rb', line 20

def name
  @name
end

#permissionsObject

Returns the value of attribute permissions.



24
25
26
# File 'lib/mudbase/models/api_key.rb', line 24

def permissions
  @permissions
end

#projectObject

Returns the value of attribute project.



22
23
24
# File 'lib/mudbase/models/api_key.rb', line 22

def project
  @project
end

#rate_limitObject

Returns the value of attribute rate_limit.



26
27
28
# File 'lib/mudbase/models/api_key.rb', line 26

def rate_limit
  @rate_limit
end

#usageObject

Returns the value of attribute usage.



28
29
30
# File 'lib/mudbase/models/api_key.rb', line 28

def usage
  @usage
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/mudbase/models/api_key.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/mudbase/models/api_key.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/mudbase/models/api_key.rb', line 39

def self.attribute_map
  {
    :'_id' => :'_id',
    :'name' => :'name',
    :'project' => :'project',
    :'permissions' => :'permissions',
    :'rate_limit' => :'rateLimit',
    :'usage' => :'usage',
    :'is_active' => :'isActive',
    :'expires_at' => :'expiresAt',
    :'created_by' => :'createdBy',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/mudbase/models/api_key.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/mudbase/models/api_key.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/mudbase/models/api_key.rb', line 65

def self.openapi_types
  {
    :'_id' => :'String',
    :'name' => :'String',
    :'project' => :'ProjectSummary',
    :'permissions' => :'Array<ApiKeyPermission>',
    :'rate_limit' => :'RateLimit',
    :'usage' => :'ApiKeyUsage',
    :'is_active' => :'Boolean',
    :'expires_at' => :'Time',
    :'created_by' => :'UserSummary',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/mudbase/models/api_key.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      name == o.name &&
      project == o.project &&
      permissions == o.permissions &&
      rate_limit == o.rate_limit &&
      usage == o.usage &&
      is_active == o.is_active &&
      expires_at == o.expires_at &&
      created_by == o.created_by &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/mudbase/models/api_key.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/mudbase/models/api_key.rb', line 185

def hash
  [_id, name, project, permissions, rate_limit, usage, is_active, expires_at, created_by, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/mudbase/models/api_key.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/mudbase/models/api_key.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/mudbase/models/api_key.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end