Class: Mudbase::ApiKycWebhookConfigPutRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::ApiKycWebhookConfigPutRequest
- Defined in:
- lib/mudbase/models/api_kyc_webhook_config_put_request.rb
Instance Attribute Summary collapse
-
#generate_secret ⇒ Object
When true, the server generates a new secret and returns it once.
-
#webhook_secret ⇒ Object
Explicit signing secret (min 16 chars).
-
#webhook_url ⇒ Object
Destination URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKycWebhookConfigPutRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKycWebhookConfigPutRequest
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ApiKycWebhookConfigPutRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ApiKycWebhookConfigPutRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] end if attributes.key?(:'webhook_secret') self.webhook_secret = attributes[:'webhook_secret'] end if attributes.key?(:'generate_secret') self.generate_secret = attributes[:'generate_secret'] end end |
Instance Attribute Details
#generate_secret ⇒ Object
When true, the server generates a new secret and returns it once.
25 26 27 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 25 def generate_secret @generate_secret end |
#webhook_secret ⇒ Object
Explicit signing secret (min 16 chars). Send null or empty string to clear.
22 23 24 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 22 def webhook_secret @webhook_secret end |
#webhook_url ⇒ Object
Destination URL. Send null or empty string to clear.
19 20 21 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 19 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 28 def self.attribute_map { :'webhook_url' => :'webhookUrl', :'webhook_secret' => :'webhookSecret', :'generate_secret' => :'generateSecret' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 147 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 60 61 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 56 def self.openapi_nullable Set.new([ :'webhook_url', :'webhook_secret', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 47 def self.openapi_types { :'webhook_url' => :'String', :'webhook_secret' => :'String', :'generate_secret' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && webhook_url == o.webhook_url && webhook_secret == o.webhook_secret && generate_secret == o.generate_secret end |
#eql?(o) ⇒ Boolean
134 135 136 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 134 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
140 141 142 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 140 def hash [webhook_url, webhook_secret, generate_secret].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
94 95 96 97 98 99 100 101 102 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 94 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@webhook_secret.nil? && @webhook_secret.to_s.length < 16 invalid_properties.push('invalid value for "webhook_secret", the character length must be greater than or equal to 16.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 |
# File 'lib/mudbase/models/api_kyc_webhook_config_put_request.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@webhook_secret.nil? && @webhook_secret.to_s.length < 16 true end |