Class: Mudbase::AuthGetOAuthProviders200ResponseProvidersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthGetOAuthProviders200ResponseProvidersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AuthGetOAuthProviders200ResponseProvidersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AuthGetOAuthProviders200ResponseProvidersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'strategy')
    self.strategy = attributes[:'strategy']
  end

  if attributes.key?(:'default_scope')
    if (value = attributes[:'default_scope']).is_a?(Array)
      self.default_scope = value
    end
  end

  if attributes.key?(:'callback_url')
    self.callback_url = attributes[:'callback_url']
  end

  if attributes.key?(:'required_fields')
    if (value = attributes[:'required_fields']).is_a?(Array)
      self.required_fields = value
    end
  end
end

Instance Attribute Details

#callback_urlObject

Returns the value of attribute callback_url.



26
27
28
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 26

def callback_url
  @callback_url
end

#default_scopeObject

Returns the value of attribute default_scope.



24
25
26
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 24

def default_scope
  @default_scope
end

#display_nameObject

Returns the value of attribute display_name.



20
21
22
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 20

def display_name
  @display_name
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 18

def name
  @name
end

#required_fieldsObject

Returns the value of attribute required_fields.



28
29
30
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 28

def required_fields
  @required_fields
end

#strategyObject

Returns the value of attribute strategy.



22
23
24
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 22

def strategy
  @strategy
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'display_name' => :'displayName',
    :'strategy' => :'strategy',
    :'default_scope' => :'defaultScope',
    :'callback_url' => :'callbackUrl',
    :'required_fields' => :'requiredFields'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 53

def self.openapi_types
  {
    :'name' => :'String',
    :'display_name' => :'String',
    :'strategy' => :'String',
    :'default_scope' => :'Array<String>',
    :'callback_url' => :'String',
    :'required_fields' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      display_name == o.display_name &&
      strategy == o.strategy &&
      default_scope == o.default_scope &&
      callback_url == o.callback_url &&
      required_fields == o.required_fields
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 151

def hash
  [name, display_name, strategy, default_scope, callback_url, required_fields].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
# File 'lib/mudbase/models/auth_get_o_auth_providers200_response_providers_inner.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end