Class: Mudbase::AuthResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AuthResponse
- Defined in:
- lib/mudbase/models/auth_response.rb
Overview
Response after successful login or registration (token, refreshToken, user).
Instance Attribute Summary collapse
-
#expires_in ⇒ Object
Access token TTL in seconds (e.g. 1800 for 30 minutes).
-
#message ⇒ Object
Returns the value of attribute message.
-
#refresh_token ⇒ Object
JWT refresh token (use with POST /api/auth/refresh to get new token pair).
-
#token ⇒ Object
JWT access token (use in Authorization Bearer header).
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthResponse
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/mudbase/models/auth_response.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AuthResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AuthResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'refresh_token') self.refresh_token = attributes[:'refresh_token'] end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] end if attributes.key?(:'user') self.user = attributes[:'user'] end end |
Instance Attribute Details
#expires_in ⇒ Object
Access token TTL in seconds (e.g. 1800 for 30 minutes)
28 29 30 |
# File 'lib/mudbase/models/auth_response.rb', line 28 def expires_in @expires_in end |
#message ⇒ Object
Returns the value of attribute message.
19 20 21 |
# File 'lib/mudbase/models/auth_response.rb', line 19 def end |
#refresh_token ⇒ Object
JWT refresh token (use with POST /api/auth/refresh to get new token pair)
25 26 27 |
# File 'lib/mudbase/models/auth_response.rb', line 25 def refresh_token @refresh_token end |
#token ⇒ Object
JWT access token (use in Authorization Bearer header)
22 23 24 |
# File 'lib/mudbase/models/auth_response.rb', line 22 def token @token end |
#user ⇒ Object
Returns the value of attribute user.
30 31 32 |
# File 'lib/mudbase/models/auth_response.rb', line 30 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/mudbase/models/auth_response.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/mudbase/models/auth_response.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mudbase/models/auth_response.rb', line 33 def self.attribute_map { :'message' => :'message', :'token' => :'token', :'refresh_token' => :'refreshToken', :'expires_in' => :'expiresIn', :'user' => :'user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/mudbase/models/auth_response.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/mudbase/models/auth_response.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/mudbase/models/auth_response.rb', line 54 def self.openapi_types { :'message' => :'String', :'token' => :'String', :'refresh_token' => :'String', :'expires_in' => :'Integer', :'user' => :'User' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 |
# File 'lib/mudbase/models/auth_response.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && token == o.token && refresh_token == o.refresh_token && expires_in == o.expires_in && user == o.user end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/mudbase/models/auth_response.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/mudbase/models/auth_response.rb', line 142 def hash [, token, refresh_token, expires_in, user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 |
# File 'lib/mudbase/models/auth_response.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/mudbase/models/auth_response.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/mudbase/models/auth_response.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |