Class: Mudbase::BackupsApi
- Inherits:
-
Object
- Object
- Mudbase::BackupsApi
- Defined in:
- lib/mudbase/api/backups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_backup(project_id, opts = {}) ⇒ CreateBackup201Response
Create project backup Create a backup of project data, optionally including files and wallets.
-
#create_backup_with_http_info(project_id, opts = {}) ⇒ Array<(CreateBackup201Response, Integer, Hash)>
Create project backup Create a backup of project data, optionally including files and wallets.
-
#delete_backup(project_id, backup_id, opts = {}) ⇒ DeleteBackup200Response
Delete backup Delete a project backup.
-
#delete_backup_with_http_info(project_id, backup_id, opts = {}) ⇒ Array<(DeleteBackup200Response, Integer, Hash)>
Delete backup Delete a project backup.
-
#initialize(api_client = ApiClient.default) ⇒ BackupsApi
constructor
A new instance of BackupsApi.
-
#list_backups(project_id, opts = {}) ⇒ ListBackups200Response
List project backups Get all backups for a project.
-
#list_backups_with_http_info(project_id, opts = {}) ⇒ Array<(ListBackups200Response, Integer, Hash)>
List project backups Get all backups for a project.
-
#restore_backup(project_id, backup_id, restore_backup_request, opts = {}) ⇒ RestoreBackup200Response
Restore from backup Restore project data from a backup.
-
#restore_backup_with_http_info(project_id, backup_id, restore_backup_request, opts = {}) ⇒ Array<(RestoreBackup200Response, Integer, Hash)>
Restore from backup Restore project data from a backup.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BackupsApi
Returns a new instance of BackupsApi.
19 20 21 |
# File 'lib/mudbase/api/backups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/backups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_backup(project_id, opts = {}) ⇒ CreateBackup201Response
Create project backup Create a backup of project data, optionally including files and wallets. Supports both JWT Bearer token and API key authentication.
28 29 30 31 |
# File 'lib/mudbase/api/backups_api.rb', line 28 def create_backup(project_id, opts = {}) data, _status_code, _headers = create_backup_with_http_info(project_id, opts) data end |
#create_backup_with_http_info(project_id, opts = {}) ⇒ Array<(CreateBackup201Response, Integer, Hash)>
Create project backup Create a backup of project data, optionally including files and wallets. Supports both JWT Bearer token and API key authentication.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mudbase/api/backups_api.rb', line 39 def create_backup_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.create_backup ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BackupsApi.create_backup" end # resource path local_var_path = '/api/projects/{projectId}/backups'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_backup_request']) # return_type return_type = opts[:debug_return_type] || 'CreateBackup201Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"BackupsApi.create_backup", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#create_backup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_backup(project_id, backup_id, opts = {}) ⇒ DeleteBackup200Response
Delete backup Delete a project backup. Supports both JWT Bearer token and API key authentication.
98 99 100 101 |
# File 'lib/mudbase/api/backups_api.rb', line 98 def delete_backup(project_id, backup_id, opts = {}) data, _status_code, _headers = delete_backup_with_http_info(project_id, backup_id, opts) data end |
#delete_backup_with_http_info(project_id, backup_id, opts = {}) ⇒ Array<(DeleteBackup200Response, Integer, Hash)>
Delete backup Delete a project backup. Supports both JWT Bearer token and API key authentication.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/mudbase/api/backups_api.rb', line 109 def delete_backup_with_http_info(project_id, backup_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.delete_backup ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BackupsApi.delete_backup" end # verify the required parameter 'backup_id' is set if @api_client.config.client_side_validation && backup_id.nil? fail ArgumentError, "Missing the required parameter 'backup_id' when calling BackupsApi.delete_backup" end # resource path local_var_path = '/api/projects/{projectId}/backups/{backupId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'backupId' + '}', CGI.escape(backup_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteBackup200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"BackupsApi.delete_backup", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#delete_backup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_backups(project_id, opts = {}) ⇒ ListBackups200Response
List project backups Get all backups for a project. Supports both JWT Bearer token and API key authentication.
166 167 168 169 |
# File 'lib/mudbase/api/backups_api.rb', line 166 def list_backups(project_id, opts = {}) data, _status_code, _headers = list_backups_with_http_info(project_id, opts) data end |
#list_backups_with_http_info(project_id, opts = {}) ⇒ Array<(ListBackups200Response, Integer, Hash)>
List project backups Get all backups for a project. Supports both JWT Bearer token and API key authentication.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/mudbase/api/backups_api.rb', line 176 def list_backups_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.list_backups ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BackupsApi.list_backups" end # resource path local_var_path = '/api/projects/{projectId}/backups'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListBackups200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"BackupsApi.list_backups", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#list_backups\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#restore_backup(project_id, backup_id, restore_backup_request, opts = {}) ⇒ RestoreBackup200Response
Restore from backup Restore project data from a backup. Supports replace or merge modes. Supports both JWT Bearer token and API key authentication.
231 232 233 234 |
# File 'lib/mudbase/api/backups_api.rb', line 231 def restore_backup(project_id, backup_id, restore_backup_request, opts = {}) data, _status_code, _headers = restore_backup_with_http_info(project_id, backup_id, restore_backup_request, opts) data end |
#restore_backup_with_http_info(project_id, backup_id, restore_backup_request, opts = {}) ⇒ Array<(RestoreBackup200Response, Integer, Hash)>
Restore from backup Restore project data from a backup. Supports replace or merge modes. Supports both JWT Bearer token and API key authentication.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/mudbase/api/backups_api.rb', line 243 def restore_backup_with_http_info(project_id, backup_id, restore_backup_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.restore_backup ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BackupsApi.restore_backup" end # verify the required parameter 'backup_id' is set if @api_client.config.client_side_validation && backup_id.nil? fail ArgumentError, "Missing the required parameter 'backup_id' when calling BackupsApi.restore_backup" end # verify the required parameter 'restore_backup_request' is set if @api_client.config.client_side_validation && restore_backup_request.nil? fail ArgumentError, "Missing the required parameter 'restore_backup_request' when calling BackupsApi.restore_backup" end # resource path local_var_path = '/api/projects/{projectId}/backups/{backupId}/restore'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'backupId' + '}', CGI.escape(backup_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(restore_backup_request) # return_type return_type = opts[:debug_return_type] || 'RestoreBackup200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"BackupsApi.restore_backup", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#restore_backup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |