Class: Mudbase::BillingHandleFlutterwaveWebhookRequestData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::BillingHandleFlutterwaveWebhookRequestData
- Defined in:
- lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#flw_ref ⇒ Object
Returns the value of attribute flw_ref.
-
#id ⇒ Object
Returns the value of attribute id.
-
#meta ⇒ Object
orgId, projectId, planId, billingCycle; or isPaymentProcessing true for fiat payment-processing.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tx_ref ⇒ Object
Returns the value of attribute tx_ref.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BillingHandleFlutterwaveWebhookRequestData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BillingHandleFlutterwaveWebhookRequestData
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::BillingHandleFlutterwaveWebhookRequestData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::BillingHandleFlutterwaveWebhookRequestData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'tx_ref') self.tx_ref = attributes[:'tx_ref'] end if attributes.key?(:'flw_ref') self.flw_ref = attributes[:'flw_ref'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'customer') self.customer = attributes[:'customer'] end if attributes.key?(:'meta') self. = attributes[:'meta'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
24 25 26 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 24 def amount @amount end |
#currency ⇒ Object
Returns the value of attribute currency.
26 27 28 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 26 def currency @currency end |
#customer ⇒ Object
Returns the value of attribute customer.
30 31 32 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 30 def customer @customer end |
#flw_ref ⇒ Object
Returns the value of attribute flw_ref.
22 23 24 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 22 def flw_ref @flw_ref end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 18 def id @id end |
#meta ⇒ Object
orgId, projectId, planId, billingCycle; or isPaymentProcessing true for fiat payment-processing
33 34 35 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 33 def end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 28 def status @status end |
#tx_ref ⇒ Object
Returns the value of attribute tx_ref.
20 21 22 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 20 def tx_ref @tx_ref end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 36 def self.attribute_map { :'id' => :'id', :'tx_ref' => :'tx_ref', :'flw_ref' => :'flw_ref', :'amount' => :'amount', :'currency' => :'currency', :'status' => :'status', :'customer' => :'customer', :'meta' => :'meta' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 60 def self.openapi_types { :'id' => :'Float', :'tx_ref' => :'String', :'flw_ref' => :'String', :'amount' => :'Float', :'currency' => :'String', :'status' => :'String', :'customer' => :'BillingHandleFlutterwaveWebhookRequestDataCustomer', :'meta' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && tx_ref == o.tx_ref && flw_ref == o.flw_ref && amount == o.amount && currency == o.currency && status == o.status && customer == o.customer && == o. end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 166 def hash [id, tx_ref, flw_ref, amount, currency, status, customer, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 |
# File 'lib/mudbase/models/billing_handle_flutterwave_webhook_request_data.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |