Class: Mudbase::BillingVerifyPayment200ResponseDataSubscription

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BillingVerifyPayment200ResponseDataSubscription

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::BillingVerifyPayment200ResponseDataSubscription` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::BillingVerifyPayment200ResponseDataSubscription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  end

  if attributes.key?(:'current_period_end')
    self.current_period_end = attributes[:'current_period_end']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 18

def _id
  @_id
end

#current_period_endObject

Returns the value of attribute current_period_end.



24
25
26
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 24

def current_period_end
  @current_period_end
end

#planObject

Returns the value of attribute plan.



22
23
24
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 22

def plan
  @plan
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 49

def self.attribute_map
  {
    :'_id' => :'_id',
    :'status' => :'status',
    :'plan' => :'plan',
    :'current_period_end' => :'currentPeriodEnd'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 69

def self.openapi_types
  {
    :'_id' => :'String',
    :'status' => :'String',
    :'plan' => :'String',
    :'current_period_end' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      status == o.status &&
      plan == o.plan &&
      current_period_end == o.current_period_end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 163

def hash
  [_id, status, plan, current_period_end].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
131
132
# File 'lib/mudbase/models/billing_verify_payment200_response_data_subscription.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["active", "cancelled", "past_due"])
  return false unless status_validator.valid?(@status)
  true
end