Class: Mudbase::ChatEditMessage200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/chat_edit_message200_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ChatEditMessage200ResponseData

Initializes the object



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ChatEditMessage200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ChatEditMessage200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'edited_at')
    self.edited_at = attributes[:'edited_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 18

def _id
  @_id
end

#contentObject

Returns the value of attribute content.



20
21
22
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 20

def content
  @content
end

#edited_atObject

Returns the value of attribute edited_at.



22
23
24
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 22

def edited_at
  @edited_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 25

def self.attribute_map
  {
    :'_id' => :'_id',
    :'content' => :'content',
    :'edited_at' => :'editedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 127

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 53

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 44

def self.openapi_types
  {
    :'_id' => :'String',
    :'content' => :'String',
    :'edited_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



104
105
106
107
108
109
110
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 104

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      content == o.content &&
      edited_at == o.edited_at
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


114
115
116
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 114

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



120
121
122
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 120

def hash
  [_id, content, edited_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



89
90
91
92
93
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 89

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 149

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



97
98
99
100
# File 'lib/mudbase/models/chat_edit_message200_response_data.rb', line 97

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end