Class: Mudbase::Collection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::Collection
- Defined in:
- lib/mudbase/models/collection.rb
Overview
Collection schema (id, name, slug, project, fields, permissions, settings).
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#fields ⇒ Object
Returns the value of attribute fields.
-
#name ⇒ Object
Returns the value of attribute name.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#project ⇒ Object
Returns the value of attribute project.
-
#settings ⇒ Object
Returns the value of attribute settings.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Collection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Collection
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/mudbase/models/collection.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Collection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Collection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'project') self.project = attributes[:'project'] end if attributes.key?(:'fields') if (value = attributes[:'fields']).is_a?(Array) self.fields = value end end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'settings') self.settings = attributes[:'settings'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/collection.rb', line 19 def _id @_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
33 34 35 |
# File 'lib/mudbase/models/collection.rb', line 33 def created_at @created_at end |
#fields ⇒ Object
Returns the value of attribute fields.
27 28 29 |
# File 'lib/mudbase/models/collection.rb', line 27 def fields @fields end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/mudbase/models/collection.rb', line 21 def name @name end |
#permissions ⇒ Object
Returns the value of attribute permissions.
29 30 31 |
# File 'lib/mudbase/models/collection.rb', line 29 def @permissions end |
#project ⇒ Object
Returns the value of attribute project.
25 26 27 |
# File 'lib/mudbase/models/collection.rb', line 25 def project @project end |
#settings ⇒ Object
Returns the value of attribute settings.
31 32 33 |
# File 'lib/mudbase/models/collection.rb', line 31 def settings @settings end |
#slug ⇒ Object
Returns the value of attribute slug.
23 24 25 |
# File 'lib/mudbase/models/collection.rb', line 23 def slug @slug end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
35 36 37 |
# File 'lib/mudbase/models/collection.rb', line 35 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/mudbase/models/collection.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/mudbase/models/collection.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/mudbase/models/collection.rb', line 38 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'slug' => :'slug', :'project' => :'project', :'fields' => :'fields', :'permissions' => :'permissions', :'settings' => :'settings', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/mudbase/models/collection.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/mudbase/models/collection.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mudbase/models/collection.rb', line 63 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'slug' => :'String', :'project' => :'String', :'fields' => :'Array<Field>', :'permissions' => :'Array<Permission>', :'settings' => :'Object', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/mudbase/models/collection.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && slug == o.slug && project == o.project && fields == o.fields && == o. && settings == o.settings && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/mudbase/models/collection.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/mudbase/models/collection.rb', line 179 def hash [_id, name, slug, project, fields, , settings, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 |
# File 'lib/mudbase/models/collection.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/mudbase/models/collection.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 |
# File 'lib/mudbase/models/collection.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |