Class: Mudbase::ComplianceApi
- Inherits:
-
Object
- Object
- Mudbase::ComplianceApi
- Defined in:
- lib/mudbase/api/compliance_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#api_gdpr_erase_post(api_gdpr_erase_post_request, opts = {}) ⇒ ApplyRoleFeaturePreset200Response
Erase my personal data (GDPR Art. 17) Anonymizes the subject's PII, revokes sessions/tokens, and anonymizes (never hard-deletes) financial/legal-retention records.
-
#api_gdpr_erase_post_with_http_info(api_gdpr_erase_post_request, opts = {}) ⇒ Array<(ApplyRoleFeaturePreset200Response, Integer, Hash)>
Erase my personal data (GDPR Art. 17) Anonymizes the subject's PII, revokes sessions/tokens, and anonymizes (never hard-deletes) financial/legal-retention records.
-
#api_gdpr_export_get(opts = {}) ⇒ Object
Export my personal data (GDPR Art. 15) Returns the authenticated subject's personal data as a downloadable JSON attachment.
-
#api_gdpr_export_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Export my personal data (GDPR Art. 15) Returns the authenticated subject's personal data as a downloadable JSON attachment.
-
#generate_access_review(generate_access_review_request, opts = {}) ⇒ GenerateAccessReview200Response
Generate access review report (SOC 2) Generate access review report for compliance audits (SOC 2, ISO 27001, etc.).
-
#generate_access_review_with_http_info(generate_access_review_request, opts = {}) ⇒ Array<(GenerateAccessReview200Response, Integer, Hash)>
Generate access review report (SOC 2) Generate access review report for compliance audits (SOC 2, ISO 27001, etc.).
-
#generate_data_processing_record(generate_data_processing_record_request, opts = {}) ⇒ GenerateDataProcessingRecord200Response
Generate data processing record (GDPR Article 30) Generate GDPR Article 30 compliant data processing record.
-
#generate_data_processing_record_with_http_info(generate_data_processing_record_request, opts = {}) ⇒ Array<(GenerateDataProcessingRecord200Response, Integer, Hash)>
Generate data processing record (GDPR Article 30) Generate GDPR Article 30 compliant data processing record.
-
#get_compliance_summary(opts = {}) ⇒ GetComplianceSummary200Response
Get compliance summary Get compliance dashboard data (GDPR, SOC 2, security status).
-
#get_compliance_summary_with_http_info(opts = {}) ⇒ Array<(GetComplianceSummary200Response, Integer, Hash)>
Get compliance summary Get compliance dashboard data (GDPR, SOC 2, security status).
-
#initialize(api_client = ApiClient.default) ⇒ ComplianceApi
constructor
A new instance of ComplianceApi.
-
#log_security_event(log_security_event_request, opts = {}) ⇒ LogSecurityEvent200Response
Log security event Log a security event for compliance and audit purposes.
-
#log_security_event_with_http_info(log_security_event_request, opts = {}) ⇒ Array<(LogSecurityEvent200Response, Integer, Hash)>
Log security event Log a security event for compliance and audit purposes.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ComplianceApi
Returns a new instance of ComplianceApi.
19 20 21 |
# File 'lib/mudbase/api/compliance_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/compliance_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#api_gdpr_erase_post(api_gdpr_erase_post_request, opts = {}) ⇒ ApplyRoleFeaturePreset200Response
Erase my personal data (GDPR Art. 17)
Anonymizes the subject's PII, revokes sessions/tokens, and anonymizes (never hard-deletes) financial/legal-retention records. Idempotent and self-scoped. Requires re-proving your current password (skipped only for OAuth-only accounts with no password set) and, if 2FA is enabled, a fresh TOTP code - the same step-up re-authentication already required by the less-destructive PATCH /api/users/password and POST /api/users/2fa/disable.
27 28 29 30 |
# File 'lib/mudbase/api/compliance_api.rb', line 27 def api_gdpr_erase_post(api_gdpr_erase_post_request, opts = {}) data, _status_code, _headers = api_gdpr_erase_post_with_http_info(api_gdpr_erase_post_request, opts) data end |
#api_gdpr_erase_post_with_http_info(api_gdpr_erase_post_request, opts = {}) ⇒ Array<(ApplyRoleFeaturePreset200Response, Integer, Hash)>
Erase my personal data (GDPR Art. 17) Anonymizes the subject's PII, revokes sessions/tokens, and anonymizes (never hard-deletes) financial/legal-retention records. Idempotent and self-scoped. Requires re-proving your current password (skipped only for OAuth-only accounts with no password set) and, if 2FA is enabled, a fresh TOTP code - the same step-up re-authentication already required by the less-destructive `PATCH /api/users/password` and `POST /api/users/2fa/disable`.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/mudbase/api/compliance_api.rb', line 37 def api_gdpr_erase_post_with_http_info(api_gdpr_erase_post_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.api_gdpr_erase_post ...' end # verify the required parameter 'api_gdpr_erase_post_request' is set if @api_client.config.client_side_validation && api_gdpr_erase_post_request.nil? fail ArgumentError, "Missing the required parameter 'api_gdpr_erase_post_request' when calling ComplianceApi.api_gdpr_erase_post" end # resource path local_var_path = '/api/gdpr/erase' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(api_gdpr_erase_post_request) # return_type return_type = opts[:debug_return_type] || 'ApplyRoleFeaturePreset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth'] = opts.merge( :operation => :"ComplianceApi.api_gdpr_erase_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#api_gdpr_erase_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#api_gdpr_export_get(opts = {}) ⇒ Object
Export my personal data (GDPR Art. 15) Returns the authenticated subject's personal data as a downloadable JSON attachment. Self-scoped — a caller can only export their own data.
94 95 96 97 |
# File 'lib/mudbase/api/compliance_api.rb', line 94 def api_gdpr_export_get(opts = {}) data, _status_code, _headers = api_gdpr_export_get_with_http_info(opts) data end |
#api_gdpr_export_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Export my personal data (GDPR Art. 15) Returns the authenticated subject's personal data as a downloadable JSON attachment. Self-scoped — a caller can only export their own data.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/mudbase/api/compliance_api.rb', line 103 def api_gdpr_export_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.api_gdpr_export_get ...' end # resource path local_var_path = '/api/gdpr/export' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth'] = opts.merge( :operation => :"ComplianceApi.api_gdpr_export_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#api_gdpr_export_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#generate_access_review(generate_access_review_request, opts = {}) ⇒ GenerateAccessReview200Response
Generate access review report (SOC 2) Generate access review report for compliance audits (SOC 2, ISO 27001, etc.). Requires JWT Bearer token authentication. Both OrgBearerAuth and ProjectBearerAuth are supported (they use the same JWT token format). These are organization-level operations.
152 153 154 155 |
# File 'lib/mudbase/api/compliance_api.rb', line 152 def generate_access_review(generate_access_review_request, opts = {}) data, _status_code, _headers = generate_access_review_with_http_info(generate_access_review_request, opts) data end |
#generate_access_review_with_http_info(generate_access_review_request, opts = {}) ⇒ Array<(GenerateAccessReview200Response, Integer, Hash)>
Generate access review report (SOC 2) Generate access review report for compliance audits (SOC 2, ISO 27001, etc.). Requires JWT Bearer token authentication. Both OrgBearerAuth and ProjectBearerAuth are supported (they use the same JWT token format). These are organization-level operations.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/mudbase/api/compliance_api.rb', line 162 def generate_access_review_with_http_info(generate_access_review_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.generate_access_review ...' end # verify the required parameter 'generate_access_review_request' is set if @api_client.config.client_side_validation && generate_access_review_request.nil? fail ArgumentError, "Missing the required parameter 'generate_access_review_request' when calling ComplianceApi.generate_access_review" end # resource path local_var_path = '/api/compliance/access-review' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(generate_access_review_request) # return_type return_type = opts[:debug_return_type] || 'GenerateAccessReview200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"ComplianceApi.generate_access_review", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#generate_access_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#generate_data_processing_record(generate_data_processing_record_request, opts = {}) ⇒ GenerateDataProcessingRecord200Response
Generate data processing record (GDPR Article 30) Generate GDPR Article 30 compliant data processing record
220 221 222 223 |
# File 'lib/mudbase/api/compliance_api.rb', line 220 def generate_data_processing_record(generate_data_processing_record_request, opts = {}) data, _status_code, _headers = generate_data_processing_record_with_http_info(generate_data_processing_record_request, opts) data end |
#generate_data_processing_record_with_http_info(generate_data_processing_record_request, opts = {}) ⇒ Array<(GenerateDataProcessingRecord200Response, Integer, Hash)>
Generate data processing record (GDPR Article 30) Generate GDPR Article 30 compliant data processing record
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/mudbase/api/compliance_api.rb', line 230 def generate_data_processing_record_with_http_info(generate_data_processing_record_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.generate_data_processing_record ...' end # verify the required parameter 'generate_data_processing_record_request' is set if @api_client.config.client_side_validation && generate_data_processing_record_request.nil? fail ArgumentError, "Missing the required parameter 'generate_data_processing_record_request' when calling ComplianceApi.generate_data_processing_record" end # resource path local_var_path = '/api/compliance/data-processing-record' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(generate_data_processing_record_request) # return_type return_type = opts[:debug_return_type] || 'GenerateDataProcessingRecord200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"ComplianceApi.generate_data_processing_record", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#generate_data_processing_record\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_compliance_summary(opts = {}) ⇒ GetComplianceSummary200Response
Get compliance summary Get compliance dashboard data (GDPR, SOC 2, security status). Requires JWT Bearer token authentication. Both OrgBearerAuth and ProjectBearerAuth are supported (they use the same JWT token format). These are organization-level operations.
287 288 289 290 |
# File 'lib/mudbase/api/compliance_api.rb', line 287 def get_compliance_summary(opts = {}) data, _status_code, _headers = get_compliance_summary_with_http_info(opts) data end |
#get_compliance_summary_with_http_info(opts = {}) ⇒ Array<(GetComplianceSummary200Response, Integer, Hash)>
Get compliance summary Get compliance dashboard data (GDPR, SOC 2, security status). Requires JWT Bearer token authentication. Both OrgBearerAuth and ProjectBearerAuth are supported (they use the same JWT token format). These are organization-level operations.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/mudbase/api/compliance_api.rb', line 296 def get_compliance_summary_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.get_compliance_summary ...' end # resource path local_var_path = '/api/compliance/summary' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetComplianceSummary200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"ComplianceApi.get_compliance_summary", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#get_compliance_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#log_security_event(log_security_event_request, opts = {}) ⇒ LogSecurityEvent200Response
Log security event Log a security event for compliance and audit purposes
345 346 347 348 |
# File 'lib/mudbase/api/compliance_api.rb', line 345 def log_security_event(log_security_event_request, opts = {}) data, _status_code, _headers = log_security_event_with_http_info(log_security_event_request, opts) data end |
#log_security_event_with_http_info(log_security_event_request, opts = {}) ⇒ Array<(LogSecurityEvent200Response, Integer, Hash)>
Log security event Log a security event for compliance and audit purposes
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/mudbase/api/compliance_api.rb', line 355 def log_security_event_with_http_info(log_security_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceApi.log_security_event ...' end # verify the required parameter 'log_security_event_request' is set if @api_client.config.client_side_validation && log_security_event_request.nil? fail ArgumentError, "Missing the required parameter 'log_security_event_request' when calling ComplianceApi.log_security_event" end # resource path local_var_path = '/api/compliance/security-event' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(log_security_event_request) # return_type return_type = opts[:debug_return_type] || 'LogSecurityEvent200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"ComplianceApi.log_security_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceApi#log_security_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |