Class: Mudbase::ConfigureWebhookRequest

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/configure_webhook_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConfigureWebhookRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/mudbase/models/configure_webhook_request.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ConfigureWebhookRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ConfigureWebhookRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'webhook_secret')
    self.webhook_secret = attributes[:'webhook_secret']
  end

  if attributes.key?(:'webhook_events')
    if (value = attributes[:'webhook_events']).is_a?(Array)
      self.webhook_events = value
    end
  end

  if attributes.key?(:'webhook_version')
    self.webhook_version = attributes[:'webhook_version']
  end

  if attributes.key?(:'transformations')
    if (value = attributes[:'transformations']).is_a?(Array)
      self.transformations = value
    end
  end
end

Instance Attribute Details

#transformationsObject

Transformation rules to apply to payloads before delivery



31
32
33
# File 'lib/mudbase/models/configure_webhook_request.rb', line 31

def transformations
  @transformations
end

#webhook_eventsObject

Event types to send (e.g. collection.insert, collection.update)



25
26
27
# File 'lib/mudbase/models/configure_webhook_request.rb', line 25

def webhook_events
  @webhook_events
end

#webhook_secretObject

Optional secret for signing payloads (e.g. X-Webhook-Signature)



22
23
24
# File 'lib/mudbase/models/configure_webhook_request.rb', line 22

def webhook_secret
  @webhook_secret
end

#webhook_urlObject

URL to receive webhook payloads; set to null or omit to disable



19
20
21
# File 'lib/mudbase/models/configure_webhook_request.rb', line 19

def webhook_url
  @webhook_url
end

#webhook_versionObject

Version string for payload format



28
29
30
# File 'lib/mudbase/models/configure_webhook_request.rb', line 28

def webhook_version
  @webhook_version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/mudbase/models/configure_webhook_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/mudbase/models/configure_webhook_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/mudbase/models/configure_webhook_request.rb', line 34

def self.attribute_map
  {
    :'webhook_url' => :'webhookUrl',
    :'webhook_secret' => :'webhookSecret',
    :'webhook_events' => :'webhookEvents',
    :'webhook_version' => :'webhookVersion',
    :'transformations' => :'transformations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/mudbase/models/configure_webhook_request.rb', line 155

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
# File 'lib/mudbase/models/configure_webhook_request.rb', line 66

def self.openapi_nullable
  Set.new([
    :'webhook_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/mudbase/models/configure_webhook_request.rb', line 55

def self.openapi_types
  {
    :'webhook_url' => :'String',
    :'webhook_secret' => :'String',
    :'webhook_events' => :'Array<String>',
    :'webhook_version' => :'String',
    :'transformations' => :'Array<GetWebhookConfig200ResponseDataTransformationsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



130
131
132
133
134
135
136
137
138
# File 'lib/mudbase/models/configure_webhook_request.rb', line 130

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      webhook_url == o.webhook_url &&
      webhook_secret == o.webhook_secret &&
      webhook_events == o.webhook_events &&
      webhook_version == o.webhook_version &&
      transformations == o.transformations
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/mudbase/models/configure_webhook_request.rb', line 142

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



148
149
150
# File 'lib/mudbase/models/configure_webhook_request.rb', line 148

def hash
  [webhook_url, webhook_secret, webhook_events, webhook_version, transformations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
# File 'lib/mudbase/models/configure_webhook_request.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/mudbase/models/configure_webhook_request.rb', line 177

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
# File 'lib/mudbase/models/configure_webhook_request.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end