Class: Mudbase::ConfirmLocalPasswordResetWithOtpRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConfirmLocalPasswordResetWithOtpRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ConfirmLocalPasswordResetWithOtpRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ConfirmLocalPasswordResetWithOtpRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  else
    self.project_id = nil
  end

  if attributes.key?(:'otp')
    self.otp = attributes[:'otp']
  else
    self.otp = nil
  end

  if attributes.key?(:'new_password')
    self.new_password = attributes[:'new_password']
  else
    self.new_password = nil
  end
end

Instance Attribute Details

#emailObject

Returns the value of attribute email.



18
19
20
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 18

def email
  @email
end

#new_passwordObject

Returns the value of attribute new_password.



24
25
26
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 24

def new_password
  @new_password
end

#otpObject

Returns the value of attribute otp.



22
23
24
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 22

def otp
  @otp
end

#project_idObject

Returns the value of attribute project_id.



20
21
22
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 20

def project_id
  @project_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 27

def self.attribute_map
  {
    :'email' => :'email',
    :'project_id' => :'projectId',
    :'otp' => :'otp',
    :'new_password' => :'newPassword'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 47

def self.openapi_types
  {
    :'email' => :'String',
    :'project_id' => :'String',
    :'otp' => :'String',
    :'new_password' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      project_id == o.project_id &&
      otp == o.otp &&
      new_password == o.new_password
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 235

def hash
  [email, project_id, otp, new_password].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if @otp.nil?
    invalid_properties.push('invalid value for "otp", otp cannot be nil.')
  end

  if @otp.to_s.length > 6
    invalid_properties.push('invalid value for "otp", the character length must be smaller than or equal to 6.')
  end

  if @otp.to_s.length < 6
    invalid_properties.push('invalid value for "otp", the character length must be greater than or equal to 6.')
  end

  pattern = Regexp.new(/^[0-9]+$/)
  if @otp !~ pattern
    invalid_properties.push("invalid value for \"otp\", must conform to the pattern #{pattern}.")
  end

  if @new_password.nil?
    invalid_properties.push('invalid value for "new_password", new_password cannot be nil.')
  end

  if @new_password.to_s.length < 8
    invalid_properties.push('invalid value for "new_password", the character length must be greater than or equal to 8.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/mudbase/models/confirm_local_password_reset_with_otp_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @project_id.nil?
  return false if @otp.nil?
  return false if @otp.to_s.length > 6
  return false if @otp.to_s.length < 6
  return false if @otp !~ Regexp.new(/^[0-9]+$/)
  return false if @new_password.nil?
  return false if @new_password.to_s.length < 8
  true
end