Class: Mudbase::ConfirmUploadResponse

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/confirm_upload_response.rb

Overview

Result of upload confirmation (fileId, status, scan).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConfirmUploadResponse

Initializes the object



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/mudbase/models/confirm_upload_response.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ConfirmUploadResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ConfirmUploadResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'file_id')
    self.file_id = attributes[:'file_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'scan')
    self.scan = attributes[:'scan']
  end
end

Instance Attribute Details

#file_idObject

Returns the value of attribute file_id.



19
20
21
# File 'lib/mudbase/models/confirm_upload_response.rb', line 19

def file_id
  @file_id
end

#scanObject

Returns the value of attribute scan.



23
24
25
# File 'lib/mudbase/models/confirm_upload_response.rb', line 23

def scan
  @scan
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/mudbase/models/confirm_upload_response.rb', line 21

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/mudbase/models/confirm_upload_response.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/mudbase/models/confirm_upload_response.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/mudbase/models/confirm_upload_response.rb', line 48

def self.attribute_map
  {
    :'file_id' => :'fileId',
    :'status' => :'status',
    :'scan' => :'scan'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/mudbase/models/confirm_upload_response.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/mudbase/models/confirm_upload_response.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/mudbase/models/confirm_upload_response.rb', line 67

def self.openapi_types
  {
    :'file_id' => :'String',
    :'status' => :'String',
    :'scan' => :'ConfirmUploadResponseScan'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



139
140
141
142
143
144
145
# File 'lib/mudbase/models/confirm_upload_response.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      file_id == o.file_id &&
      status == o.status &&
      scan == o.scan
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


149
150
151
# File 'lib/mudbase/models/confirm_upload_response.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



155
156
157
# File 'lib/mudbase/models/confirm_upload_response.rb', line 155

def hash
  [file_id, status, scan].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



112
113
114
115
116
# File 'lib/mudbase/models/confirm_upload_response.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/mudbase/models/confirm_upload_response.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



120
121
122
123
124
125
# File 'lib/mudbase/models/confirm_upload_response.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["ok", "quarantined", "error"])
  return false unless status_validator.valid?(@status)
  true
end