Class: Mudbase::CreateCheckoutSession200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::CreateCheckoutSession200ResponseData
- Defined in:
- lib/mudbase/models/create_checkout_session200_response_data.rb
Instance Attribute Summary collapse
-
#access_code ⇒ Object
Gateway access code.
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#authorization_url ⇒ Object
Hosted payment URL.
-
#checkout_url ⇒ Object
Hosted payment URL (same as authorizationUrl).
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#reference ⇒ Object
Transaction reference (mudbase_...) for verify-payment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseData
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::CreateCheckoutSession200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::CreateCheckoutSession200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'checkout_url') self.checkout_url = attributes[:'checkout_url'] end if attributes.key?(:'authorization_url') self. = attributes[:'authorization_url'] end if attributes.key?(:'access_code') self.access_code = attributes[:'access_code'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end end |
Instance Attribute Details
#access_code ⇒ Object
Gateway access code
25 26 27 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 25 def access_code @access_code end |
#amount ⇒ Object
Returns the value of attribute amount.
30 31 32 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 30 def amount @amount end |
#authorization_url ⇒ Object
Hosted payment URL
22 23 24 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 22 def @authorization_url end |
#checkout_url ⇒ Object
Hosted payment URL (same as authorizationUrl)
19 20 21 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 19 def checkout_url @checkout_url end |
#currency ⇒ Object
Returns the value of attribute currency.
32 33 34 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 32 def currency @currency end |
#reference ⇒ Object
Transaction reference (mudbase_...) for verify-payment
28 29 30 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 28 def reference @reference end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 35 def self.attribute_map { :'checkout_url' => :'checkoutUrl', :'authorization_url' => :'authorizationUrl', :'access_code' => :'accessCode', :'reference' => :'reference', :'amount' => :'amount', :'currency' => :'currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 57 def self.openapi_types { :'checkout_url' => :'String', :'authorization_url' => :'String', :'access_code' => :'String', :'reference' => :'String', :'amount' => :'Float', :'currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && checkout_url == o.checkout_url && == o. && access_code == o.access_code && reference == o.reference && amount == o.amount && currency == o.currency end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 151 def hash [checkout_url, , access_code, reference, amount, currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |