Class: Mudbase::CreateWalletRequest

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/create_wallet_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateWalletRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/mudbase/models/create_wallet_request.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::CreateWalletRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::CreateWalletRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end
end

Instance Attribute Details

#currencyObject

Currency. USDT requires network (ETH, BSC, TRX, SOL, POLYGON). All platform chains supported for testing non-custodial flows.



19
20
21
# File 'lib/mudbase/models/create_wallet_request.rb', line 19

def currency
  @currency
end

#labelObject

Returns the value of attribute label.



30
31
32
# File 'lib/mudbase/models/create_wallet_request.rb', line 30

def label
  @label
end

#networkObject

Required for USDT; one of ETH, BSC, TRX, SOL, POLYGON



25
26
27
# File 'lib/mudbase/models/create_wallet_request.rb', line 25

def network
  @network
end

#private_keyObject

Optional custom private key



28
29
30
# File 'lib/mudbase/models/create_wallet_request.rb', line 28

def private_key
  @private_key
end

#project_idObject

Optional project ID



22
23
24
# File 'lib/mudbase/models/create_wallet_request.rb', line 22

def project_id
  @project_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/mudbase/models/create_wallet_request.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/mudbase/models/create_wallet_request.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/mudbase/models/create_wallet_request.rb', line 55

def self.attribute_map
  {
    :'currency' => :'currency',
    :'project_id' => :'projectId',
    :'network' => :'network',
    :'private_key' => :'privateKey',
    :'label' => :'label'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/mudbase/models/create_wallet_request.rb', line 190

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/mudbase/models/create_wallet_request.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/mudbase/models/create_wallet_request.rb', line 76

def self.openapi_types
  {
    :'currency' => :'String',
    :'project_id' => :'String',
    :'network' => :'String',
    :'private_key' => :'String',
    :'label' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
# File 'lib/mudbase/models/create_wallet_request.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      currency == o.currency &&
      project_id == o.project_id &&
      network == o.network &&
      private_key == o.private_key &&
      label == o.label
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/mudbase/models/create_wallet_request.rb', line 177

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



183
184
185
# File 'lib/mudbase/models/create_wallet_request.rb', line 183

def hash
  [currency, project_id, network, private_key, label].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
# File 'lib/mudbase/models/create_wallet_request.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/mudbase/models/create_wallet_request.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
# File 'lib/mudbase/models/create_wallet_request.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @currency.nil?
  currency_validator = EnumAttributeValidator.new('String', ["BTC", "LTC", "DOGE", "ETH", "CELO", "SOL", "TRX", "TON", "MATIC", "BNB", "AVAX", "ADA", "USDT"])
  return false unless currency_validator.valid?(@currency)
  true
end