Class: Mudbase::DashboardOverviewData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::DashboardOverviewData
- Defined in:
- lib/mudbase/models/dashboard_overview_data.rb
Instance Attribute Summary collapse
-
#active_users ⇒ Object
Returns the value of attribute active_users.
-
#generated_at ⇒ Object
Returns the value of attribute generated_at.
-
#latency ⇒ Object
Returns the value of attribute latency.
-
#project ⇒ Object
Returns the value of attribute project.
-
#recent_activity ⇒ Object
Returns the value of attribute recent_activity.
-
#request_volume14d ⇒ Object
Returns the value of attribute request_volume14d.
-
#requests ⇒ Object
Returns the value of attribute requests.
-
#uptime ⇒ Object
Returns the value of attribute uptime.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DashboardOverviewData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DashboardOverviewData
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::DashboardOverviewData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::DashboardOverviewData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project') self.project = attributes[:'project'] end if attributes.key?(:'requests') self.requests = attributes[:'requests'] end if attributes.key?(:'active_users') self.active_users = attributes[:'active_users'] end if attributes.key?(:'latency') self.latency = attributes[:'latency'] end if attributes.key?(:'uptime') self.uptime = attributes[:'uptime'] end if attributes.key?(:'request_volume14d') if (value = attributes[:'request_volume14d']).is_a?(Array) self.request_volume14d = value end end if attributes.key?(:'recent_activity') if (value = attributes[:'recent_activity']).is_a?(Array) self.recent_activity = value end end if attributes.key?(:'generated_at') self.generated_at = attributes[:'generated_at'] end end |
Instance Attribute Details
#active_users ⇒ Object
Returns the value of attribute active_users.
22 23 24 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 22 def active_users @active_users end |
#generated_at ⇒ Object
Returns the value of attribute generated_at.
32 33 34 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 32 def generated_at @generated_at end |
#latency ⇒ Object
Returns the value of attribute latency.
24 25 26 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 24 def latency @latency end |
#project ⇒ Object
Returns the value of attribute project.
18 19 20 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 18 def project @project end |
#recent_activity ⇒ Object
Returns the value of attribute recent_activity.
30 31 32 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 30 def recent_activity @recent_activity end |
#request_volume14d ⇒ Object
Returns the value of attribute request_volume14d.
28 29 30 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 28 def request_volume14d @request_volume14d end |
#requests ⇒ Object
Returns the value of attribute requests.
20 21 22 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 20 def requests @requests end |
#uptime ⇒ Object
Returns the value of attribute uptime.
26 27 28 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 26 def uptime @uptime end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 35 def self.attribute_map { :'project' => :'project', :'requests' => :'requests', :'active_users' => :'activeUsers', :'latency' => :'latency', :'uptime' => :'uptime', :'request_volume14d' => :'requestVolume14d', :'recent_activity' => :'recentActivity', :'generated_at' => :'generatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 176 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 59 def self.openapi_types { :'project' => :'DashboardOverviewDataProject', :'requests' => :'DashboardOverviewDataRequests', :'active_users' => :'DashboardOverviewDataActiveUsers', :'latency' => :'DashboardOverviewDataLatency', :'uptime' => :'DashboardOverviewDataUptime', :'request_volume14d' => :'Array<DashboardOverviewDataRequestVolume14dInner>', :'recent_activity' => :'Array<DashboardActivityItem>', :'generated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && project == o.project && requests == o.requests && active_users == o.active_users && latency == o.latency && uptime == o.uptime && request_volume14d == o.request_volume14d && recent_activity == o.recent_activity && generated_at == o.generated_at end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 169 def hash [project, requests, active_users, latency, uptime, request_volume14d, recent_activity, generated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 |
# File 'lib/mudbase/models/dashboard_overview_data.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |