Class: Mudbase::DashboardOverviewDataLatency

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/dashboard_overview_data_latency.rb

Overview

Per-project weighted mean latency from UsageStat for routes in openapi-docs.yaml (customer/project API only).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DashboardOverviewDataLatency

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::DashboardOverviewDataLatency` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::DashboardOverviewDataLatency`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'avg_ms_today')
    self.avg_ms_today = attributes[:'avg_ms_today']
  end

  if attributes.key?(:'avg_ms7d')
    self.avg_ms7d = attributes[:'avg_ms7d']
  end

  if attributes.key?(:'latency_samples_today')
    self.latency_samples_today = attributes[:'latency_samples_today']
  end

  if attributes.key?(:'latency_needs_traffic')
    self.latency_needs_traffic = attributes[:'latency_needs_traffic']
  end

  if attributes.key?(:'interpretation')
    self.interpretation = attributes[:'interpretation']
  end

  if attributes.key?(:'instance_rollup')
    self.instance_rollup = attributes[:'instance_rollup']
  end

  if attributes.key?(:'top_routes_by_impact_hint')
    if (value = attributes[:'top_routes_by_impact_hint']).is_a?(Array)
      self.top_routes_by_impact_hint = value
    end
  end
end

Instance Attribute Details

#avg_ms7dObject

Returns the value of attribute avg_ms7d.



23
24
25
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 23

def avg_ms7d
  @avg_ms7d
end

#avg_ms_todayObject

Returns the value of attribute avg_ms_today.



21
22
23
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 21

def avg_ms_today
  @avg_ms_today
end

#instance_rollupObject

Returns the value of attribute instance_rollup.



33
34
35
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 33

def instance_rollup
  @instance_rollup
end

#interpretationObject

Why mean can differ from typical latency; points to latency-insights



31
32
33
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 31

def interpretation
  @interpretation
end

#latency_needs_trafficObject

Returns the value of attribute latency_needs_traffic.



28
29
30
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 28

def latency_needs_traffic
  @latency_needs_traffic
end

#latency_samples_todayObject

Count of openapi-docs–scoped latency samples for this project (UTC today)



26
27
28
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 26

def latency_samples_today
  @latency_samples_today
end

#scopeObject

Returns the value of attribute scope.



19
20
21
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 19

def scope
  @scope
end

#top_routes_by_impact_hintObject

Top route templates by impact score on this instance (debugging hint)



36
37
38
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 36

def top_routes_by_impact_hint
  @top_routes_by_impact_hint
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 61

def self.attribute_map
  {
    :'scope' => :'scope',
    :'avg_ms_today' => :'avgMsToday',
    :'avg_ms7d' => :'avgMs7d',
    :'latency_samples_today' => :'latencySamplesToday',
    :'latency_needs_traffic' => :'latencyNeedsTraffic',
    :'interpretation' => :'interpretation',
    :'instance_rollup' => :'instanceRollup',
    :'top_routes_by_impact_hint' => :'topRoutesByImpactHint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
104
105
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 99

def self.openapi_nullable
  Set.new([
    :'avg_ms_today',
    :'avg_ms7d',
    :'instance_rollup',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 85

def self.openapi_types
  {
    :'scope' => :'String',
    :'avg_ms_today' => :'Integer',
    :'avg_ms7d' => :'Integer',
    :'latency_samples_today' => :'Integer',
    :'latency_needs_traffic' => :'Boolean',
    :'interpretation' => :'String',
    :'instance_rollup' => :'DashboardOverviewDataLatencyInstanceRollup',
    :'top_routes_by_impact_hint' => :'Array<DashboardOverviewDataLatencyTopRoutesByImpactHintInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scope == o.scope &&
      avg_ms_today == o.avg_ms_today &&
      avg_ms7d == o.avg_ms7d &&
      latency_samples_today == o.latency_samples_today &&
      latency_needs_traffic == o.latency_needs_traffic &&
      interpretation == o.interpretation &&
      instance_rollup == o.instance_rollup &&
      top_routes_by_impact_hint == o.top_routes_by_impact_hint
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 208

def hash
  [scope, avg_ms_today, avg_ms7d, latency_samples_today, latency_needs_traffic, interpretation, instance_rollup, top_routes_by_impact_hint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
173
# File 'lib/mudbase/models/dashboard_overview_data_latency.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  scope_validator = EnumAttributeValidator.new('String', ["project_openapi_doc"])
  return false unless scope_validator.valid?(@scope)
  true
end