Class: Mudbase::DataApi
- Inherits:
-
Object
- Object
- Mudbase::DataApi
- Defined in:
- lib/mudbase/api/data_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_data(project_id, collection_id, body, opts = {}) ⇒ DataResponse
Create data in collection.
-
#create_data_with_http_info(project_id, collection_id, body, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Create data in collection.
-
#delete_data(project_id, collection_id, document_id, opts = {}) ⇒ MessageResponse
Delete document Delete a document from a collection.
-
#delete_data_with_http_info(project_id, collection_id, document_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Delete document Delete a document from a collection.
-
#get_data(project_id, collection_id, document_id, opts = {}) ⇒ DataResponse
Get single document.
-
#get_data_with_http_info(project_id, collection_id, document_id, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Get single document.
-
#initialize(api_client = ApiClient.default) ⇒ DataApi
constructor
A new instance of DataApi.
-
#list_data(project_id, collection_id, opts = {}) ⇒ DataListResponse
List data in collection List all documents in a collection.
-
#list_data_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(DataListResponse, Integer, Hash)>
List data in collection List all documents in a collection.
-
#update_data(project_id, collection_id, document_id, body, opts = {}) ⇒ DataResponse
Update document Update a document in a collection.
-
#update_data_with_http_info(project_id, collection_id, document_id, body, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Update document Update a document in a collection.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/data_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_data(project_id, collection_id, body, opts = {}) ⇒ DataResponse
Create data in collection
28 29 30 31 |
# File 'lib/mudbase/api/data_api.rb', line 28 def create_data(project_id, collection_id, body, opts = {}) data, _status_code, _headers = create_data_with_http_info(project_id, collection_id, body, opts) data end |
#create_data_with_http_info(project_id, collection_id, body, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Create data in collection
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/mudbase/api/data_api.rb', line 39 def create_data_with_http_info(project_id, collection_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DataApi.create_data ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling DataApi.create_data" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling DataApi.create_data" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DataApi.create_data" end # resource path local_var_path = '/api/data/projects/{projectId}/collections/{collectionId}/data'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DataResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"DataApi.create_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DataApi#create_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_data(project_id, collection_id, document_id, opts = {}) ⇒ MessageResponse
Delete document Delete a document from a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
107 108 109 110 |
# File 'lib/mudbase/api/data_api.rb', line 107 def delete_data(project_id, collection_id, document_id, opts = {}) data, _status_code, _headers = delete_data_with_http_info(project_id, collection_id, document_id, opts) data end |
#delete_data_with_http_info(project_id, collection_id, document_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Delete document Delete a document from a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/mudbase/api/data_api.rb', line 119 def delete_data_with_http_info(project_id, collection_id, document_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DataApi.delete_data ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling DataApi.delete_data" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling DataApi.delete_data" end # verify the required parameter 'document_id' is set if @api_client.config.client_side_validation && document_id.nil? fail ArgumentError, "Missing the required parameter 'document_id' when calling DataApi.delete_data" end # resource path local_var_path = '/api/data/projects/{projectId}/collections/{collectionId}/data/{documentId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)).sub('{' + 'documentId' + '}', CGI.escape(document_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MessageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"DataApi.delete_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DataApi#delete_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_data(project_id, collection_id, document_id, opts = {}) ⇒ DataResponse
Get single document
181 182 183 184 |
# File 'lib/mudbase/api/data_api.rb', line 181 def get_data(project_id, collection_id, document_id, opts = {}) data, _status_code, _headers = get_data_with_http_info(project_id, collection_id, document_id, opts) data end |
#get_data_with_http_info(project_id, collection_id, document_id, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Get single document
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/mudbase/api/data_api.rb', line 192 def get_data_with_http_info(project_id, collection_id, document_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DataApi.get_data ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling DataApi.get_data" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling DataApi.get_data" end # verify the required parameter 'document_id' is set if @api_client.config.client_side_validation && document_id.nil? fail ArgumentError, "Missing the required parameter 'document_id' when calling DataApi.get_data" end # resource path local_var_path = '/api/data/projects/{projectId}/collections/{collectionId}/data/{documentId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)).sub('{' + 'documentId' + '}', CGI.escape(document_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DataResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"DataApi.get_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DataApi#get_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_data(project_id, collection_id, opts = {}) ⇒ DataListResponse
List data in collection List all documents in a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
258 259 260 261 |
# File 'lib/mudbase/api/data_api.rb', line 258 def list_data(project_id, collection_id, opts = {}) data, _status_code, _headers = list_data_with_http_info(project_id, collection_id, opts) data end |
#list_data_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(DataListResponse, Integer, Hash)>
List data in collection List all documents in a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/mudbase/api/data_api.rb', line 273 def list_data_with_http_info(project_id, collection_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DataApi.list_data ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling DataApi.list_data" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling DataApi.list_data" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DataApi.list_data, must be smaller than or equal to 100.' end # resource path local_var_path = '/api/data/projects/{projectId}/collections/{collectionId}/data'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DataListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"DataApi.list_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DataApi#list_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_data(project_id, collection_id, document_id, body, opts = {}) ⇒ DataResponse
Update document Update a document in a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
341 342 343 344 |
# File 'lib/mudbase/api/data_api.rb', line 341 def update_data(project_id, collection_id, document_id, body, opts = {}) data, _status_code, _headers = update_data_with_http_info(project_id, collection_id, document_id, body, opts) data end |
#update_data_with_http_info(project_id, collection_id, document_id, body, opts = {}) ⇒ Array<(DataResponse, Integer, Hash)>
Update document Update a document in a collection. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/mudbase/api/data_api.rb', line 354 def update_data_with_http_info(project_id, collection_id, document_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DataApi.update_data ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling DataApi.update_data" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling DataApi.update_data" end # verify the required parameter 'document_id' is set if @api_client.config.client_side_validation && document_id.nil? fail ArgumentError, "Missing the required parameter 'document_id' when calling DataApi.update_data" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DataApi.update_data" end # resource path local_var_path = '/api/data/projects/{projectId}/collections/{collectionId}/data/{documentId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)).sub('{' + 'documentId' + '}', CGI.escape(document_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DataResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"DataApi.update_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DataApi#update_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |