Class: Mudbase::EmailRequest

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/email_request.rb

Overview

Email payload (to, subject, html, text, templateId, templateData).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EmailRequest

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/mudbase/models/email_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::EmailRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::EmailRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'template_data')
    self.template_data = attributes[:'template_data']
  end
end

Instance Attribute Details

#htmlObject

Returns the value of attribute html.



23
24
25
# File 'lib/mudbase/models/email_request.rb', line 23

def html
  @html
end

#subjectObject

Returns the value of attribute subject.



21
22
23
# File 'lib/mudbase/models/email_request.rb', line 21

def subject
  @subject
end

#template_dataObject

Returns the value of attribute template_data.



29
30
31
# File 'lib/mudbase/models/email_request.rb', line 29

def template_data
  @template_data
end

#template_idObject

Returns the value of attribute template_id.



27
28
29
# File 'lib/mudbase/models/email_request.rb', line 27

def template_id
  @template_id
end

#textObject

Returns the value of attribute text.



25
26
27
# File 'lib/mudbase/models/email_request.rb', line 25

def text
  @text
end

#toObject

Returns the value of attribute to.



19
20
21
# File 'lib/mudbase/models/email_request.rb', line 19

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/mudbase/models/email_request.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/mudbase/models/email_request.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/mudbase/models/email_request.rb', line 32

def self.attribute_map
  {
    :'to' => :'to',
    :'subject' => :'subject',
    :'html' => :'html',
    :'text' => :'text',
    :'template_id' => :'templateId',
    :'template_data' => :'templateData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/mudbase/models/email_request.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/mudbase/models/email_request.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/mudbase/models/email_request.rb', line 54

def self.openapi_types
  {
    :'to' => :'EmailRequestTo',
    :'subject' => :'String',
    :'html' => :'String',
    :'text' => :'String',
    :'template_id' => :'String',
    :'template_data' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



163
164
165
166
167
168
169
170
171
172
# File 'lib/mudbase/models/email_request.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      to == o.to &&
      subject == o.subject &&
      html == o.html &&
      text == o.text &&
      template_id == o.template_id &&
      template_data == o.template_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


176
177
178
# File 'lib/mudbase/models/email_request.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



182
183
184
# File 'lib/mudbase/models/email_request.rb', line 182

def hash
  [to, subject, html, text, template_id, template_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/mudbase/models/email_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/mudbase/models/email_request.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



134
135
136
137
138
139
# File 'lib/mudbase/models/email_request.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @to.nil?
  return false if @subject.nil?
  true
end