Class: Mudbase::FunctionExecutionStatusResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/function_execution_status_response_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FunctionExecutionStatusResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::FunctionExecutionStatusResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::FunctionExecutionStatusResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'execution_id')
    self.execution_id = attributes[:'execution_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'duration_ms')
    self.duration_ms = attributes[:'duration_ms']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'error_class')
    self.error_class = attributes[:'error_class']
  end

  if attributes.key?(:'logs')
    self.logs = attributes[:'logs']
  end

  if attributes.key?(:'machine')
    self.machine = attributes[:'machine']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



39
40
41
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 39

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 35

def created_at
  @created_at
end

#duration_msObject

Duration in milliseconds (null until completed)



23
24
25
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 23

def duration_ms
  @duration_ms
end

#errorObject

Returns the value of attribute error.



27
28
29
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 27

def error
  @error
end

#error_classObject

Returns the value of attribute error_class.



29
30
31
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 29

def error_class
  @error_class
end

#execution_idObject

Returns the value of attribute execution_id.



18
19
20
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 18

def execution_id
  @execution_id
end

#logsObject

Returns the value of attribute logs.



31
32
33
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 31

def logs
  @logs
end

#machineObject

Returns the value of attribute machine.



33
34
35
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 33

def machine
  @machine
end

#resultObject

Returns the value of attribute result.



25
26
27
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 25

def result
  @result
end

#started_atObject

Returns the value of attribute started_at.



37
38
39
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 37

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 64

def self.attribute_map
  {
    :'execution_id' => :'executionId',
    :'status' => :'status',
    :'duration_ms' => :'durationMs',
    :'result' => :'result',
    :'error' => :'error',
    :'error_class' => :'errorClass',
    :'logs' => :'logs',
    :'machine' => :'machine',
    :'created_at' => :'createdAt',
    :'started_at' => :'startedAt',
    :'completed_at' => :'completedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
113
114
115
116
117
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 108

def self.openapi_nullable
  Set.new([
    :'result',
    :'error',
    :'error_class',
    :'machine',
    :'started_at',
    :'completed_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 91

def self.openapi_types
  {
    :'execution_id' => :'String',
    :'status' => :'String',
    :'duration_ms' => :'Integer',
    :'result' => :'Object',
    :'error' => :'String',
    :'error_class' => :'String',
    :'logs' => :'FunctionExecutionStatusResponseDataLogs',
    :'machine' => :'Object',
    :'created_at' => :'Time',
    :'started_at' => :'Time',
    :'completed_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      execution_id == o.execution_id &&
      status == o.status &&
      duration_ms == o.duration_ms &&
      result == o.result &&
      error == o.error &&
      error_class == o.error_class &&
      logs == o.logs &&
      machine == o.machine &&
      created_at == o.created_at &&
      started_at == o.started_at &&
      completed_at == o.completed_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 233

def hash
  [execution_id, status, duration_ms, result, error, error_class, logs, machine, created_at, started_at, completed_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
# File 'lib/mudbase/models/function_execution_status_response_data.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["queued", "provisioning", "running", "success", "failed", "timeout"])
  return false unless status_validator.valid?(@status)
  true
end