Class: Mudbase::FunctionStats

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/function_stats.rb

Overview

Function execution stats (total, successful, failed, avgExecutionTime, lastExecution).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FunctionStats

Initializes the object



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/mudbase/models/function_stats.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::FunctionStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::FunctionStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total_executions')
    self.total_executions = attributes[:'total_executions']
  end

  if attributes.key?(:'successful_executions')
    self.successful_executions = attributes[:'successful_executions']
  end

  if attributes.key?(:'failed_executions')
    self.failed_executions = attributes[:'failed_executions']
  end

  if attributes.key?(:'avg_execution_time')
    self.avg_execution_time = attributes[:'avg_execution_time']
  end

  if attributes.key?(:'last_execution')
    self.last_execution = attributes[:'last_execution']
  end
end

Instance Attribute Details

#avg_execution_timeObject

Returns the value of attribute avg_execution_time.



25
26
27
# File 'lib/mudbase/models/function_stats.rb', line 25

def avg_execution_time
  @avg_execution_time
end

#failed_executionsObject

Returns the value of attribute failed_executions.



23
24
25
# File 'lib/mudbase/models/function_stats.rb', line 23

def failed_executions
  @failed_executions
end

#last_executionObject

Returns the value of attribute last_execution.



27
28
29
# File 'lib/mudbase/models/function_stats.rb', line 27

def last_execution
  @last_execution
end

#successful_executionsObject

Returns the value of attribute successful_executions.



21
22
23
# File 'lib/mudbase/models/function_stats.rb', line 21

def successful_executions
  @successful_executions
end

#total_executionsObject

Returns the value of attribute total_executions.



19
20
21
# File 'lib/mudbase/models/function_stats.rb', line 19

def total_executions
  @total_executions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/mudbase/models/function_stats.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/mudbase/models/function_stats.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/mudbase/models/function_stats.rb', line 30

def self.attribute_map
  {
    :'total_executions' => :'totalExecutions',
    :'successful_executions' => :'successfulExecutions',
    :'failed_executions' => :'failedExecutions',
    :'avg_execution_time' => :'avgExecutionTime',
    :'last_execution' => :'lastExecution'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/mudbase/models/function_stats.rb', line 146

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/mudbase/models/function_stats.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/mudbase/models/function_stats.rb', line 51

def self.openapi_types
  {
    :'total_executions' => :'Integer',
    :'successful_executions' => :'Integer',
    :'failed_executions' => :'Integer',
    :'avg_execution_time' => :'Float',
    :'last_execution' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



121
122
123
124
125
126
127
128
129
# File 'lib/mudbase/models/function_stats.rb', line 121

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_executions == o.total_executions &&
      successful_executions == o.successful_executions &&
      failed_executions == o.failed_executions &&
      avg_execution_time == o.avg_execution_time &&
      last_execution == o.last_execution
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


133
134
135
# File 'lib/mudbase/models/function_stats.rb', line 133

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



139
140
141
# File 'lib/mudbase/models/function_stats.rb', line 139

def hash
  [total_executions, successful_executions, failed_executions, avg_execution_time, last_execution].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



106
107
108
109
110
# File 'lib/mudbase/models/function_stats.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/mudbase/models/function_stats.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



114
115
116
117
# File 'lib/mudbase/models/function_stats.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end