Class: Mudbase::FunctionTrigger

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/function_trigger.rb

Overview

Function trigger config (type, event, schedule, path, method, collectionId, bucketId).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FunctionTrigger

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/mudbase/models/function_trigger.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::FunctionTrigger` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::FunctionTrigger`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'schedule')
    self.schedule = attributes[:'schedule']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'collection_id')
    self.collection_id = attributes[:'collection_id']
  end

  if attributes.key?(:'bucket_id')
    self.bucket_id = attributes[:'bucket_id']
  end
end

Instance Attribute Details

#bucket_idObject

For file triggers - filter by bucket



37
38
39
# File 'lib/mudbase/models/function_trigger.rb', line 37

def bucket_id
  @bucket_id
end

#collection_idObject

For document triggers - filter by collection



34
35
36
# File 'lib/mudbase/models/function_trigger.rb', line 34

def collection_id
  @collection_id
end

#eventObject

Event name (e.g. create, update, delete for document; uploaded, deleted for file; tx, balance for wallet)



23
24
25
# File 'lib/mudbase/models/function_trigger.rb', line 23

def event
  @event
end

#methodObject

Returns the value of attribute method.



31
32
33
# File 'lib/mudbase/models/function_trigger.rb', line 31

def method
  @method
end

#pathObject

HTTP path for http triggers



29
30
31
# File 'lib/mudbase/models/function_trigger.rb', line 29

def path
  @path
end

#scheduleObject

For cron - minutely, hourly, daily, weekly, or custom cron expression



26
27
28
# File 'lib/mudbase/models/function_trigger.rb', line 26

def schedule
  @schedule
end

#typeObject

Trigger type



20
21
22
# File 'lib/mudbase/models/function_trigger.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/mudbase/models/function_trigger.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/mudbase/models/function_trigger.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/mudbase/models/function_trigger.rb', line 62

def self.attribute_map
  {
    :'type' => :'type',
    :'event' => :'event',
    :'schedule' => :'schedule',
    :'path' => :'path',
    :'method' => :'method',
    :'collection_id' => :'collectionId',
    :'bucket_id' => :'bucketId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/mudbase/models/function_trigger.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/mudbase/models/function_trigger.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/mudbase/models/function_trigger.rb', line 85

def self.openapi_types
  {
    :'type' => :'String',
    :'event' => :'String',
    :'schedule' => :'String',
    :'path' => :'String',
    :'method' => :'String',
    :'collection_id' => :'String',
    :'bucket_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
# File 'lib/mudbase/models/function_trigger.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      event == o.event &&
      schedule == o.schedule &&
      path == o.path &&
      method == o.method &&
      collection_id == o.collection_id &&
      bucket_id == o.bucket_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/mudbase/models/function_trigger.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/mudbase/models/function_trigger.rb', line 216

def hash
  [type, event, schedule, path, method, collection_id, bucket_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
# File 'lib/mudbase/models/function_trigger.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/mudbase/models/function_trigger.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
172
# File 'lib/mudbase/models/function_trigger.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["http", "event", "document", "file", "webhook", "wallet", "cron", "messaging"])
  return false unless type_validator.valid?(@type)
  method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "DELETE"])
  return false unless method_validator.valid?(@method)
  true
end