Class: Mudbase::GetBillingEstimate200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_billing_estimate200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetBillingEstimate200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetBillingEstimate200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetBillingEstimate200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'estimated_overage_cents')
    self.estimated_overage_cents = attributes[:'estimated_overage_cents']
  end

  if attributes.key?(:'estimated_overage')
    self.estimated_overage = attributes[:'estimated_overage']
  end

  if attributes.key?(:'forecast_overage_cents')
    self.forecast_overage_cents = attributes[:'forecast_overage_cents']
  end

  if attributes.key?(:'forecast_overage')
    self.forecast_overage = attributes[:'forecast_overage']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'spend_limits')
    self.spend_limits = attributes[:'spend_limits']
  end
end

Instance Attribute Details

#estimated_overageObject

Returns the value of attribute estimated_overage.



25
26
27
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 25

def estimated_overage
  @estimated_overage
end

#estimated_overage_centsObject

Returns the value of attribute estimated_overage_cents.



23
24
25
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 23

def estimated_overage_cents
  @estimated_overage_cents
end

#forecast_overageObject

Returns the value of attribute forecast_overage.



29
30
31
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 29

def forecast_overage
  @forecast_overage
end

#forecast_overage_centsObject

Returns the value of attribute forecast_overage_cents.



27
28
29
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 27

def forecast_overage_cents
  @forecast_overage_cents
end

#line_itemsObject

Returns the value of attribute line_items.



21
22
23
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 21

def line_items
  @line_items
end

#messageObject

Human-readable forecast when applicable



32
33
34
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 32

def message
  @message
end

#periodObject

Current month YYYY-MM



19
20
21
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 19

def period
  @period
end

#spend_limitsObject

Returns the value of attribute spend_limits.



34
35
36
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 34

def spend_limits
  @spend_limits
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 37

def self.attribute_map
  {
    :'period' => :'period',
    :'line_items' => :'lineItems',
    :'estimated_overage_cents' => :'estimatedOverageCents',
    :'estimated_overage' => :'estimatedOverage',
    :'forecast_overage_cents' => :'forecastOverageCents',
    :'forecast_overage' => :'forecastOverage',
    :'message' => :'message',
    :'spend_limits' => :'spendLimits'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
79
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 75

def self.openapi_nullable
  Set.new([
    :'message',
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 61

def self.openapi_types
  {
    :'period' => :'String',
    :'line_items' => :'Array<GetBillingEstimate200ResponseLineItemsInner>',
    :'estimated_overage_cents' => :'Float',
    :'estimated_overage' => :'String',
    :'forecast_overage_cents' => :'Float',
    :'forecast_overage' => :'String',
    :'message' => :'String',
    :'spend_limits' => :'GetBillingEstimate200ResponseSpendLimits'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      period == o.period &&
      line_items == o.line_items &&
      estimated_overage_cents == o.estimated_overage_cents &&
      estimated_overage == o.estimated_overage &&
      forecast_overage_cents == o.forecast_overage_cents &&
      forecast_overage == o.forecast_overage &&
      message == o.message &&
      spend_limits == o.spend_limits
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 170

def hash
  [period, line_items, estimated_overage_cents, estimated_overage, forecast_overage_cents, forecast_overage, message, spend_limits].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
# File 'lib/mudbase/models/get_billing_estimate200_response.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end