Class: Mudbase::GetCheckoutPayment200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_checkout_payment200_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetCheckoutPayment200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetCheckoutPayment200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetCheckoutPayment200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  end

  if attributes.key?(:'payment_address')
    self.payment_address = attributes[:'payment_address']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'asset')
    self.asset = attributes[:'asset']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'total_due')
    self.total_due = attributes[:'total_due']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



26
27
28
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 26

def amount
  @amount
end

#assetObject

Returns the value of attribute asset.



24
25
26
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 24

def asset
  @asset
end

#currencyObject

Returns the value of attribute currency.



28
29
30
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 28

def currency
  @currency
end

#expires_atObject

Returns the value of attribute expires_at.



34
35
36
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 34

def expires_at
  @expires_at
end

#networkObject

Returns the value of attribute network.



22
23
24
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 22

def network
  @network
end

#payment_addressObject

Returns the value of attribute payment_address.



20
21
22
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 20

def payment_address
  @payment_address
end

#payment_idObject

Returns the value of attribute payment_id.



18
19
20
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 18

def payment_id
  @payment_id
end

#statusObject

Returns the value of attribute status.



32
33
34
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 32

def status
  @status
end

#total_dueObject

Returns the value of attribute total_due.



30
31
32
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 30

def total_due
  @total_due
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 37

def self.attribute_map
  {
    :'payment_id' => :'paymentId',
    :'payment_address' => :'paymentAddress',
    :'network' => :'network',
    :'asset' => :'asset',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'total_due' => :'totalDue',
    :'status' => :'status',
    :'expires_at' => :'expiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
84
85
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 77

def self.openapi_nullable
  Set.new([
    :'payment_address',
    :'network',
    :'asset',
    :'total_due',
    :'expires_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 62

def self.openapi_types
  {
    :'payment_id' => :'String',
    :'payment_address' => :'String',
    :'network' => :'String',
    :'asset' => :'String',
    :'amount' => :'Float',
    :'currency' => :'String',
    :'total_due' => :'String',
    :'status' => :'String',
    :'expires_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      payment_id == o.payment_id &&
      payment_address == o.payment_address &&
      network == o.network &&
      asset == o.asset &&
      amount == o.amount &&
      currency == o.currency &&
      total_due == o.total_due &&
      status == o.status &&
      expires_at == o.expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 179

def hash
  [payment_id, payment_address, network, asset, amount, currency, total_due, status, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
# File 'lib/mudbase/models/get_checkout_payment200_response_data.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end