Class: Mudbase::GetInvoices200ResponseInvoicesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_invoices200_response_invoices_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInvoices200ResponseInvoicesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetInvoices200ResponseInvoicesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetInvoices200ResponseInvoicesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'invoice_number')
    self.invoice_number = attributes[:'invoice_number']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'paid_at')
    self.paid_at = attributes[:'paid_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'hosted_invoice_url')
    self.hosted_invoice_url = attributes[:'hosted_invoice_url']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 18

def _id
  @_id
end

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 32

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



26
27
28
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 26

def currency
  @currency
end

#due_dateObject

Returns the value of attribute due_date.



28
29
30
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 28

def due_date
  @due_date
end

#hosted_invoice_urlObject

Returns the value of attribute hosted_invoice_url.



34
35
36
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 34

def hosted_invoice_url
  @hosted_invoice_url
end

#invoice_numberObject

Returns the value of attribute invoice_number.



20
21
22
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 20

def invoice_number
  @invoice_number
end

Returns the value of attribute paid_at.



30
31
32
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 30

def paid_at
  @paid_at
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 22

def status
  @status
end

#totalObject

Returns the value of attribute total.



24
25
26
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 24

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 37

def self.attribute_map
  {
    :'_id' => :'_id',
    :'invoice_number' => :'invoiceNumber',
    :'status' => :'status',
    :'total' => :'total',
    :'currency' => :'currency',
    :'due_date' => :'dueDate',
    :'paid_at' => :'paidAt',
    :'created_at' => :'createdAt',
    :'hosted_invoice_url' => :'hostedInvoiceUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 77

def self.openapi_nullable
  Set.new([
    :'due_date',
    :'paid_at',
    :'hosted_invoice_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 62

def self.openapi_types
  {
    :'_id' => :'String',
    :'invoice_number' => :'String',
    :'status' => :'String',
    :'total' => :'Float',
    :'currency' => :'String',
    :'due_date' => :'Time',
    :'paid_at' => :'Time',
    :'created_at' => :'Time',
    :'hosted_invoice_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      invoice_number == o.invoice_number &&
      status == o.status &&
      total == o.total &&
      currency == o.currency &&
      due_date == o.due_date &&
      paid_at == o.paid_at &&
      created_at == o.created_at &&
      hosted_invoice_url == o.hosted_invoice_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 177

def hash
  [_id, invoice_number, status, total, currency, due_date, paid_at, created_at, hosted_invoice_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
# File 'lib/mudbase/models/get_invoices200_response_invoices_inner.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end