Class: Mudbase::GetOrganizationUsers200ResponseUsersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_organization_users200_response_users_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetOrganizationUsers200ResponseUsersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetOrganizationUsers200ResponseUsersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetOrganizationUsers200ResponseUsersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'avatar')
    self.avatar = attributes[:'avatar']
  end

  if attributes.key?(:'email_verified')
    self.email_verified = attributes[:'email_verified']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'custom_role')
    self.custom_role = attributes[:'custom_role']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'phone_verified')
    self.phone_verified = attributes[:'phone_verified']
  end

  if attributes.key?(:'last_login')
    self. = attributes[:'last_login']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'account_status')
    self. = attributes[:'account_status']
  end

  if attributes.key?(:'is_anonymous')
    self.is_anonymous = attributes[:'is_anonymous']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 18

def _id
  @_id
end

#account_statusObject

Returns the value of attribute account_status.



42
43
44
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 42

def 
  @account_status
end

#avatarObject

Returns the value of attribute avatar.



26
27
28
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 26

def avatar
  @avatar
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 46

def created_at
  @created_at
end

#custom_roleObject

Returns the value of attribute custom_role.



32
33
34
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 32

def custom_role
  @custom_role
end

#emailObject

Returns the value of attribute email.



24
25
26
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 24

def email
  @email
end

#email_verifiedObject

Returns the value of attribute email_verified.



28
29
30
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 28

def email_verified
  @email_verified
end

#first_nameObject

Returns the value of attribute first_name.



20
21
22
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 20

def first_name
  @first_name
end

#is_activeObject

Returns the value of attribute is_active.



40
41
42
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 40

def is_active
  @is_active
end

#is_anonymousObject

Returns the value of attribute is_anonymous.



44
45
46
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 44

def is_anonymous
  @is_anonymous
end

#last_loginObject

Returns the value of attribute last_login.



38
39
40
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 38

def 
  @last_login
end

#last_nameObject

Returns the value of attribute last_name.



22
23
24
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 22

def last_name
  @last_name
end

#phoneObject

Returns the value of attribute phone.



34
35
36
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 34

def phone
  @phone
end

#phone_verifiedObject

Returns the value of attribute phone_verified.



36
37
38
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 36

def phone_verified
  @phone_verified
end

#projectObject

Returns the value of attribute project.



48
49
50
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 48

def project
  @project
end

#roleObject

Returns the value of attribute role.



30
31
32
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 30

def role
  @role
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 73

def self.attribute_map
  {
    :'_id' => :'_id',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'email' => :'email',
    :'avatar' => :'avatar',
    :'email_verified' => :'emailVerified',
    :'role' => :'role',
    :'custom_role' => :'customRole',
    :'phone' => :'phone',
    :'phone_verified' => :'phoneVerified',
    :'last_login' => :'lastLogin',
    :'is_active' => :'isActive',
    :'account_status' => :'accountStatus',
    :'is_anonymous' => :'isAnonymous',
    :'created_at' => :'createdAt',
    :'project' => :'project'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 105

def self.openapi_types
  {
    :'_id' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'email' => :'String',
    :'avatar' => :'String',
    :'email_verified' => :'Boolean',
    :'role' => :'String',
    :'custom_role' => :'String',
    :'phone' => :'String',
    :'phone_verified' => :'Boolean',
    :'last_login' => :'Time',
    :'is_active' => :'Boolean',
    :'account_status' => :'String',
    :'is_anonymous' => :'Boolean',
    :'created_at' => :'Time',
    :'project' => :'GetOrganizationUsers200ResponseUsersInnerProject'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      email == o.email &&
      avatar == o.avatar &&
      email_verified == o.email_verified &&
      role == o.role &&
      custom_role == o.custom_role &&
      phone == o.phone &&
      phone_verified == o.phone_verified &&
       == o. &&
      is_active == o.is_active &&
       == o. &&
      is_anonymous == o.is_anonymous &&
      created_at == o.created_at &&
      project == o.project
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 271

def hash
  [_id, first_name, last_name, email, avatar, email_verified, role, custom_role, phone, phone_verified, , is_active, , is_anonymous, created_at, project].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 215

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
# File 'lib/mudbase/models/get_organization_users200_response_users_inner.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
   = EnumAttributeValidator.new('String', ["pending", "active", "suspended"])
  return false unless .valid?(@account_status)
  true
end