Class: Mudbase::GetPayoutHistory200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_payout_history200_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPayoutHistory200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetPayoutHistory200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetPayoutHistory200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'gross_amount')
    self.gross_amount = attributes[:'gross_amount']
  end

  if attributes.key?(:'network_fee')
    self.network_fee = attributes[:'network_fee']
  end

  if attributes.key?(:'net_amount')
    self.net_amount = attributes[:'net_amount']
  end

  if attributes.key?(:'to_address')
    self.to_address = attributes[:'to_address']
  end

  if attributes.key?(:'tx_hash')
    self.tx_hash = attributes[:'tx_hash']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 18

def _id
  @_id
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 34

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



20
21
22
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 20

def currency
  @currency
end

#gross_amountObject

Returns the value of attribute gross_amount.



22
23
24
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 22

def gross_amount
  @gross_amount
end

#net_amountObject

Returns the value of attribute net_amount.



26
27
28
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 26

def net_amount
  @net_amount
end

#network_feeObject

Returns the value of attribute network_fee.



24
25
26
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 24

def network_fee
  @network_fee
end

#statusObject

Returns the value of attribute status.



32
33
34
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 32

def status
  @status
end

#to_addressObject

Returns the value of attribute to_address.



28
29
30
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 28

def to_address
  @to_address
end

#tx_hashObject

Returns the value of attribute tx_hash.



30
31
32
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 30

def tx_hash
  @tx_hash
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 37

def self.attribute_map
  {
    :'_id' => :'_id',
    :'currency' => :'currency',
    :'gross_amount' => :'grossAmount',
    :'network_fee' => :'networkFee',
    :'net_amount' => :'netAmount',
    :'to_address' => :'toAddress',
    :'tx_hash' => :'txHash',
    :'status' => :'status',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 62

def self.openapi_types
  {
    :'_id' => :'String',
    :'currency' => :'String',
    :'gross_amount' => :'Float',
    :'network_fee' => :'Float',
    :'net_amount' => :'Float',
    :'to_address' => :'String',
    :'tx_hash' => :'String',
    :'status' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      currency == o.currency &&
      gross_amount == o.gross_amount &&
      network_fee == o.network_fee &&
      net_amount == o.net_amount &&
      to_address == o.to_address &&
      tx_hash == o.tx_hash &&
      status == o.status &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 174

def hash
  [_id, currency, gross_amount, network_fee, net_amount, to_address, tx_hash, status, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
# File 'lib/mudbase/models/get_payout_history200_response_data_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end