Class: Mudbase::GetSpeedUpParams200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::GetSpeedUpParams200ResponseData
- Defined in:
- lib/mudbase/models/get_speed_up_params200_response_data.rb
Instance Attribute Summary collapse
-
#chain_id ⇒ Object
Returns the value of attribute chain_id.
-
#data ⇒ Object
Returns the value of attribute data.
-
#from ⇒ Object
Returns the value of attribute from.
-
#gas_limit ⇒ Object
Returns the value of attribute gas_limit.
-
#gas_price ⇒ Object
Legacy; use when EIP-1559 not used.
-
#max_fee_per_gas ⇒ Object
Returns the value of attribute max_fee_per_gas.
-
#max_priority_fee_per_gas ⇒ Object
Returns the value of attribute max_priority_fee_per_gas.
-
#nonce ⇒ Object
Returns the value of attribute nonce.
-
#to ⇒ Object
Returns the value of attribute to.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetSpeedUpParams200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetSpeedUpParams200ResponseData
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetSpeedUpParams200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetSpeedUpParams200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chain_id') self.chain_id = attributes[:'chain_id'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'nonce') self.nonce = attributes[:'nonce'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'data') self.data = attributes[:'data'] end if attributes.key?(:'gas_limit') self.gas_limit = attributes[:'gas_limit'] end if attributes.key?(:'max_fee_per_gas') self.max_fee_per_gas = attributes[:'max_fee_per_gas'] end if attributes.key?(:'max_priority_fee_per_gas') self.max_priority_fee_per_gas = attributes[:'max_priority_fee_per_gas'] end if attributes.key?(:'gas_price') self.gas_price = attributes[:'gas_price'] end end |
Instance Attribute Details
#chain_id ⇒ Object
Returns the value of attribute chain_id.
18 19 20 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 18 def chain_id @chain_id end |
#data ⇒ Object
Returns the value of attribute data.
28 29 30 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 28 def data @data end |
#from ⇒ Object
Returns the value of attribute from.
20 21 22 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 20 def from @from end |
#gas_limit ⇒ Object
Returns the value of attribute gas_limit.
30 31 32 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 30 def gas_limit @gas_limit end |
#gas_price ⇒ Object
Legacy; use when EIP-1559 not used
37 38 39 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 37 def gas_price @gas_price end |
#max_fee_per_gas ⇒ Object
Returns the value of attribute max_fee_per_gas.
32 33 34 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 32 def max_fee_per_gas @max_fee_per_gas end |
#max_priority_fee_per_gas ⇒ Object
Returns the value of attribute max_priority_fee_per_gas.
34 35 36 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 34 def max_priority_fee_per_gas @max_priority_fee_per_gas end |
#nonce ⇒ Object
Returns the value of attribute nonce.
22 23 24 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 22 def nonce @nonce end |
#to ⇒ Object
Returns the value of attribute to.
24 25 26 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 24 def to @to end |
#value ⇒ Object
Returns the value of attribute value.
26 27 28 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 26 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 40 def self.attribute_map { :'chain_id' => :'chainId', :'from' => :'from', :'nonce' => :'nonce', :'to' => :'to', :'value' => :'value', :'data' => :'data', :'gas_limit' => :'gasLimit', :'max_fee_per_gas' => :'maxFeePerGas', :'max_priority_fee_per_gas' => :'maxPriorityFeePerGas', :'gas_price' => :'gasPrice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 66 def self.openapi_types { :'chain_id' => :'Integer', :'from' => :'String', :'nonce' => :'Integer', :'to' => :'String', :'value' => :'String', :'data' => :'String', :'gas_limit' => :'String', :'max_fee_per_gas' => :'String', :'max_priority_fee_per_gas' => :'String', :'gas_price' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && chain_id == o.chain_id && from == o.from && nonce == o.nonce && to == o.to && value == o.value && data == o.data && gas_limit == o.gas_limit && max_fee_per_gas == o.max_fee_per_gas && max_priority_fee_per_gas == o.max_priority_fee_per_gas && gas_price == o.gas_price end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 184 def hash [chain_id, from, nonce, to, value, data, gas_limit, max_fee_per_gas, max_priority_fee_per_gas, gas_price].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/mudbase/models/get_speed_up_params200_response_data.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |