Class: Mudbase::GetWebhookConfig200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_webhook_config200_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWebhookConfig200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetWebhookConfig200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetWebhookConfig200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'webhook_events')
    if (value = attributes[:'webhook_events']).is_a?(Array)
      self.webhook_events = value
    end
  end

  if attributes.key?(:'webhook_version')
    self.webhook_version = attributes[:'webhook_version']
  end

  if attributes.key?(:'transformations')
    if (value = attributes[:'transformations']).is_a?(Array)
      self.transformations = value
    end
  end

  if attributes.key?(:'has_secret')
    self.has_secret = attributes[:'has_secret']
  end
end

Instance Attribute Details

#has_secretObject

Whether a webhook secret is configured (value not returned)



28
29
30
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 28

def has_secret
  @has_secret
end

#transformationsObject

Transformation rules applied to payloads



25
26
27
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 25

def transformations
  @transformations
end

#webhook_eventsObject

Returns the value of attribute webhook_events.



20
21
22
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 20

def webhook_events
  @webhook_events
end

#webhook_urlObject

Returns the value of attribute webhook_url.



18
19
20
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 18

def webhook_url
  @webhook_url
end

#webhook_versionObject

Returns the value of attribute webhook_version.



22
23
24
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 22

def webhook_version
  @webhook_version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 31

def self.attribute_map
  {
    :'webhook_url' => :'webhookUrl',
    :'webhook_events' => :'webhookEvents',
    :'webhook_version' => :'webhookVersion',
    :'transformations' => :'transformations',
    :'has_secret' => :'hasSecret'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 152

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
67
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 63

def self.openapi_nullable
  Set.new([
    :'webhook_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 52

def self.openapi_types
  {
    :'webhook_url' => :'String',
    :'webhook_events' => :'Array<String>',
    :'webhook_version' => :'String',
    :'transformations' => :'Array<GetWebhookConfig200ResponseDataTransformationsInner>',
    :'has_secret' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
132
133
134
135
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      webhook_url == o.webhook_url &&
      webhook_events == o.webhook_events &&
      webhook_version == o.webhook_version &&
      transformations == o.transformations &&
      has_secret == o.has_secret
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


139
140
141
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 139

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



145
146
147
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 145

def hash
  [webhook_url, webhook_events, webhook_version, transformations, has_secret].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
# File 'lib/mudbase/models/get_webhook_config200_response_data.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end