Class: Mudbase::Message

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Message

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/mudbase/models/message.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Message` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Message`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'recipients')
    self.recipients = attributes[:'recipients']
  end

  if attributes.key?(:'success_count')
    self.success_count = attributes[:'success_count']
  end

  if attributes.key?(:'failure_count')
    self.failure_count = attributes[:'failure_count']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/message.rb', line 18

def _id
  @_id
end

#bodyObject

Returns the value of attribute body.



24
25
26
# File 'lib/mudbase/models/message.rb', line 24

def body
  @body
end

#failure_countObject

Returns the value of attribute failure_count.



32
33
34
# File 'lib/mudbase/models/message.rb', line 32

def failure_count
  @failure_count
end

#recipientsObject

Returns the value of attribute recipients.



28
29
30
# File 'lib/mudbase/models/message.rb', line 28

def recipients
  @recipients
end

#sent_atObject

Returns the value of attribute sent_at.



36
37
38
# File 'lib/mudbase/models/message.rb', line 36

def sent_at
  @sent_at
end

#statusObject

Returns the value of attribute status.



34
35
36
# File 'lib/mudbase/models/message.rb', line 34

def status
  @status
end

#subjectObject

Returns the value of attribute subject.



26
27
28
# File 'lib/mudbase/models/message.rb', line 26

def subject
  @subject
end

#success_countObject

Returns the value of attribute success_count.



30
31
32
# File 'lib/mudbase/models/message.rb', line 30

def success_count
  @success_count
end

#titleObject

Returns the value of attribute title.



22
23
24
# File 'lib/mudbase/models/message.rb', line 22

def title
  @title
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/mudbase/models/message.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/mudbase/models/message.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/mudbase/models/message.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/mudbase/models/message.rb', line 61

def self.attribute_map
  {
    :'_id' => :'_id',
    :'type' => :'type',
    :'title' => :'title',
    :'body' => :'body',
    :'subject' => :'subject',
    :'recipients' => :'recipients',
    :'success_count' => :'successCount',
    :'failure_count' => :'failureCount',
    :'status' => :'status',
    :'sent_at' => :'sentAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/mudbase/models/message.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/mudbase/models/message.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mudbase/models/message.rb', line 87

def self.openapi_types
  {
    :'_id' => :'String',
    :'type' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'subject' => :'String',
    :'recipients' => :'Integer',
    :'success_count' => :'Integer',
    :'failure_count' => :'Integer',
    :'status' => :'String',
    :'sent_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/mudbase/models/message.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      type == o.type &&
      title == o.title &&
      body == o.body &&
      subject == o.subject &&
      recipients == o.recipients &&
      success_count == o.success_count &&
      failure_count == o.failure_count &&
      status == o.status &&
      sent_at == o.sent_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/mudbase/models/message.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/mudbase/models/message.rb', line 229

def hash
  [_id, type, title, body, subject, recipients, success_count, failure_count, status, sent_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
# File 'lib/mudbase/models/message.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/mudbase/models/message.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
179
180
181
182
# File 'lib/mudbase/models/message.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["push", "email", "sms"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["sent", "failed", "pending"])
  return false unless status_validator.valid?(@status)
  true
end