Class: Mudbase::MessageSentResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::MessageSentResponseData
- Defined in:
- lib/mudbase/models/message_sent_response_data.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#failure_count ⇒ Object
Returns the value of attribute failure_count.
-
#message_id ⇒ Object
Returns the value of attribute message_id.
-
#recipients ⇒ Object
Returns the value of attribute recipients.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#success_count ⇒ Object
Returns the value of attribute success_count.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MessageSentResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MessageSentResponseData
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::MessageSentResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::MessageSentResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'recipients') self.recipients = attributes[:'recipients'] end if attributes.key?(:'success_count') self.success_count = attributes[:'success_count'] end if attributes.key?(:'failure_count') self.failure_count = attributes[:'failure_count'] end if attributes.key?(:'message_id') self. = attributes[:'message_id'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 18 def _id @_id end |
#failure_count ⇒ Object
Returns the value of attribute failure_count.
28 29 30 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 28 def failure_count @failure_count end |
#message_id ⇒ Object
Returns the value of attribute message_id.
30 31 32 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 30 def @message_id end |
#recipients ⇒ Object
Returns the value of attribute recipients.
24 25 26 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 24 def recipients @recipients end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
32 33 34 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 32 def sent_at @sent_at end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 22 def status @status end |
#success_count ⇒ Object
Returns the value of attribute success_count.
26 27 28 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 26 def success_count @success_count end |
#type ⇒ Object
Returns the value of attribute type.
20 21 22 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 35 def self.attribute_map { :'_id' => :'_id', :'type' => :'type', :'status' => :'status', :'recipients' => :'recipients', :'success_count' => :'successCount', :'failure_count' => :'failureCount', :'message_id' => :'messageId', :'sent_at' => :'sentAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 59 def self.openapi_types { :'_id' => :'String', :'type' => :'String', :'status' => :'String', :'recipients' => :'Integer', :'success_count' => :'Integer', :'failure_count' => :'Integer', :'message_id' => :'String', :'sent_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && type == o.type && status == o.status && recipients == o.recipients && success_count == o.success_count && failure_count == o.failure_count && == o. && sent_at == o.sent_at end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 165 def hash [_id, type, status, recipients, success_count, failure_count, , sent_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/mudbase/models/message_sent_response_data.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |