Class: Mudbase::MonitoringLogsResponseLogsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/monitoring_logs_response_logs_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MonitoringLogsResponseLogsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::MonitoringLogsResponseLogsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::MonitoringLogsResponseLogsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'activity_title')
    self.activity_title = attributes[:'activity_title']
  end

  if attributes.key?(:'activity_detail')
    self.activity_detail = attributes[:'activity_detail']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



26
27
28
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 26

def action
  @action
end

#activity_detailObject

Returns the value of attribute activity_detail.



30
31
32
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 30

def activity_detail
  @activity_detail
end

#activity_titleObject

Returns the value of attribute activity_title.



28
29
30
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 28

def activity_title
  @activity_title
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 18

def id
  @id
end

#levelObject

Returns the value of attribute level.



22
23
24
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 22

def level
  @level
end

#messageObject

Returns the value of attribute message.



24
25
26
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 24

def message
  @message
end

#metadataObject

Returns the value of attribute metadata.



36
37
38
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 36

def 
  @metadata
end

#projectObject

Returns the value of attribute project.



34
35
36
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 34

def project
  @project
end

#timestampObject

Returns the value of attribute timestamp.



20
21
22
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 20

def timestamp
  @timestamp
end

#userObject

Returns the value of attribute user.



32
33
34
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 32

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'timestamp' => :'timestamp',
    :'level' => :'level',
    :'message' => :'message',
    :'action' => :'action',
    :'activity_title' => :'activityTitle',
    :'activity_detail' => :'activityDetail',
    :'user' => :'user',
    :'project' => :'project',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 81

def self.openapi_nullable
  Set.new([
    :'user',
    :'project',
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 65

def self.openapi_types
  {
    :'id' => :'String',
    :'timestamp' => :'Time',
    :'level' => :'String',
    :'message' => :'String',
    :'action' => :'String',
    :'activity_title' => :'String',
    :'activity_detail' => :'String',
    :'user' => :'MonitoringLogsResponseLogsInnerUser',
    :'project' => :'Object',
    :'metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      timestamp == o.timestamp &&
      level == o.level &&
      message == o.message &&
      action == o.action &&
      activity_title == o.activity_title &&
      activity_detail == o.activity_detail &&
      user == o.user &&
      project == o.project &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 185

def hash
  [id, timestamp, level, message, action, activity_title, activity_detail, user, project, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/mudbase/models/monitoring_logs_response_logs_inner.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end