Class: Mudbase::MonitoringPerformanceResponseMetrics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::MonitoringPerformanceResponseMetrics
- Defined in:
- lib/mudbase/models/monitoring_performance_response_metrics.rb
Instance Attribute Summary collapse
-
#avg_response_time ⇒ Object
Returns the value of attribute avg_response_time.
-
#error_count ⇒ Object
Returns the value of attribute error_count.
-
#error_rate ⇒ Object
Returns the value of attribute error_rate.
-
#latency_source ⇒ Object
usage_stat when filled from UsageStat.
-
#max_response_time ⇒ Object
Returns the value of attribute max_response_time.
-
#min_response_time ⇒ Object
Returns the value of attribute min_response_time.
-
#success_count ⇒ Object
Returns the value of attribute success_count.
-
#success_rate ⇒ Object
Returns the value of attribute success_rate.
-
#total_requests ⇒ Object
Returns the value of attribute total_requests.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoringPerformanceResponseMetrics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MonitoringPerformanceResponseMetrics
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::MonitoringPerformanceResponseMetrics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::MonitoringPerformanceResponseMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total_requests') self.total_requests = attributes[:'total_requests'] end if attributes.key?(:'avg_response_time') self.avg_response_time = attributes[:'avg_response_time'] end if attributes.key?(:'min_response_time') self.min_response_time = attributes[:'min_response_time'] end if attributes.key?(:'max_response_time') self.max_response_time = attributes[:'max_response_time'] end if attributes.key?(:'error_count') self.error_count = attributes[:'error_count'] end if attributes.key?(:'success_count') self.success_count = attributes[:'success_count'] end if attributes.key?(:'success_rate') self.success_rate = attributes[:'success_rate'] end if attributes.key?(:'error_rate') self.error_rate = attributes[:'error_rate'] end if attributes.key?(:'latency_source') self.latency_source = attributes[:'latency_source'] end end |
Instance Attribute Details
#avg_response_time ⇒ Object
Returns the value of attribute avg_response_time.
20 21 22 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 20 def avg_response_time @avg_response_time end |
#error_count ⇒ Object
Returns the value of attribute error_count.
26 27 28 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 26 def error_count @error_count end |
#error_rate ⇒ Object
Returns the value of attribute error_rate.
32 33 34 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 32 def error_rate @error_rate end |
#latency_source ⇒ Object
usage_stat when filled from UsageStat
35 36 37 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 35 def latency_source @latency_source end |
#max_response_time ⇒ Object
Returns the value of attribute max_response_time.
24 25 26 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 24 def max_response_time @max_response_time end |
#min_response_time ⇒ Object
Returns the value of attribute min_response_time.
22 23 24 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 22 def min_response_time @min_response_time end |
#success_count ⇒ Object
Returns the value of attribute success_count.
28 29 30 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 28 def success_count @success_count end |
#success_rate ⇒ Object
Returns the value of attribute success_rate.
30 31 32 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 30 def success_rate @success_rate end |
#total_requests ⇒ Object
Returns the value of attribute total_requests.
18 19 20 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 18 def total_requests @total_requests end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 38 def self.attribute_map { :'total_requests' => :'totalRequests', :'avg_response_time' => :'avgResponseTime', :'min_response_time' => :'minResponseTime', :'max_response_time' => :'maxResponseTime', :'error_count' => :'errorCount', :'success_count' => :'successCount', :'success_rate' => :'successRate', :'error_rate' => :'errorRate', :'latency_source' => :'latencySource' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 63 def self.openapi_types { :'total_requests' => :'Integer', :'avg_response_time' => :'Float', :'min_response_time' => :'Float', :'max_response_time' => :'Float', :'error_count' => :'Integer', :'success_count' => :'Integer', :'success_rate' => :'Float', :'error_rate' => :'Float', :'latency_source' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && total_requests == o.total_requests && avg_response_time == o.avg_response_time && min_response_time == o.min_response_time && max_response_time == o.max_response_time && error_count == o.error_count && success_count == o.success_count && success_rate == o.success_rate && error_rate == o.error_rate && latency_source == o.latency_source end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 175 def hash [total_requests, avg_response_time, min_response_time, max_response_time, error_count, success_count, success_rate, error_rate, latency_source].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 |
# File 'lib/mudbase/models/monitoring_performance_response_metrics.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |