Class: Mudbase::NonCustodialAddress

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/non_custodial_address.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NonCustodialAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/mudbase/models/non_custodial_address.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::NonCustodialAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::NonCustodialAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'chain')
    self.chain = attributes[:'chain']
  end

  if attributes.key?(:'org')
    self.org = attributes[:'org']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'derivation_path')
    self.derivation_path = attributes[:'derivation_path']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'registered_at')
    self.registered_at = attributes[:'registered_at']
  end

  if attributes.key?(:'last_synced_at')
    self.last_synced_at = attributes[:'last_synced_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/non_custodial_address.rb', line 18

def _id
  @_id
end

#addressObject

Returns the value of attribute address.



20
21
22
# File 'lib/mudbase/models/non_custodial_address.rb', line 20

def address
  @address
end

#chainObject

Returns the value of attribute chain.



22
23
24
# File 'lib/mudbase/models/non_custodial_address.rb', line 22

def chain
  @chain
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/mudbase/models/non_custodial_address.rb', line 38

def created_at
  @created_at
end

#derivation_pathObject

Returns the value of attribute derivation_path.



28
29
30
# File 'lib/mudbase/models/non_custodial_address.rb', line 28

def derivation_path
  @derivation_path
end

#is_activeObject

Returns the value of attribute is_active.



32
33
34
# File 'lib/mudbase/models/non_custodial_address.rb', line 32

def is_active
  @is_active
end

#labelObject

Returns the value of attribute label.



30
31
32
# File 'lib/mudbase/models/non_custodial_address.rb', line 30

def label
  @label
end

#last_synced_atObject

Returns the value of attribute last_synced_at.



36
37
38
# File 'lib/mudbase/models/non_custodial_address.rb', line 36

def last_synced_at
  @last_synced_at
end

#orgObject

Returns the value of attribute org.



24
25
26
# File 'lib/mudbase/models/non_custodial_address.rb', line 24

def org
  @org
end

#projectObject

Returns the value of attribute project.



26
27
28
# File 'lib/mudbase/models/non_custodial_address.rb', line 26

def project
  @project
end

#registered_atObject

Returns the value of attribute registered_at.



34
35
36
# File 'lib/mudbase/models/non_custodial_address.rb', line 34

def registered_at
  @registered_at
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/mudbase/models/non_custodial_address.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/mudbase/models/non_custodial_address.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/mudbase/models/non_custodial_address.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/mudbase/models/non_custodial_address.rb', line 65

def self.attribute_map
  {
    :'_id' => :'_id',
    :'address' => :'address',
    :'chain' => :'chain',
    :'org' => :'org',
    :'project' => :'project',
    :'derivation_path' => :'derivationPath',
    :'label' => :'label',
    :'is_active' => :'isActive',
    :'registered_at' => :'registeredAt',
    :'last_synced_at' => :'lastSyncedAt',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/mudbase/models/non_custodial_address.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
117
# File 'lib/mudbase/models/non_custodial_address.rb', line 111

def self.openapi_nullable
  Set.new([
    :'derivation_path',
    :'label',
    :'last_synced_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/mudbase/models/non_custodial_address.rb', line 93

def self.openapi_types
  {
    :'_id' => :'String',
    :'address' => :'String',
    :'chain' => :'String',
    :'org' => :'String',
    :'project' => :'String',
    :'derivation_path' => :'String',
    :'label' => :'String',
    :'is_active' => :'Boolean',
    :'registered_at' => :'Time',
    :'last_synced_at' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/mudbase/models/non_custodial_address.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      address == o.address &&
      chain == o.chain &&
      org == o.org &&
      project == o.project &&
      derivation_path == o.derivation_path &&
      label == o.label &&
      is_active == o.is_active &&
      registered_at == o.registered_at &&
      last_synced_at == o.last_synced_at &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/mudbase/models/non_custodial_address.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/mudbase/models/non_custodial_address.rb', line 238

def hash
  [_id, address, chain, org, project, derivation_path, label, is_active, registered_at, last_synced_at, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
# File 'lib/mudbase/models/non_custodial_address.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/mudbase/models/non_custodial_address.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
# File 'lib/mudbase/models/non_custodial_address.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  chain_validator = EnumAttributeValidator.new('String', ["ethereum", "binance", "polygon", "celo", "bitcoin"])
  return false unless chain_validator.valid?(@chain)
  true
end