Class: Mudbase::OTPSendRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::OTPSendRequest
- Defined in:
- lib/mudbase/models/otp_send_request.rb
Overview
Request to send OTP via SMS or email for the given project.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#method ⇒ Object
Returns the value of attribute method.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OTPSendRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OTPSendRequest
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/mudbase/models/otp_send_request.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::OTPSendRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::OTPSendRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
21 22 23 |
# File 'lib/mudbase/models/otp_send_request.rb', line 21 def email @email end |
#method ⇒ Object
Returns the value of attribute method.
25 26 27 |
# File 'lib/mudbase/models/otp_send_request.rb', line 25 def method @method end |
#phone ⇒ Object
Returns the value of attribute phone.
19 20 21 |
# File 'lib/mudbase/models/otp_send_request.rb', line 19 def phone @phone end |
#project_id ⇒ Object
Returns the value of attribute project_id.
23 24 25 |
# File 'lib/mudbase/models/otp_send_request.rb', line 23 def project_id @project_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/mudbase/models/otp_send_request.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/mudbase/models/otp_send_request.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 |
# File 'lib/mudbase/models/otp_send_request.rb', line 50 def self.attribute_map { :'phone' => :'phone', :'email' => :'email', :'project_id' => :'projectId', :'method' => :'method' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/mudbase/models/otp_send_request.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/mudbase/models/otp_send_request.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 |
# File 'lib/mudbase/models/otp_send_request.rb', line 70 def self.openapi_types { :'phone' => :'String', :'email' => :'String', :'project_id' => :'String', :'method' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 |
# File 'lib/mudbase/models/otp_send_request.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && phone == o.phone && email == o.email && project_id == o.project_id && method == o.method end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/mudbase/models/otp_send_request.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/mudbase/models/otp_send_request.rb', line 188 def hash [phone, email, project_id, method].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/mudbase/models/otp_send_request.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/mudbase/models/otp_send_request.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 146 147 |
# File 'lib/mudbase/models/otp_send_request.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @project_id.nil? return false if @method.nil? method_validator = EnumAttributeValidator.new('String', ["sms", "email"]) return false unless method_validator.valid?(@method) true end |