Class: Mudbase::OrgCloudflareEdgeHints

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/org_cloudflare_edge_hints.rb

Overview

Cloudflare SSL for SaaS Custom Hostname hints after Mudbase verify (when CLOUDFLARE_* env is set)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrgCloudflareEdgeHints

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::OrgCloudflareEdgeHints` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::OrgCloudflareEdgeHints`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'saas_integration_enabled')
    self.saas_integration_enabled = attributes[:'saas_integration_enabled']
  end

  if attributes.key?(:'skipped')
    self.skipped = attributes[:'skipped']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'custom_hostname_id')
    self.custom_hostname_id = attributes[:'custom_hostname_id']
  end

  if attributes.key?(:'hostname_status')
    self.hostname_status = attributes[:'hostname_status']
  end

  if attributes.key?(:'ssl_status')
    self.ssl_status = attributes[:'ssl_status']
  end

  if attributes.key?(:'ownership_verification')
    self.ownership_verification = attributes[:'ownership_verification']
  end

  if attributes.key?(:'ssl_validation_records')
    if (value = attributes[:'ssl_validation_records']).is_a?(Array)
      self.ssl_validation_records = value
    end
  end

  if attributes.key?(:'last_error')
    self.last_error = attributes[:'last_error']
  end

  if attributes.key?(:'instructions')
    self.instructions = attributes[:'instructions']
  end
end

Instance Attribute Details

#custom_hostname_idObject

Returns the value of attribute custom_hostname_id.



25
26
27
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 25

def custom_hostname_id
  @custom_hostname_id
end

#hostname_statusObject

Returns the value of attribute hostname_status.



27
28
29
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 27

def hostname_status
  @hostname_status
end

#instructionsObject

Returns the value of attribute instructions.



37
38
39
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 37

def instructions
  @instructions
end

#last_errorObject

Returns the value of attribute last_error.



35
36
37
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 35

def last_error
  @last_error
end

#ownership_verificationObject

Returns the value of attribute ownership_verification.



31
32
33
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 31

def ownership_verification
  @ownership_verification
end

#reasonObject

Returns the value of attribute reason.



23
24
25
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 23

def reason
  @reason
end

#saas_integration_enabledObject

Returns the value of attribute saas_integration_enabled.



19
20
21
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 19

def saas_integration_enabled
  @saas_integration_enabled
end

#skippedObject

Returns the value of attribute skipped.



21
22
23
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 21

def skipped
  @skipped
end

#ssl_statusObject

Returns the value of attribute ssl_status.



29
30
31
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 29

def ssl_status
  @ssl_status
end

#ssl_validation_recordsObject

Returns the value of attribute ssl_validation_records.



33
34
35
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 33

def ssl_validation_records
  @ssl_validation_records
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 40

def self.attribute_map
  {
    :'saas_integration_enabled' => :'saasIntegrationEnabled',
    :'skipped' => :'skipped',
    :'reason' => :'reason',
    :'custom_hostname_id' => :'customHostnameId',
    :'hostname_status' => :'hostnameStatus',
    :'ssl_status' => :'sslStatus',
    :'ownership_verification' => :'ownershipVerification',
    :'ssl_validation_records' => :'sslValidationRecords',
    :'last_error' => :'lastError',
    :'instructions' => :'instructions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
91
92
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 82

def self.openapi_nullable
  Set.new([
    :'reason',
    :'custom_hostname_id',
    :'hostname_status',
    :'ssl_status',
    :'ownership_verification',
    :'last_error',
    :'instructions'
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 66

def self.openapi_types
  {
    :'saas_integration_enabled' => :'Boolean',
    :'skipped' => :'Boolean',
    :'reason' => :'String',
    :'custom_hostname_id' => :'String',
    :'hostname_status' => :'String',
    :'ssl_status' => :'String',
    :'ownership_verification' => :'OrgCloudflareEdgeHintsOwnershipVerification',
    :'ssl_validation_records' => :'Array<OrgCloudflareSslValidationRecord>',
    :'last_error' => :'String',
    :'instructions' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      saas_integration_enabled == o.saas_integration_enabled &&
      skipped == o.skipped &&
      reason == o.reason &&
      custom_hostname_id == o.custom_hostname_id &&
      hostname_status == o.hostname_status &&
      ssl_status == o.ssl_status &&
      ownership_verification == o.ownership_verification &&
      ssl_validation_records == o.ssl_validation_records &&
      last_error == o.last_error &&
      instructions == o.instructions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 193

def hash
  [saas_integration_enabled, skipped, reason, custom_hostname_id, hostname_status, ssl_status, ownership_verification, ssl_validation_records, last_error, instructions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
# File 'lib/mudbase/models/org_cloudflare_edge_hints.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end