Class: Mudbase::OrgDomainEntryOrgConsole

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/org_domain_entry_org_console.rb

Overview

Org API compact domain row: use dnsRecords for the Mudbase ownership TXT (purpose mudbase_ownership) and routing CNAME. Omits hostnameNormalized, verificationToken, dnsTxtHost, and dnsTxtValue. Omits cloudflareEdge when Cloudflare SaaS is not configured. Optional keys with no value are omitted from JSON responses.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrgDomainEntryOrgConsole

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 156

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::OrgDomainEntryOrgConsole` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::OrgDomainEntryOrgConsole`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'is_primary')
    self.is_primary = attributes[:'is_primary']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  end

  if attributes.key?(:'last_verified_at')
    self.last_verified_at = attributes[:'last_verified_at']
  end

  if attributes.key?(:'cname_submitted_at')
    self. = attributes[:'cname_submitted_at']
  end

  if attributes.key?(:'cname_approved_at')
    self.cname_approved_at = attributes[:'cname_approved_at']
  end

  if attributes.key?(:'custom_domain_verification_step')
    self.custom_domain_verification_step = attributes[:'custom_domain_verification_step']
  end

  if attributes.key?(:'routing_cname_target')
    self.routing_cname_target = attributes[:'routing_cname_target']
  end

  if attributes.key?(:'dns_records')
    if (value = attributes[:'dns_records']).is_a?(Array)
      self.dns_records = value
    end
  end

  if attributes.key?(:'platform_activation_pending')
    self.platform_activation_pending = attributes[:'platform_activation_pending']
  end

  if attributes.key?(:'custom_domain_live_for_api_traffic')
    self.custom_domain_live_for_api_traffic = attributes[:'custom_domain_live_for_api_traffic']
  end

  if attributes.key?(:'cloudflare_edge')
    self.cloudflare_edge = attributes[:'cloudflare_edge']
  end

  if attributes.key?(:'fly_certificate_status')
    self.fly_certificate_status = attributes[:'fly_certificate_status']
  end

  if attributes.key?(:'platform_dns_verification')
    self.platform_dns_verification = attributes[:'platform_dns_verification']
  end

  if attributes.key?(:'platform_dns_verification_submitted_at')
    self. = attributes[:'platform_dns_verification_submitted_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



19
20
21
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 19

def _id
  @_id
end

#cloudflare_edgeObject

Returns the value of attribute cloudflare_edge.



49
50
51
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 49

def cloudflare_edge
  @cloudflare_edge
end

#cname_approved_atObject

Returns the value of attribute cname_approved_at.



37
38
39
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 37

def cname_approved_at
  @cname_approved_at
end

#cname_submitted_atObject

Returns the value of attribute cname_submitted_at.



35
36
37
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 35

def 
  @cname_submitted_at
end

#created_atObject

Returns the value of attribute created_at.



29
30
31
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 29

def created_at
  @created_at
end

#custom_domain_live_for_api_trafficObject

Returns the value of attribute custom_domain_live_for_api_traffic.



47
48
49
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 47

def custom_domain_live_for_api_traffic
  @custom_domain_live_for_api_traffic
end

#custom_domain_verification_stepObject

Returns the value of attribute custom_domain_verification_step.



39
40
41
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 39

def custom_domain_verification_step
  @custom_domain_verification_step
end

#dns_recordsObject

Returns the value of attribute dns_records.



43
44
45
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 43

def dns_records
  @dns_records
end

#fly_certificate_statusObject

Returns the value of attribute fly_certificate_status.



51
52
53
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 51

def fly_certificate_status
  @fly_certificate_status
end

#hostnameObject

Returns the value of attribute hostname.



21
22
23
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 21

def hostname
  @hostname
end

#is_primaryObject

Returns the value of attribute is_primary.



25
26
27
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 25

def is_primary
  @is_primary
end

#last_verified_atObject

Returns the value of attribute last_verified_at.



33
34
35
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 33

def last_verified_at
  @last_verified_at
end

#platform_activation_pendingObject

Returns the value of attribute platform_activation_pending.



45
46
47
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 45

def platform_activation_pending
  @platform_activation_pending
end

#platform_dns_verificationObject

Returns the value of attribute platform_dns_verification.



53
54
55
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 53

def platform_dns_verification
  @platform_dns_verification
end

#platform_dns_verification_submitted_atObject

Returns the value of attribute platform_dns_verification_submitted_at.



55
56
57
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 55

def 
  @platform_dns_verification_submitted_at
end

#routing_cname_targetObject

Returns the value of attribute routing_cname_target.



41
42
43
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 41

def routing_cname_target
  @routing_cname_target
end

#sourceObject

Returns the value of attribute source.



27
28
29
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 27

def source
  @source
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 23

def status
  @status
end

#verified_atObject

Returns the value of attribute verified_at.



31
32
33
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 31

def verified_at
  @verified_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



105
106
107
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 80

def self.attribute_map
  {
    :'_id' => :'_id',
    :'hostname' => :'hostname',
    :'status' => :'status',
    :'is_primary' => :'isPrimary',
    :'source' => :'source',
    :'created_at' => :'createdAt',
    :'verified_at' => :'verifiedAt',
    :'last_verified_at' => :'lastVerifiedAt',
    :'cname_submitted_at' => :'cnameSubmittedAt',
    :'cname_approved_at' => :'cnameApprovedAt',
    :'custom_domain_verification_step' => :'customDomainVerificationStep',
    :'routing_cname_target' => :'routingCnameTarget',
    :'dns_records' => :'dnsRecords',
    :'platform_activation_pending' => :'platformActivationPending',
    :'custom_domain_live_for_api_traffic' => :'customDomainLiveForApiTraffic',
    :'cloudflare_edge' => :'cloudflareEdge',
    :'fly_certificate_status' => :'flyCertificateStatus',
    :'platform_dns_verification' => :'platformDnsVerification',
    :'platform_dns_verification_submitted_at' => :'platformDnsVerificationSubmittedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 140

def self.openapi_nullable
  Set.new([
    :'verified_at',
    :'last_verified_at',
    :'cname_submitted_at',
    :'cname_approved_at',
    :'custom_domain_verification_step',
    :'routing_cname_target',
    :'fly_certificate_status',
    :'platform_dns_verification',
    :'platform_dns_verification_submitted_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 115

def self.openapi_types
  {
    :'_id' => :'String',
    :'hostname' => :'String',
    :'status' => :'String',
    :'is_primary' => :'Boolean',
    :'source' => :'String',
    :'created_at' => :'Time',
    :'verified_at' => :'Time',
    :'last_verified_at' => :'Time',
    :'cname_submitted_at' => :'Time',
    :'cname_approved_at' => :'Time',
    :'custom_domain_verification_step' => :'Integer',
    :'routing_cname_target' => :'String',
    :'dns_records' => :'Array<OrgDnsRecord>',
    :'platform_activation_pending' => :'Boolean',
    :'custom_domain_live_for_api_traffic' => :'Boolean',
    :'cloudflare_edge' => :'OrgCloudflareEdgeHints',
    :'fly_certificate_status' => :'String',
    :'platform_dns_verification' => :'OrgPlatformDnsVerificationCustomer',
    :'platform_dns_verification_submitted_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 278

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      hostname == o.hostname &&
      status == o.status &&
      is_primary == o.is_primary &&
      source == o.source &&
      created_at == o.created_at &&
      verified_at == o.verified_at &&
      last_verified_at == o.last_verified_at &&
       == o. &&
      cname_approved_at == o.cname_approved_at &&
      custom_domain_verification_step == o.custom_domain_verification_step &&
      routing_cname_target == o.routing_cname_target &&
      dns_records == o.dns_records &&
      platform_activation_pending == o.platform_activation_pending &&
      custom_domain_live_for_api_traffic == o.custom_domain_live_for_api_traffic &&
      cloudflare_edge == o.cloudflare_edge &&
      fly_certificate_status == o.fly_certificate_status &&
      platform_dns_verification == o.platform_dns_verification &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 310

def hash
  [_id, hostname, status, is_primary, source, created_at, verified_at, last_verified_at, , cname_approved_at, custom_domain_verification_step, routing_cname_target, dns_records, platform_activation_pending, custom_domain_live_for_api_traffic, cloudflare_edge, fly_certificate_status, platform_dns_verification, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



251
252
253
254
255
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 251

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



259
260
261
262
263
264
# File 'lib/mudbase/models/org_domain_entry_org_console.rb', line 259

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  source_validator = EnumAttributeValidator.new('String', ["manual", "api", "imported"])
  return false unless source_validator.valid?(@source)
  true
end