Class: Mudbase::ProjectFeesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/mudbase/api/project_fees_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ProjectFeesApi

Returns a new instance of ProjectFeesApi.



19
20
21
# File 'lib/mudbase/api/project_fees_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/mudbase/api/project_fees_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#confirm_address_verification(project_id, currency, confirm_address_verification_request, opts = {}) ⇒ ConfirmAddressVerification200Response

Confirm address verification (deprecated) Confirm address verification by providing the transaction hash of the test transaction sent to the payout address. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • confirm_address_verification_request (ConfirmAddressVerificationRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



29
30
31
32
# File 'lib/mudbase/api/project_fees_api.rb', line 29

def confirm_address_verification(project_id, currency, confirm_address_verification_request, opts = {})
  data, _status_code, _headers = confirm_address_verification_with_http_info(project_id, currency, confirm_address_verification_request, opts)
  data
end

#confirm_address_verification_with_http_info(project_id, currency, confirm_address_verification_request, opts = {}) ⇒ Array<(ConfirmAddressVerification200Response, Integer, Hash)>

Confirm address verification (deprecated) Confirm address verification by providing the transaction hash of the test transaction sent to the payout address. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • confirm_address_verification_request (ConfirmAddressVerificationRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mudbase/api/project_fees_api.rb', line 41

def confirm_address_verification_with_http_info(project_id, currency, confirm_address_verification_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.confirm_address_verification ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.confirm_address_verification"
  end
  # verify the required parameter 'currency' is set
  if @api_client.config.client_side_validation && currency.nil?
    fail ArgumentError, "Missing the required parameter 'currency' when calling ProjectFeesApi.confirm_address_verification"
  end
  # verify the required parameter 'confirm_address_verification_request' is set
  if @api_client.config.client_side_validation && confirm_address_verification_request.nil?
    fail ArgumentError, "Missing the required parameter 'confirm_address_verification_request' when calling ProjectFeesApi.confirm_address_verification"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-settings/{currency}/confirm-verification'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'currency' + '}', CGI.escape(currency.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(confirm_address_verification_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ConfirmAddressVerification200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.confirm_address_verification",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#confirm_address_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_or_update_fee_settings(project_id, create_or_update_fee_settings_request, opts = {}) ⇒ ApplyRoleFeaturePreset200Response

Create or update project fee settings (deprecated) Create or update fee settings for a project. Configure transaction fees, payout addresses, and thresholds for supported cryptocurrencies. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

Returns:



108
109
110
111
# File 'lib/mudbase/api/project_fees_api.rb', line 108

def create_or_update_fee_settings(project_id, create_or_update_fee_settings_request, opts = {})
  data, _status_code, _headers = create_or_update_fee_settings_with_http_info(project_id, create_or_update_fee_settings_request, opts)
  data
end

#create_or_update_fee_settings_with_http_info(project_id, create_or_update_fee_settings_request, opts = {}) ⇒ Array<(ApplyRoleFeaturePreset200Response, Integer, Hash)>

Create or update project fee settings (deprecated) Create or update fee settings for a project. Configure transaction fees, payout addresses, and thresholds for supported cryptocurrencies. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

Returns:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/mudbase/api/project_fees_api.rb', line 119

def create_or_update_fee_settings_with_http_info(project_id, create_or_update_fee_settings_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.create_or_update_fee_settings ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.create_or_update_fee_settings"
  end
  # verify the required parameter 'create_or_update_fee_settings_request' is set
  if @api_client.config.client_side_validation && create_or_update_fee_settings_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_or_update_fee_settings_request' when calling ProjectFeesApi.create_or_update_fee_settings"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-settings'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_or_update_fee_settings_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplyRoleFeaturePreset200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.create_or_update_fee_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#create_or_update_fee_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_currency_fee_balance(project_id, currency, opts = {}) ⇒ GetCurrencyFeeBalance200Response

Get currency fee balance (deprecated) Get fee balance for a specific cryptocurrency in a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



182
183
184
185
# File 'lib/mudbase/api/project_fees_api.rb', line 182

def get_currency_fee_balance(project_id, currency, opts = {})
  data, _status_code, _headers = get_currency_fee_balance_with_http_info(project_id, currency, opts)
  data
end

#get_currency_fee_balance_with_http_info(project_id, currency, opts = {}) ⇒ Array<(GetCurrencyFeeBalance200Response, Integer, Hash)>

Get currency fee balance (deprecated) Get fee balance for a specific cryptocurrency in a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/mudbase/api/project_fees_api.rb', line 193

def get_currency_fee_balance_with_http_info(project_id, currency, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.get_currency_fee_balance ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.get_currency_fee_balance"
  end
  # verify the required parameter 'currency' is set
  if @api_client.config.client_side_validation && currency.nil?
    fail ArgumentError, "Missing the required parameter 'currency' when calling ProjectFeesApi.get_currency_fee_balance"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-balances/{currency}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'currency' + '}', CGI.escape(currency.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetCurrencyFeeBalance200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.get_currency_fee_balance",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#get_currency_fee_balance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_fee_balances(project_id, opts = {}) ⇒ GetFeeBalances200Response

Get all fee balances (deprecated) Get fee balances for all currencies in a project, including collected amounts, thresholds, and payout status. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



250
251
252
253
# File 'lib/mudbase/api/project_fees_api.rb', line 250

def get_fee_balances(project_id, opts = {})
  data, _status_code, _headers = get_fee_balances_with_http_info(project_id, opts)
  data
end

#get_fee_balances_with_http_info(project_id, opts = {}) ⇒ Array<(GetFeeBalances200Response, Integer, Hash)>

Get all fee balances (deprecated) Get fee balances for all currencies in a project, including collected amounts, thresholds, and payout status. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetFeeBalances200Response, Integer, Hash)>)

    GetFeeBalances200Response data, response status code and response headers



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/mudbase/api/project_fees_api.rb', line 260

def get_fee_balances_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.get_fee_balances ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.get_fee_balances"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-balances'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetFeeBalances200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.get_fee_balances",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#get_fee_balances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_fee_settings(project_id, opts = {}) ⇒ TestWalletWebhook200Response

Get project fee settings (deprecated) Get all fee settings configured for a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



313
314
315
316
# File 'lib/mudbase/api/project_fees_api.rb', line 313

def get_fee_settings(project_id, opts = {})
  data, _status_code, _headers = get_fee_settings_with_http_info(project_id, opts)
  data
end

#get_fee_settings_with_http_info(project_id, opts = {}) ⇒ Array<(TestWalletWebhook200Response, Integer, Hash)>

Get project fee settings (deprecated) Get all fee settings configured for a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/mudbase/api/project_fees_api.rb', line 323

def get_fee_settings_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.get_fee_settings ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.get_fee_settings"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-settings'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TestWalletWebhook200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.get_fee_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#get_fee_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_payout_history(project_id, opts = {}) ⇒ GetPayoutHistory200Response

Get payout history (deprecated) Get historical payout records for a project with pagination. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer) — default: default to 20
  • :page (Integer) — default: default to 1
  • :currency (String)
  • :status (String)

Returns:



380
381
382
383
# File 'lib/mudbase/api/project_fees_api.rb', line 380

def get_payout_history(project_id, opts = {})
  data, _status_code, _headers = get_payout_history_with_http_info(project_id, opts)
  data
end

#get_payout_history_with_http_info(project_id, opts = {}) ⇒ Array<(GetPayoutHistory200Response, Integer, Hash)>

Get payout history (deprecated) Get historical payout records for a project with pagination. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer) — default: default to 20
  • :page (Integer) — default: default to 1
  • :currency (String)
  • :status (String)

Returns:

  • (Array<(GetPayoutHistory200Response, Integer, Hash)>)

    GetPayoutHistory200Response data, response status code and response headers



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/mudbase/api/project_fees_api.rb', line 394

def get_payout_history_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.get_payout_history ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.get_payout_history"
  end
  allowable_values = ["scheduled", "processing", "completed", "failed", "requires_attention"]
  if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status'])
    fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/payout-history'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'currency'] = opts[:'currency'] if !opts[:'currency'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetPayoutHistory200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.get_payout_history",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#get_payout_history\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_project_fee_dashboard(project_id, opts = {}) ⇒ GetProjectFeeDashboard200Response

Get fee dashboard (deprecated)

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



454
455
456
457
# File 'lib/mudbase/api/project_fees_api.rb', line 454

def get_project_fee_dashboard(project_id, opts = {})
  data, _status_code, _headers = get_project_fee_dashboard_with_http_info(project_id, opts)
  data
end

#get_project_fee_dashboard_with_http_info(project_id, opts = {}) ⇒ Array<(GetProjectFeeDashboard200Response, Integer, Hash)>

Get fee dashboard (deprecated)

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/mudbase/api/project_fees_api.rb', line 463

def get_project_fee_dashboard_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.get_project_fee_dashboard ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.get_project_fee_dashboard"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-dashboard'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetProjectFeeDashboard200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.get_project_fee_dashboard",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#get_project_fee_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#initiate_address_verification(project_id, currency, opts = {}) ⇒ InitiateAddressVerification200Response

Initiate address verification (deprecated) Initiate verification process for a payout address. Requires sending a small test transaction to verify ownership. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



517
518
519
520
# File 'lib/mudbase/api/project_fees_api.rb', line 517

def initiate_address_verification(project_id, currency, opts = {})
  data, _status_code, _headers = initiate_address_verification_with_http_info(project_id, currency, opts)
  data
end

#initiate_address_verification_with_http_info(project_id, currency, opts = {}) ⇒ Array<(InitiateAddressVerification200Response, Integer, Hash)>

Initiate address verification (deprecated) Initiate verification process for a payout address. Requires sending a small test transaction to verify ownership. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
# File 'lib/mudbase/api/project_fees_api.rb', line 528

def initiate_address_verification_with_http_info(project_id, currency, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.initiate_address_verification ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.initiate_address_verification"
  end
  # verify the required parameter 'currency' is set
  if @api_client.config.client_side_validation && currency.nil?
    fail ArgumentError, "Missing the required parameter 'currency' when calling ProjectFeesApi.initiate_address_verification"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-settings/{currency}/verify-address'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'currency' + '}', CGI.escape(currency.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InitiateAddressVerification200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.initiate_address_verification",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#initiate_address_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#request_manual_payout(project_id, request_manual_payout_request, opts = {}) ⇒ ApplyRoleFeaturePreset200Response

Request manual payout (deprecated) Request a manual payout for collected fees. Requires sufficient balance above the threshold. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • request_manual_payout_request (RequestManualPayoutRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



586
587
588
589
# File 'lib/mudbase/api/project_fees_api.rb', line 586

def request_manual_payout(project_id, request_manual_payout_request, opts = {})
  data, _status_code, _headers = request_manual_payout_with_http_info(project_id, request_manual_payout_request, opts)
  data
end

#request_manual_payout_with_http_info(project_id, request_manual_payout_request, opts = {}) ⇒ Array<(ApplyRoleFeaturePreset200Response, Integer, Hash)>

Request manual payout (deprecated) Request a manual payout for collected fees. Requires sufficient balance above the threshold. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • request_manual_payout_request (RequestManualPayoutRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
# File 'lib/mudbase/api/project_fees_api.rb', line 597

def request_manual_payout_with_http_info(project_id, request_manual_payout_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.request_manual_payout ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.request_manual_payout"
  end
  # verify the required parameter 'request_manual_payout_request' is set
  if @api_client.config.client_side_validation && request_manual_payout_request.nil?
    fail ArgumentError, "Missing the required parameter 'request_manual_payout_request' when calling ProjectFeesApi.request_manual_payout"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/payouts/request-manual'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request_manual_payout_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplyRoleFeaturePreset200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.request_manual_payout",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#request_manual_payout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_currency_fee_settings(project_id, currency, update_currency_fee_settings_request, opts = {}) ⇒ ApplyRoleFeaturePreset200Response

Update currency fee settings (deprecated) Update fee settings for a specific cryptocurrency in a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • update_currency_fee_settings_request (UpdateCurrencyFeeSettingsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



661
662
663
664
# File 'lib/mudbase/api/project_fees_api.rb', line 661

def update_currency_fee_settings(project_id, currency, update_currency_fee_settings_request, opts = {})
  data, _status_code, _headers = update_currency_fee_settings_with_http_info(project_id, currency, update_currency_fee_settings_request, opts)
  data
end

#update_currency_fee_settings_with_http_info(project_id, currency, update_currency_fee_settings_request, opts = {}) ⇒ Array<(ApplyRoleFeaturePreset200Response, Integer, Hash)>

Update currency fee settings (deprecated) Update fee settings for a specific cryptocurrency in a project. Accepts: OrgBearerAuth (for admin users), ProjectBearerAuth (JWT for authenticated users), or ApiKeyAuth (X-API-Key for programmatic access). Both ProjectBearerAuth and ApiKeyAuth are fully implemented.

Parameters:

  • project_id (String)
  • currency (String)
  • update_currency_fee_settings_request (UpdateCurrencyFeeSettingsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/mudbase/api/project_fees_api.rb', line 673

def update_currency_fee_settings_with_http_info(project_id, currency, update_currency_fee_settings_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProjectFeesApi.update_currency_fee_settings ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling ProjectFeesApi.update_currency_fee_settings"
  end
  # verify the required parameter 'currency' is set
  if @api_client.config.client_side_validation && currency.nil?
    fail ArgumentError, "Missing the required parameter 'currency' when calling ProjectFeesApi.update_currency_fee_settings"
  end
  # verify enum value
  allowable_values = ["BTC", "ETH", "BNB", "LTC", "SOL", "TRX", "USDT-ETH", "USDT-BSC", "USDT-TRX", "USDT-SOL"]
  if @api_client.config.client_side_validation && !allowable_values.include?(currency)
    fail ArgumentError, "invalid value for \"currency\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'update_currency_fee_settings_request' is set
  if @api_client.config.client_side_validation && update_currency_fee_settings_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_currency_fee_settings_request' when calling ProjectFeesApi.update_currency_fee_settings"
  end
  # resource path
  local_var_path = '/api/projects/{projectId}/fee-settings/{currency}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'currency' + '}', CGI.escape(currency.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_currency_fee_settings_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplyRoleFeaturePreset200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OrgBearerAuth', 'ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"ProjectFeesApi.update_currency_fee_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProjectFeesApi#update_currency_fee_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end