Class: Mudbase::ProjectSettings

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/project_settings.rb

Overview

Project-level settings. Toggles for verification and default user status apply to app and role-based signup.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/mudbase/models/project_settings.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ProjectSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ProjectSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_anonymous_auth')
    self.allow_anonymous_auth = attributes[:'allow_anonymous_auth']
  else
    self.allow_anonymous_auth = true
  end

  if attributes.key?(:'require_email_verification')
    self.require_email_verification = attributes[:'require_email_verification']
  else
    self.require_email_verification = true
  end

  if attributes.key?(:'require_phone_verification')
    self.require_phone_verification = attributes[:'require_phone_verification']
  else
    self.require_phone_verification = false
  end

  if attributes.key?(:'default_user_account_status')
    self. = attributes[:'default_user_account_status']
  else
    self. = 'active'
  end

  if attributes.key?(:'enable_realtime')
    self.enable_realtime = attributes[:'enable_realtime']
  else
    self.enable_realtime = true
  end

  if attributes.key?(:'enable_storage')
    self.enable_storage = attributes[:'enable_storage']
  else
    self.enable_storage = true
  end

  if attributes.key?(:'enable_functions')
    self.enable_functions = attributes[:'enable_functions']
  else
    self.enable_functions = false
  end
end

Instance Attribute Details

#allow_anonymous_authObject

Allow anonymous (unauthenticated) users



20
21
22
# File 'lib/mudbase/models/project_settings.rb', line 20

def allow_anonymous_auth
  @allow_anonymous_auth
end

#default_user_account_statusObject

Default account status for new signups. active = user can use the app immediately. pending = user must be approved by an org owner/admin (PATCH org user status to active) before they can perform protected operations.



29
30
31
# File 'lib/mudbase/models/project_settings.rb', line 29

def 
  
end

#enable_functionsObject

Returns the value of attribute enable_functions.



35
36
37
# File 'lib/mudbase/models/project_settings.rb', line 35

def enable_functions
  @enable_functions
end

#enable_realtimeObject

Returns the value of attribute enable_realtime.



31
32
33
# File 'lib/mudbase/models/project_settings.rb', line 31

def enable_realtime
  @enable_realtime
end

#enable_storageObject

Returns the value of attribute enable_storage.



33
34
35
# File 'lib/mudbase/models/project_settings.rb', line 33

def enable_storage
  @enable_storage
end

#require_email_verificationObject

When true, users who sign up with email do not receive a token until they verify their email; login is blocked until verified.



23
24
25
# File 'lib/mudbase/models/project_settings.rb', line 23

def require_email_verification
  @require_email_verification
end

#require_phone_verificationObject

When true, users who sign in with phone (e.g. OTP) must have verified their phone before receiving a token.



26
27
28
# File 'lib/mudbase/models/project_settings.rb', line 26

def require_phone_verification
  @require_phone_verification
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/mudbase/models/project_settings.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/mudbase/models/project_settings.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mudbase/models/project_settings.rb', line 60

def self.attribute_map
  {
    :'allow_anonymous_auth' => :'allowAnonymousAuth',
    :'require_email_verification' => :'requireEmailVerification',
    :'require_phone_verification' => :'requirePhoneVerification',
    :'default_user_account_status' => :'defaultUserAccountStatus',
    :'enable_realtime' => :'enableRealtime',
    :'enable_storage' => :'enableStorage',
    :'enable_functions' => :'enableFunctions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/mudbase/models/project_settings.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/mudbase/models/project_settings.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
# File 'lib/mudbase/models/project_settings.rb', line 83

def self.openapi_types
  {
    :'allow_anonymous_auth' => :'Boolean',
    :'require_email_verification' => :'Boolean',
    :'require_phone_verification' => :'Boolean',
    :'default_user_account_status' => :'String',
    :'enable_realtime' => :'Boolean',
    :'enable_storage' => :'Boolean',
    :'enable_functions' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
# File 'lib/mudbase/models/project_settings.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_anonymous_auth == o.allow_anonymous_auth &&
      require_email_verification == o.require_email_verification &&
      require_phone_verification == o.require_phone_verification &&
       == o. &&
      enable_realtime == o.enable_realtime &&
      enable_storage == o.enable_storage &&
      enable_functions == o.enable_functions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/mudbase/models/project_settings.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/mudbase/models/project_settings.rb', line 209

def hash
  [allow_anonymous_auth, require_email_verification, require_phone_verification, , enable_realtime, enable_storage, enable_functions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
# File 'lib/mudbase/models/project_settings.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/mudbase/models/project_settings.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
# File 'lib/mudbase/models/project_settings.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
   = EnumAttributeValidator.new('String', ["pending", "active"])
  return false unless .valid?()
  true
end