Class: Mudbase::ProjectSmtpTestRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::ProjectSmtpTestRequest
- Defined in:
- lib/mudbase/models/project_smtp_test_request.rb
Instance Attribute Summary collapse
-
#auth_pass ⇒ Object
Returns the value of attribute auth_pass.
-
#auth_user ⇒ Object
Returns the value of attribute auth_user.
-
#from_email ⇒ Object
Returns the value of attribute from_email.
-
#from_name ⇒ Object
Returns the value of attribute from_name.
-
#host ⇒ Object
Returns the value of attribute host.
-
#port ⇒ Object
Returns the value of attribute port.
-
#secure ⇒ Object
Returns the value of attribute secure.
-
#to ⇒ Object
Recipient for verification and test message.
-
#use_saved ⇒ Object
When true, use saved SMTP config; otherwise supply host/auth fields below.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProjectSmtpTestRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProjectSmtpTestRequest
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::ProjectSmtpTestRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::ProjectSmtpTestRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'to') self.to = attributes[:'to'] else self.to = nil end if attributes.key?(:'use_saved') self.use_saved = attributes[:'use_saved'] else self.use_saved = true end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'secure') self.secure = attributes[:'secure'] end if attributes.key?(:'auth_user') self.auth_user = attributes[:'auth_user'] end if attributes.key?(:'auth_pass') self.auth_pass = attributes[:'auth_pass'] end if attributes.key?(:'from_email') self.from_email = attributes[:'from_email'] end if attributes.key?(:'from_name') self.from_name = attributes[:'from_name'] end end |
Instance Attribute Details
#auth_pass ⇒ Object
Returns the value of attribute auth_pass.
32 33 34 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 32 def auth_pass @auth_pass end |
#auth_user ⇒ Object
Returns the value of attribute auth_user.
30 31 32 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 30 def auth_user @auth_user end |
#from_email ⇒ Object
Returns the value of attribute from_email.
34 35 36 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 34 def from_email @from_email end |
#from_name ⇒ Object
Returns the value of attribute from_name.
36 37 38 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 36 def from_name @from_name end |
#host ⇒ Object
Returns the value of attribute host.
24 25 26 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 24 def host @host end |
#port ⇒ Object
Returns the value of attribute port.
26 27 28 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 26 def port @port end |
#secure ⇒ Object
Returns the value of attribute secure.
28 29 30 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 28 def secure @secure end |
#to ⇒ Object
Recipient for verification and test message
19 20 21 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 19 def to @to end |
#use_saved ⇒ Object
When true, use saved SMTP config; otherwise supply host/auth fields below
22 23 24 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 22 def use_saved @use_saved end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 39 def self.attribute_map { :'to' => :'to', :'use_saved' => :'useSaved', :'host' => :'host', :'port' => :'port', :'secure' => :'secure', :'auth_user' => :'authUser', :'auth_pass' => :'authPass', :'from_email' => :'fromEmail', :'from_name' => :'fromName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 202 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 64 def self.openapi_types { :'to' => :'String', :'use_saved' => :'Boolean', :'host' => :'String', :'port' => :'Integer', :'secure' => :'Boolean', :'auth_user' => :'String', :'auth_pass' => :'String', :'from_email' => :'String', :'from_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && to == o.to && use_saved == o.use_saved && host == o.host && port == o.port && secure == o.secure && auth_user == o.auth_user && auth_pass == o.auth_pass && from_email == o.from_email && from_name == o.from_name end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 195 def hash [to, use_saved, host, port, secure, auth_user, auth_pass, from_email, from_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 |
# File 'lib/mudbase/models/project_smtp_test_request.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @to.nil? true end |