Class: Mudbase::PushNotificationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::PushNotificationRequest
- Defined in:
- lib/mudbase/models/push_notification_request.rb
Overview
Push notification payload (tokens, title, body, data, imageUrl).
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#data ⇒ Object
Returns the value of attribute data.
-
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#title ⇒ Object
Returns the value of attribute title.
-
#tokens ⇒ Object
Returns the value of attribute tokens.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushNotificationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PushNotificationRequest
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/mudbase/models/push_notification_request.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::PushNotificationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::PushNotificationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tokens') if (value = attributes[:'tokens']).is_a?(Array) self.tokens = value end else self.tokens = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'data') self.data = attributes[:'data'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
23 24 25 |
# File 'lib/mudbase/models/push_notification_request.rb', line 23 def body @body end |
#data ⇒ Object
Returns the value of attribute data.
25 26 27 |
# File 'lib/mudbase/models/push_notification_request.rb', line 25 def data @data end |
#image_url ⇒ Object
Returns the value of attribute image_url.
27 28 29 |
# File 'lib/mudbase/models/push_notification_request.rb', line 27 def image_url @image_url end |
#title ⇒ Object
Returns the value of attribute title.
21 22 23 |
# File 'lib/mudbase/models/push_notification_request.rb', line 21 def title @title end |
#tokens ⇒ Object
Returns the value of attribute tokens.
19 20 21 |
# File 'lib/mudbase/models/push_notification_request.rb', line 19 def tokens @tokens end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/mudbase/models/push_notification_request.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/mudbase/models/push_notification_request.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/mudbase/models/push_notification_request.rb', line 30 def self.attribute_map { :'tokens' => :'tokens', :'title' => :'title', :'body' => :'body', :'data' => :'data', :'image_url' => :'imageUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/mudbase/models/push_notification_request.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/mudbase/models/push_notification_request.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/mudbase/models/push_notification_request.rb', line 51 def self.openapi_types { :'tokens' => :'Array<String>', :'title' => :'String', :'body' => :'String', :'data' => :'Object', :'image_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 |
# File 'lib/mudbase/models/push_notification_request.rb', line 174 def ==(o) return true if self.equal?(o) self.class == o.class && tokens == o.tokens && title == o.title && body == o.body && data == o.data && image_url == o.image_url end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/mudbase/models/push_notification_request.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/mudbase/models/push_notification_request.rb', line 192 def hash [tokens, title, body, data, image_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/mudbase/models/push_notification_request.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tokens.nil? invalid_properties.push('invalid value for "tokens", tokens cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/mudbase/models/push_notification_request.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 140 |
# File 'lib/mudbase/models/push_notification_request.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tokens.nil? return false if @title.nil? return false if @body.nil? true end |