Class: Mudbase::RealTimeAnalyticsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/mudbase/api/real_time_analytics_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RealTimeAnalyticsApi

Returns a new instance of RealTimeAnalyticsApi.



19
20
21
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#check_user_presence(project_id, check_user_presence_request, opts = {}) ⇒ CheckUserPresence200Response

Check presence status for users Returns online status for specified user IDs

Parameters:

  • project_id (String)

    Project ID.

  • check_user_presence_request (CheckUserPresenceRequest)

    Array of user IDs to check presence for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 28

def check_user_presence(project_id, check_user_presence_request, opts = {})
  data, _status_code, _headers = check_user_presence_with_http_info(project_id, check_user_presence_request, opts)
  data
end

#check_user_presence_with_http_info(project_id, check_user_presence_request, opts = {}) ⇒ Array<(CheckUserPresence200Response, Integer, Hash)>

Check presence status for users Returns online status for specified user IDs

Parameters:

  • project_id (String)

    Project ID.

  • check_user_presence_request (CheckUserPresenceRequest)

    Array of user IDs to check presence for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 39

def check_user_presence_with_http_info(project_id, check_user_presence_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RealTimeAnalyticsApi.check_user_presence ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling RealTimeAnalyticsApi.check_user_presence"
  end
  # verify the required parameter 'check_user_presence_request' is set
  if @api_client.config.client_side_validation && check_user_presence_request.nil?
    fail ArgumentError, "Missing the required parameter 'check_user_presence_request' when calling RealTimeAnalyticsApi.check_user_presence"
  end
  # resource path
  local_var_path = '/api/realtime/projects/{projectId}/presence'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(check_user_presence_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CheckUserPresence200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"RealTimeAnalyticsApi.check_user_presence",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RealTimeAnalyticsApi#check_user_presence\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_active_users(project_id, opts = {}) ⇒ GetActiveUsers200Response

Get active users for a project Returns list of currently connected users

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



101
102
103
104
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 101

def get_active_users(project_id, opts = {})
  data, _status_code, _headers = get_active_users_with_http_info(project_id, opts)
  data
end

#get_active_users_with_http_info(project_id, opts = {}) ⇒ Array<(GetActiveUsers200Response, Integer, Hash)>

Get active users for a project Returns list of currently connected users

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetActiveUsers200Response, Integer, Hash)>)

    GetActiveUsers200Response data, response status code and response headers



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 111

def get_active_users_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RealTimeAnalyticsApi.get_active_users ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling RealTimeAnalyticsApi.get_active_users"
  end
  # resource path
  local_var_path = '/api/realtime/projects/{projectId}/active-users'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetActiveUsers200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"RealTimeAnalyticsApi.get_active_users",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RealTimeAnalyticsApi#get_active_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_event_throughput(project_id, opts = {}) ⇒ GetEventThroughput200Response

Get event throughput metrics Returns event throughput for a project

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :window (Integer)

    Time window in milliseconds (default to 60000)

Returns:



165
166
167
168
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 165

def get_event_throughput(project_id, opts = {})
  data, _status_code, _headers = get_event_throughput_with_http_info(project_id, opts)
  data
end

#get_event_throughput_with_http_info(project_id, opts = {}) ⇒ Array<(GetEventThroughput200Response, Integer, Hash)>

Get event throughput metrics Returns event throughput for a project

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :window (Integer)

    Time window in milliseconds (default to 60000)

Returns:



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 176

def get_event_throughput_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RealTimeAnalyticsApi.get_event_throughput ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling RealTimeAnalyticsApi.get_event_throughput"
  end
  # resource path
  local_var_path = '/api/realtime/projects/{projectId}/throughput'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'window'] = opts[:'window'] if !opts[:'window'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetEventThroughput200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"RealTimeAnalyticsApi.get_event_throughput",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RealTimeAnalyticsApi#get_event_throughput\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_historical_analytics(project_id, opts = {}) ⇒ GetHistoricalAnalytics200Response

Get historical analytics Returns historical analytics for charting

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :period (String)

    Time period for historical data (default to ‘hour’)

Returns:



231
232
233
234
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 231

def get_historical_analytics(project_id, opts = {})
  data, _status_code, _headers = get_historical_analytics_with_http_info(project_id, opts)
  data
end

#get_historical_analytics_with_http_info(project_id, opts = {}) ⇒ Array<(GetHistoricalAnalytics200Response, Integer, Hash)>

Get historical analytics Returns historical analytics for charting

Parameters:

  • project_id (String)

    Project ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :period (String)

    Time period for historical data (default to ‘hour’)

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 242

def get_historical_analytics_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RealTimeAnalyticsApi.get_historical_analytics ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling RealTimeAnalyticsApi.get_historical_analytics"
  end
  allowable_values = ["hour", "day", "week"]
  if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period'])
    fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/realtime/projects/{projectId}/history'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetHistoricalAnalytics200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"RealTimeAnalyticsApi.get_historical_analytics",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RealTimeAnalyticsApi#get_historical_analytics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_project_analytics(project_id, opts = {}) ⇒ GetProjectAnalytics200Response

Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.)

Parameters:

  • project_id (String)

    Project ID (MongoDB ObjectId) to get real-time analytics for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



300
301
302
303
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 300

def get_project_analytics(project_id, opts = {})
  data, _status_code, _headers = get_project_analytics_with_http_info(project_id, opts)
  data
end

#get_project_analytics_with_http_info(project_id, opts = {}) ⇒ Array<(GetProjectAnalytics200Response, Integer, Hash)>

Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.)

Parameters:

  • project_id (String)

    Project ID (MongoDB ObjectId) to get real-time analytics for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/mudbase/api/real_time_analytics_api.rb', line 310

def get_project_analytics_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RealTimeAnalyticsApi.get_project_analytics ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling RealTimeAnalyticsApi.get_project_analytics"
  end
  # resource path
  local_var_path = '/api/realtime/projects/{projectId}/analytics'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetProjectAnalytics200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ProjectBearerAuth']

  new_options = opts.merge(
    :operation => :"RealTimeAnalyticsApi.get_project_analytics",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RealTimeAnalyticsApi#get_project_analytics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end