Class: Mudbase::RealtimeAnalyticsApi
- Inherits:
-
Object
- Object
- Mudbase::RealtimeAnalyticsApi
- Defined in:
- lib/mudbase/api/realtime_analytics_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RealtimeAnalyticsApi
constructor
A new instance of RealtimeAnalyticsApi.
-
#realtime_analytics_check_user_presence(project_id, realtime_analytics_check_user_presence_request, opts = {}) ⇒ RealtimeAnalyticsCheckUserPresence200Response
Check presence status for users Returns online status for specified user IDs.
-
#realtime_analytics_check_user_presence_with_http_info(project_id, realtime_analytics_check_user_presence_request, opts = {}) ⇒ Array<(RealtimeAnalyticsCheckUserPresence200Response, Integer, Hash)>
Check presence status for users Returns online status for specified user IDs.
-
#realtime_analytics_get_active_users(project_id, opts = {}) ⇒ RealtimeAnalyticsGetActiveUsers200Response
Get active users for a project Returns list of currently connected users.
-
#realtime_analytics_get_active_users_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetActiveUsers200Response, Integer, Hash)>
Get active users for a project Returns list of currently connected users.
-
#realtime_analytics_get_event_throughput(project_id, opts = {}) ⇒ RealtimeAnalyticsGetEventThroughput200Response
Get event throughput metrics Returns event throughput for a project.
-
#realtime_analytics_get_event_throughput_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetEventThroughput200Response, Integer, Hash)>
Get event throughput metrics Returns event throughput for a project.
-
#realtime_analytics_get_historical_analytics(project_id, opts = {}) ⇒ RealtimeAnalyticsGetHistoricalAnalytics200Response
Get historical analytics Returns historical analytics for charting.
-
#realtime_analytics_get_historical_analytics_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetHistoricalAnalytics200Response, Integer, Hash)>
Get historical analytics Returns historical analytics for charting.
-
#realtime_analytics_get_project(project_id, opts = {}) ⇒ RealtimeAnalyticsGetProject200Response
Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.).
-
#realtime_analytics_get_project_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetProject200Response, Integer, Hash)>
Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RealtimeAnalyticsApi
Returns a new instance of RealtimeAnalyticsApi.
19 20 21 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#realtime_analytics_check_user_presence(project_id, realtime_analytics_check_user_presence_request, opts = {}) ⇒ RealtimeAnalyticsCheckUserPresence200Response
Check presence status for users Returns online status for specified user IDs
28 29 30 31 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 28 def realtime_analytics_check_user_presence(project_id, realtime_analytics_check_user_presence_request, opts = {}) data, _status_code, _headers = realtime_analytics_check_user_presence_with_http_info(project_id, realtime_analytics_check_user_presence_request, opts) data end |
#realtime_analytics_check_user_presence_with_http_info(project_id, realtime_analytics_check_user_presence_request, opts = {}) ⇒ Array<(RealtimeAnalyticsCheckUserPresence200Response, Integer, Hash)>
Check presence status for users Returns online status for specified user IDs
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 39 def realtime_analytics_check_user_presence_with_http_info(project_id, realtime_analytics_check_user_presence_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeAnalyticsApi.realtime_analytics_check_user_presence ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling RealtimeAnalyticsApi.realtime_analytics_check_user_presence" end # verify the required parameter 'realtime_analytics_check_user_presence_request' is set if @api_client.config.client_side_validation && realtime_analytics_check_user_presence_request.nil? fail ArgumentError, "Missing the required parameter 'realtime_analytics_check_user_presence_request' when calling RealtimeAnalyticsApi.realtime_analytics_check_user_presence" end # resource path local_var_path = '/api/realtime/projects/{projectId}/presence'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(realtime_analytics_check_user_presence_request) # return_type return_type = opts[:debug_return_type] || 'RealtimeAnalyticsCheckUserPresence200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"RealtimeAnalyticsApi.realtime_analytics_check_user_presence", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeAnalyticsApi#realtime_analytics_check_user_presence\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#realtime_analytics_get_active_users(project_id, opts = {}) ⇒ RealtimeAnalyticsGetActiveUsers200Response
Get active users for a project Returns list of currently connected users
101 102 103 104 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 101 def realtime_analytics_get_active_users(project_id, opts = {}) data, _status_code, _headers = realtime_analytics_get_active_users_with_http_info(project_id, opts) data end |
#realtime_analytics_get_active_users_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetActiveUsers200Response, Integer, Hash)>
Get active users for a project Returns list of currently connected users
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 111 def realtime_analytics_get_active_users_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeAnalyticsApi.realtime_analytics_get_active_users ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling RealtimeAnalyticsApi.realtime_analytics_get_active_users" end # resource path local_var_path = '/api/realtime/projects/{projectId}/active-users'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RealtimeAnalyticsGetActiveUsers200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"RealtimeAnalyticsApi.realtime_analytics_get_active_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeAnalyticsApi#realtime_analytics_get_active_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#realtime_analytics_get_event_throughput(project_id, opts = {}) ⇒ RealtimeAnalyticsGetEventThroughput200Response
Get event throughput metrics Returns event throughput for a project
165 166 167 168 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 165 def realtime_analytics_get_event_throughput(project_id, opts = {}) data, _status_code, _headers = realtime_analytics_get_event_throughput_with_http_info(project_id, opts) data end |
#realtime_analytics_get_event_throughput_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetEventThroughput200Response, Integer, Hash)>
Get event throughput metrics Returns event throughput for a project
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 176 def realtime_analytics_get_event_throughput_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeAnalyticsApi.realtime_analytics_get_event_throughput ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling RealtimeAnalyticsApi.realtime_analytics_get_event_throughput" end # resource path local_var_path = '/api/realtime/projects/{projectId}/throughput'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'window'] = opts[:'window'] if !opts[:'window'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RealtimeAnalyticsGetEventThroughput200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"RealtimeAnalyticsApi.realtime_analytics_get_event_throughput", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeAnalyticsApi#realtime_analytics_get_event_throughput\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#realtime_analytics_get_historical_analytics(project_id, opts = {}) ⇒ RealtimeAnalyticsGetHistoricalAnalytics200Response
Get historical analytics Returns historical analytics for charting
231 232 233 234 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 231 def realtime_analytics_get_historical_analytics(project_id, opts = {}) data, _status_code, _headers = realtime_analytics_get_historical_analytics_with_http_info(project_id, opts) data end |
#realtime_analytics_get_historical_analytics_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetHistoricalAnalytics200Response, Integer, Hash)>
Get historical analytics Returns historical analytics for charting
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 242 def realtime_analytics_get_historical_analytics_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeAnalyticsApi.realtime_analytics_get_historical_analytics ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling RealtimeAnalyticsApi.realtime_analytics_get_historical_analytics" end allowable_values = ["hour", "day", "week"] if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period']) fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/realtime/projects/{projectId}/history'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RealtimeAnalyticsGetHistoricalAnalytics200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"RealtimeAnalyticsApi.realtime_analytics_get_historical_analytics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeAnalyticsApi#realtime_analytics_get_historical_analytics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#realtime_analytics_get_project(project_id, opts = {}) ⇒ RealtimeAnalyticsGetProject200Response
Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.)
300 301 302 303 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 300 def realtime_analytics_get_project(project_id, opts = {}) data, _status_code, _headers = realtime_analytics_get_project_with_http_info(project_id, opts) data end |
#realtime_analytics_get_project_with_http_info(project_id, opts = {}) ⇒ Array<(RealtimeAnalyticsGetProject200Response, Integer, Hash)>
Get project real-time analytics Returns real-time metrics for a specific project (active connections, events, etc.)
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/mudbase/api/realtime_analytics_api.rb', line 310 def realtime_analytics_get_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeAnalyticsApi.realtime_analytics_get_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling RealtimeAnalyticsApi.realtime_analytics_get_project" end # resource path local_var_path = '/api/realtime/projects/{projectId}/analytics'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RealtimeAnalyticsGetProject200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"RealtimeAnalyticsApi.realtime_analytics_get_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeAnalyticsApi#realtime_analytics_get_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |