Class: Mudbase::RestoreBackupRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::RestoreBackupRequest
- Defined in:
- lib/mudbase/models/restore_backup_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#collections ⇒ Object
Optional: specific collections to restore.
-
#confirmation ⇒ Object
Returns the value of attribute confirmation.
-
#restore_mode ⇒ Object
Returns the value of attribute restore_mode.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RestoreBackupRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RestoreBackupRequest
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::RestoreBackupRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::RestoreBackupRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'restore_mode') self.restore_mode = attributes[:'restore_mode'] end if attributes.key?(:'collections') if (value = attributes[:'collections']).is_a?(Array) self.collections = value end end if attributes.key?(:'confirmation') self.confirmation = attributes[:'confirmation'] else self.confirmation = nil end end |
Instance Attribute Details
#collections ⇒ Object
Optional: specific collections to restore
21 22 23 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 21 def collections @collections end |
#confirmation ⇒ Object
Returns the value of attribute confirmation.
23 24 25 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 23 def confirmation @confirmation end |
#restore_mode ⇒ Object
Returns the value of attribute restore_mode.
18 19 20 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 18 def restore_mode @restore_mode end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 48 def self.attribute_map { :'restore_mode' => :'restoreMode', :'collections' => :'collections', :'confirmation' => :'confirmation' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 67 def self.openapi_types { :'restore_mode' => :'String', :'collections' => :'Array<String>', :'confirmation' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && restore_mode == o.restore_mode && collections == o.collections && confirmation == o.confirmation end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 176 def hash [restore_mode, collections, confirmation].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @confirmation.nil? invalid_properties.push('invalid value for "confirmation", confirmation cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 135 136 |
# File 'lib/mudbase/models/restore_backup_request.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' restore_mode_validator = EnumAttributeValidator.new('String', ["replace", "merge"]) return false unless restore_mode_validator.valid?(@restore_mode) return false if @confirmation.nil? confirmation_validator = EnumAttributeValidator.new('String', ["RESTORE_DATA"]) return false unless confirmation_validator.valid?(@confirmation) true end |