Class: Mudbase::StorageGetPresignedUploadRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/storage_get_presigned_upload_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StorageGetPresignedUploadRequest

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::StorageGetPresignedUploadRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::StorageGetPresignedUploadRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  else
    self.project_id = nil
  end

  if attributes.key?(:'bucket')
    self.bucket = attributes[:'bucket']
  else
    self.bucket = 'default'
  end

  if attributes.key?(:'original_name')
    self.original_name = attributes[:'original_name']
  else
    self.original_name = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  end

  if attributes.key?(:'is_public')
    self.is_public = attributes[:'is_public']
  else
    self.is_public = false
  end
end

Instance Attribute Details

#bucketObject

Returns the value of attribute bucket.



20
21
22
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 20

def bucket
  @bucket
end

#content_typeObject

Returns the value of attribute content_type.



24
25
26
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 24

def content_type
  @content_type
end

#is_publicObject

Returns the value of attribute is_public.



26
27
28
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 26

def is_public
  @is_public
end

#original_nameObject

Returns the value of attribute original_name.



22
23
24
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 22

def original_name
  @original_name
end

#project_idObject

Returns the value of attribute project_id.



18
19
20
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 18

def project_id
  @project_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 29

def self.attribute_map
  {
    :'project_id' => :'projectId',
    :'bucket' => :'bucket',
    :'original_name' => :'originalName',
    :'content_type' => :'contentType',
    :'is_public' => :'isPublic'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 50

def self.openapi_types
  {
    :'project_id' => :'String',
    :'bucket' => :'String',
    :'original_name' => :'String',
    :'content_type' => :'String',
    :'is_public' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



158
159
160
161
162
163
164
165
166
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      project_id == o.project_id &&
      bucket == o.bucket &&
      original_name == o.original_name &&
      content_type == o.content_type &&
      is_public == o.is_public
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


170
171
172
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



176
177
178
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 176

def hash
  [project_id, bucket, original_name, content_type, is_public].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if @original_name.nil?
    invalid_properties.push('invalid value for "original_name", original_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



129
130
131
132
133
134
# File 'lib/mudbase/models/storage_get_presigned_upload_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @project_id.nil?
  return false if @original_name.nil?
  true
end