Class: Mudbase::TriggerWebhookRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::TriggerWebhookRequest
- Defined in:
- lib/mudbase/models/trigger_webhook_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#event ⇒ Object
Event name (sent as X-MUDBASE-Event).
-
#method ⇒ Object
Returns the value of attribute method.
-
#payload ⇒ Object
JSON body POSTed to your endpoint.
-
#project_id ⇒ Object
Target project (must belong to your org).
-
#url ⇒ Object
HTTPS URL validated against SSRF rules.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TriggerWebhookRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TriggerWebhookRequest
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::TriggerWebhookRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::TriggerWebhookRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'event') self.event = attributes[:'event'] else self.event = nil end if attributes.key?(:'payload') self.payload = attributes[:'payload'] else self.payload = nil end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = 'POST' end end |
Instance Attribute Details
#event ⇒ Object
Event name (sent as X-MUDBASE-Event)
25 26 27 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 25 def event @event end |
#method ⇒ Object
Returns the value of attribute method.
30 31 32 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 30 def method @method end |
#payload ⇒ Object
JSON body POSTed to your endpoint
28 29 30 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 28 def payload @payload end |
#project_id ⇒ Object
Target project (must belong to your org)
19 20 21 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 19 def project_id @project_id end |
#url ⇒ Object
HTTPS URL validated against SSRF rules
22 23 24 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 55 def self.attribute_map { :'project_id' => :'projectId', :'url' => :'url', :'event' => :'event', :'payload' => :'payload', :'method' => :'method' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 253 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 76 def self.openapi_types { :'project_id' => :'String', :'url' => :'String', :'event' => :'String', :'payload' => :'Object', :'method' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && project_id == o.project_id && url == o.url && event == o.event && payload == o.payload && method == o.method end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 246 def hash [project_id, url, event, payload, method].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @event.nil? invalid_properties.push('invalid value for "event", event cannot be nil.') end if @payload.nil? invalid_properties.push('invalid value for "payload", payload cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/mudbase/models/trigger_webhook_request.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @project_id.nil? return false if @url.nil? return false if @event.nil? return false if @payload.nil? method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "PATCH", "DELETE"]) return false unless method_validator.valid?(@method) true end |