Class: Mudbase::UpdateApiKeyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::UpdateApiKeyRequest
- Defined in:
- lib/mudbase/models/update_api_key_request.rb
Overview
Fields to update on an API key (name, permissions, rateLimit, isActive).
Instance Attribute Summary collapse
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#rate_limit ⇒ Object
Returns the value of attribute rate_limit.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateApiKeyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateApiKeyRequest
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::UpdateApiKeyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::UpdateApiKeyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'rate_limit') self.rate_limit = attributes[:'rate_limit'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#is_active ⇒ Object
Returns the value of attribute is_active.
25 26 27 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 25 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 19 def name @name end |
#permissions ⇒ Object
Returns the value of attribute permissions.
21 22 23 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 21 def @permissions end |
#rate_limit ⇒ Object
Returns the value of attribute rate_limit.
23 24 25 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 23 def rate_limit @rate_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 28 def self.attribute_map { :'name' => :'name', :'permissions' => :'permissions', :'rate_limit' => :'rateLimit', :'is_active' => :'isActive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
58 59 60 61 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 58 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 48 def self.openapi_types { :'name' => :'String', :'permissions' => :'Array<ApiKeyPermission>', :'rate_limit' => :'RateLimit', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && == o. && rate_limit == o.rate_limit && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 160 def hash [name, , rate_limit, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 100 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if !@name.nil? && @name.to_s.length < 2 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 121 |
# File 'lib/mudbase/models/update_api_key_request.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 100 return false if !@name.nil? && @name.to_s.length < 2 true end |