Class: Mudbase::User

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/user.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/mudbase/models/user.rb', line 137

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'avatar')
    self.avatar = attributes[:'avatar']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'custom_role')
    self.custom_role = attributes[:'custom_role']
  end

  if attributes.key?(:'is_anonymous')
    self.is_anonymous = attributes[:'is_anonymous']
  end

  if attributes.key?(:'email_verified')
    self.email_verified = attributes[:'email_verified']
  end

  if attributes.key?(:'phone_verified')
    self.phone_verified = attributes[:'phone_verified']
  end

  if attributes.key?(:'two_factor_enabled')
    self.two_factor_enabled = attributes[:'two_factor_enabled']
  end

  if attributes.key?(:'last_login')
    self. = attributes[:'last_login']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'org')
    self.org = attributes[:'org']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/user.rb', line 18

def _id
  @_id
end

#avatarObject

Returns the value of attribute avatar.



28
29
30
# File 'lib/mudbase/models/user.rb', line 28

def avatar
  @avatar
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/mudbase/models/user.rb', line 46

def created_at
  @created_at
end

#custom_roleObject

Application-level role slug from the project's Multi-Role feature (e.g. "customer", "seller"). Null for org-level (org/admin/member/viewer) users who aren't project end-users.



33
34
35
# File 'lib/mudbase/models/user.rb', line 33

def custom_role
  @custom_role
end

#emailObject

Returns the value of attribute email.



20
21
22
# File 'lib/mudbase/models/user.rb', line 20

def email
  @email
end

#email_verifiedObject

Returns the value of attribute email_verified.



38
39
40
# File 'lib/mudbase/models/user.rb', line 38

def email_verified
  @email_verified
end

#first_nameObject

Returns the value of attribute first_name.



22
23
24
# File 'lib/mudbase/models/user.rb', line 22

def first_name
  @first_name
end

#full_nameObject

Returns the value of attribute full_name.



26
27
28
# File 'lib/mudbase/models/user.rb', line 26

def full_name
  @full_name
end

#is_anonymousObject

True for a guest session created via POST /api/auth/anonymous that hasn't been converted to a full account yet.



36
37
38
# File 'lib/mudbase/models/user.rb', line 36

def is_anonymous
  @is_anonymous
end

#last_loginObject

Returns the value of attribute last_login.



44
45
46
# File 'lib/mudbase/models/user.rb', line 44

def 
  @last_login
end

#last_nameObject

Returns the value of attribute last_name.



24
25
26
# File 'lib/mudbase/models/user.rb', line 24

def last_name
  @last_name
end

#orgObject

Returns the value of attribute org.



50
51
52
# File 'lib/mudbase/models/user.rb', line 50

def org
  @org
end

#phone_verifiedObject

Returns the value of attribute phone_verified.



40
41
42
# File 'lib/mudbase/models/user.rb', line 40

def phone_verified
  @phone_verified
end

#roleObject

Returns the value of attribute role.



30
31
32
# File 'lib/mudbase/models/user.rb', line 30

def role
  @role
end

#two_factor_enabledObject

Returns the value of attribute two_factor_enabled.



42
43
44
# File 'lib/mudbase/models/user.rb', line 42

def two_factor_enabled
  @two_factor_enabled
end

#updated_atObject

Returns the value of attribute updated_at.



48
49
50
# File 'lib/mudbase/models/user.rb', line 48

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



97
98
99
# File 'lib/mudbase/models/user.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/mudbase/models/user.rb', line 102

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mudbase/models/user.rb', line 75

def self.attribute_map
  {
    :'_id' => :'_id',
    :'email' => :'email',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'full_name' => :'fullName',
    :'avatar' => :'avatar',
    :'role' => :'role',
    :'custom_role' => :'customRole',
    :'is_anonymous' => :'isAnonymous',
    :'email_verified' => :'emailVerified',
    :'phone_verified' => :'phoneVerified',
    :'two_factor_enabled' => :'twoFactorEnabled',
    :'last_login' => :'lastLogin',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'org' => :'org'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/mudbase/models/user.rb', line 281

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



129
130
131
132
133
# File 'lib/mudbase/models/user.rb', line 129

def self.openapi_nullable
  Set.new([
    :'custom_role',
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/mudbase/models/user.rb', line 107

def self.openapi_types
  {
    :'_id' => :'String',
    :'email' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'full_name' => :'String',
    :'avatar' => :'String',
    :'role' => :'String',
    :'custom_role' => :'String',
    :'is_anonymous' => :'Boolean',
    :'email_verified' => :'Boolean',
    :'phone_verified' => :'Boolean',
    :'two_factor_enabled' => :'Boolean',
    :'last_login' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'org' => :'OrganizationSummary'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/mudbase/models/user.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      email == o.email &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      full_name == o.full_name &&
      avatar == o.avatar &&
      role == o.role &&
      custom_role == o.custom_role &&
      is_anonymous == o.is_anonymous &&
      email_verified == o.email_verified &&
      phone_verified == o.phone_verified &&
      two_factor_enabled == o.two_factor_enabled &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      org == o.org
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/mudbase/models/user.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/mudbase/models/user.rb', line 274

def hash
  [_id, email, first_name, last_name, full_name, avatar, role, custom_role, is_anonymous, email_verified, phone_verified, two_factor_enabled, , created_at, updated_at, org].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



218
219
220
221
222
# File 'lib/mudbase/models/user.rb', line 218

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/mudbase/models/user.rb', line 303

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



226
227
228
229
230
231
# File 'lib/mudbase/models/user.rb', line 226

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  role_validator = EnumAttributeValidator.new('String', ["owner", "admin", "member", "viewer"])
  return false unless role_validator.valid?(@role)
  true
end