Class: Mudbase::UsersEraseDataRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::UsersEraseDataRequest
- Defined in:
- lib/mudbase/models/users_erase_data_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#confirmation ⇒ Object
Returns the value of attribute confirmation.
-
#reason ⇒ Object
Optional reason for account deletion.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UsersEraseDataRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UsersEraseDataRequest
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::UsersEraseDataRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::UsersEraseDataRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'confirmation') self.confirmation = attributes[:'confirmation'] else self.confirmation = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end end |
Instance Attribute Details
#confirmation ⇒ Object
Returns the value of attribute confirmation.
18 19 20 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 18 def confirmation @confirmation end |
#reason ⇒ Object
Optional reason for account deletion
21 22 23 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 21 def reason @reason end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 46 def self.attribute_map { :'confirmation' => :'confirmation', :'reason' => :'reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 64 def self.openapi_types { :'confirmation' => :'String', :'reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && confirmation == o.confirmation && reason == o.reason end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 153 def hash [confirmation, reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @confirmation.nil? invalid_properties.push('invalid value for "confirmation", confirmation cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 122 123 124 |
# File 'lib/mudbase/models/users_erase_data_request.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @confirmation.nil? confirmation_validator = EnumAttributeValidator.new('String', ["DELETE_MY_ACCOUNT"]) return false unless confirmation_validator.valid?(@confirmation) true end |