Class: Mudbase::UsersExportData200Response

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/users_export_data200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UsersExportData200Response

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/mudbase/models/users_export_data200_response.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::UsersExportData200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::UsersExportData200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'exported_at')
    self.exported_at = attributes[:'exported_at']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'projects')
    if (value = attributes[:'projects']).is_a?(Array)
      self.projects = value
    end
  end

  if attributes.key?(:'wallets')
    if (value = attributes[:'wallets']).is_a?(Array)
      self.wallets = value
    end
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'files')
    if (value = attributes[:'files']).is_a?(Array)
      self.files = value
    end
  end

  if attributes.key?(:'integrations')
    if (value = attributes[:'integrations']).is_a?(Array)
      self.integrations = value
    end
  end

  if attributes.key?(:'api_keys')
    if (value = attributes[:'api_keys']).is_a?(Array)
      self.api_keys = value
    end
  end
end

Instance Attribute Details

#api_keysObject

Returns the value of attribute api_keys.



32
33
34
# File 'lib/mudbase/models/users_export_data200_response.rb', line 32

def api_keys
  @api_keys
end

#exported_atObject

Returns the value of attribute exported_at.



18
19
20
# File 'lib/mudbase/models/users_export_data200_response.rb', line 18

def exported_at
  @exported_at
end

#filesObject

Returns the value of attribute files.



28
29
30
# File 'lib/mudbase/models/users_export_data200_response.rb', line 28

def files
  @files
end

#integrationsObject

Returns the value of attribute integrations.



30
31
32
# File 'lib/mudbase/models/users_export_data200_response.rb', line 30

def integrations
  @integrations
end

#projectsObject

Returns the value of attribute projects.



22
23
24
# File 'lib/mudbase/models/users_export_data200_response.rb', line 22

def projects
  @projects
end

#transactionsObject

Returns the value of attribute transactions.



26
27
28
# File 'lib/mudbase/models/users_export_data200_response.rb', line 26

def transactions
  @transactions
end

#userObject

Returns the value of attribute user.



20
21
22
# File 'lib/mudbase/models/users_export_data200_response.rb', line 20

def user
  @user
end

#walletsObject

Returns the value of attribute wallets.



24
25
26
# File 'lib/mudbase/models/users_export_data200_response.rb', line 24

def wallets
  @wallets
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/mudbase/models/users_export_data200_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/mudbase/models/users_export_data200_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/mudbase/models/users_export_data200_response.rb', line 35

def self.attribute_map
  {
    :'exported_at' => :'exportedAt',
    :'user' => :'user',
    :'projects' => :'projects',
    :'wallets' => :'wallets',
    :'transactions' => :'transactions',
    :'files' => :'files',
    :'integrations' => :'integrations',
    :'api_keys' => :'apiKeys'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/mudbase/models/users_export_data200_response.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/mudbase/models/users_export_data200_response.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mudbase/models/users_export_data200_response.rb', line 59

def self.openapi_types
  {
    :'exported_at' => :'Time',
    :'user' => :'User',
    :'projects' => :'Array<Hash<String, Object>>',
    :'wallets' => :'Array<Hash<String, Object>>',
    :'transactions' => :'Array<Hash<String, Object>>',
    :'files' => :'Array<Hash<String, Object>>',
    :'integrations' => :'Array<Hash<String, Object>>',
    :'api_keys' => :'Array<Hash<String, Object>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/mudbase/models/users_export_data200_response.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      exported_at == o.exported_at &&
      user == o.user &&
      projects == o.projects &&
      wallets == o.wallets &&
      transactions == o.transactions &&
      files == o.files &&
      integrations == o.integrations &&
      api_keys == o.api_keys
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


171
172
173
# File 'lib/mudbase/models/users_export_data200_response.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



177
178
179
# File 'lib/mudbase/models/users_export_data200_response.rb', line 177

def hash
  [exported_at, user, projects, wallets, transactions, files, integrations, api_keys].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
# File 'lib/mudbase/models/users_export_data200_response.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/mudbase/models/users_export_data200_response.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



149
150
151
152
# File 'lib/mudbase/models/users_export_data200_response.rb', line 149

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end