Class: Mudbase::WalletEstimateGasRequestTransaction

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/wallet_estimate_gas_request_transaction.rb

Overview

Required for EVM chains. Optional for non-EVM (ignored). Supports 1) Token transfer { from, tokenAddress, to, amount }, 2) Native transfer { from, to, value }, 3) Raw { from, to, value, data }.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WalletEstimateGasRequestTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletEstimateGasRequestTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletEstimateGasRequestTransaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'token_address')
    self.token_address = attributes[:'token_address']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end
end

Instance Attribute Details

#amountObject

Token amount in human-readable format (e.g., \“1.0\” for 1 token). Used with tokenAddress for user-friendly token transfers. Automatically converted to token units based on token decimals.



35
36
37
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 35

def amount
  @amount
end

#dataObject

Raw transaction data (hex string starting with 0x). Used for raw format or contract calls. For token transfers, this is auto-generated from tokenAddress, to, and amount.



29
30
31
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 29

def data
  @data
end

#fromObject

Sender address



20
21
22
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 20

def from
  @from
end

#toObject

For native transfers: recipient address. For token transfers: recipient address (tokenAddress must be provided separately). For raw format: contract or recipient address.



23
24
25
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 23

def to
  @to
end

#token_addressObject

Token contract address (for token transfers). When provided with ‘amount’, automatically encodes the transfer.



32
33
34
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 32

def token_address
  @token_address
end

#valueObject

Amount in native currency (ETH/BNB/MATIC). Can be provided as decimal string (e.g., \“1.0\”) or wei string. Required for native transfers.



26
27
28
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 26

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 38

def self.attribute_map
  {
    :'from' => :'from',
    :'to' => :'to',
    :'value' => :'value',
    :'data' => :'data',
    :'token_address' => :'tokenAddress',
    :'amount' => :'amount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 60

def self.openapi_types
  {
    :'from' => :'String',
    :'to' => :'String',
    :'value' => :'String',
    :'data' => :'String',
    :'token_address' => :'String',
    :'amount' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      to == o.to &&
      value == o.value &&
      data == o.data &&
      token_address == o.token_address &&
      amount == o.amount
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 171

def hash
  [from, to, value, data, token_address, amount].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @from.nil?
    invalid_properties.push('invalid value for "from", from cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
# File 'lib/mudbase/models/wallet_estimate_gas_request_transaction.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @from.nil?
  true
end