Class: Mudbase::WalletGetCancelParams200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/wallet_get_cancel_params200_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WalletGetCancelParams200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletGetCancelParams200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletGetCancelParams200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'chain_id')
    self.chain_id = attributes[:'chain_id']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'nonce')
    self.nonce = attributes[:'nonce']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'gas_limit')
    self.gas_limit = attributes[:'gas_limit']
  end

  if attributes.key?(:'max_fee_per_gas')
    self.max_fee_per_gas = attributes[:'max_fee_per_gas']
  end

  if attributes.key?(:'max_priority_fee_per_gas')
    self.max_priority_fee_per_gas = attributes[:'max_priority_fee_per_gas']
  end

  if attributes.key?(:'gas_price')
    self.gas_price = attributes[:'gas_price']
  end
end

Instance Attribute Details

#chain_idObject

Returns the value of attribute chain_id.



18
19
20
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 18

def chain_id
  @chain_id
end

#dataObject

0x



31
32
33
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 31

def data
  @data
end

#fromObject

Returns the value of attribute from.



20
21
22
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 20

def from
  @from
end

#gas_limitObject

Returns the value of attribute gas_limit.



33
34
35
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 33

def gas_limit
  @gas_limit
end

#gas_priceObject

Returns the value of attribute gas_price.



39
40
41
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 39

def gas_price
  @gas_price
end

#max_fee_per_gasObject

Returns the value of attribute max_fee_per_gas.



35
36
37
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 35

def max_fee_per_gas
  @max_fee_per_gas
end

#max_priority_fee_per_gasObject

Returns the value of attribute max_priority_fee_per_gas.



37
38
39
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 37

def max_priority_fee_per_gas
  @max_priority_fee_per_gas
end

#nonceObject

Returns the value of attribute nonce.



22
23
24
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 22

def nonce
  @nonce
end

#toObject

Same as from (self)



25
26
27
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 25

def to
  @to
end

#valueObject

0



28
29
30
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 28

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 42

def self.attribute_map
  {
    :'chain_id' => :'chainId',
    :'from' => :'from',
    :'nonce' => :'nonce',
    :'to' => :'to',
    :'value' => :'value',
    :'data' => :'data',
    :'gas_limit' => :'gasLimit',
    :'max_fee_per_gas' => :'maxFeePerGas',
    :'max_priority_fee_per_gas' => :'maxPriorityFeePerGas',
    :'gas_price' => :'gasPrice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 68

def self.openapi_types
  {
    :'chain_id' => :'Integer',
    :'from' => :'String',
    :'nonce' => :'Integer',
    :'to' => :'String',
    :'value' => :'String',
    :'data' => :'String',
    :'gas_limit' => :'String',
    :'max_fee_per_gas' => :'String',
    :'max_priority_fee_per_gas' => :'String',
    :'gas_price' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      chain_id == o.chain_id &&
      from == o.from &&
      nonce == o.nonce &&
      to == o.to &&
      value == o.value &&
      data == o.data &&
      gas_limit == o.gas_limit &&
      max_fee_per_gas == o.max_fee_per_gas &&
      max_priority_fee_per_gas == o.max_priority_fee_per_gas &&
      gas_price == o.gas_price
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 186

def hash
  [chain_id, from, nonce, to, value, data, gas_limit, max_fee_per_gas, max_priority_fee_per_gas, gas_price].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
# File 'lib/mudbase/models/wallet_get_cancel_params200_response_data.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end