Class: Mudbase::WalletWebhookStats

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/wallet_webhook_stats.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WalletWebhookStats

Initializes the object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletWebhookStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletWebhookStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total_deliveries')
    self.total_deliveries = attributes[:'total_deliveries']
  end

  if attributes.key?(:'successful_deliveries')
    self.successful_deliveries = attributes[:'successful_deliveries']
  end

  if attributes.key?(:'failed_deliveries')
    self.failed_deliveries = attributes[:'failed_deliveries']
  end

  if attributes.key?(:'last_delivery_at')
    self.last_delivery_at = attributes[:'last_delivery_at']
  end
end

Instance Attribute Details

#failed_deliveriesObject

Returns the value of attribute failed_deliveries.



22
23
24
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 22

def failed_deliveries
  @failed_deliveries
end

#last_delivery_atObject

Returns the value of attribute last_delivery_at.



24
25
26
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 24

def last_delivery_at
  @last_delivery_at
end

#successful_deliveriesObject

Returns the value of attribute successful_deliveries.



20
21
22
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 20

def successful_deliveries
  @successful_deliveries
end

#total_deliveriesObject

Returns the value of attribute total_deliveries.



18
19
20
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 18

def total_deliveries
  @total_deliveries
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 27

def self.attribute_map
  {
    :'total_deliveries' => :'totalDeliveries',
    :'successful_deliveries' => :'successfulDeliveries',
    :'failed_deliveries' => :'failedDeliveries',
    :'last_delivery_at' => :'lastDeliveryAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 137

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 57

def self.openapi_nullable
  Set.new([
    :'last_delivery_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 47

def self.openapi_types
  {
    :'total_deliveries' => :'Integer',
    :'successful_deliveries' => :'Integer',
    :'failed_deliveries' => :'Integer',
    :'last_delivery_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



113
114
115
116
117
118
119
120
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 113

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_deliveries == o.total_deliveries &&
      successful_deliveries == o.successful_deliveries &&
      failed_deliveries == o.failed_deliveries &&
      last_delivery_at == o.last_delivery_at
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


124
125
126
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 124

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



130
131
132
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 130

def hash
  [total_deliveries, successful_deliveries, failed_deliveries, last_delivery_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



98
99
100
101
102
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 98

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 159

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



106
107
108
109
# File 'lib/mudbase/models/wallet_webhook_stats.rb', line 106

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end