Class: Mudbase::Withdraw200ResponseData

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/withdraw200_response_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Withdraw200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Withdraw200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Withdraw200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'signed_tx')
    self.signed_tx = attributes[:'signed_tx']
  end

  if attributes.key?(:'chain')
    self.chain = attributes[:'chain']
  end

  if attributes.key?(:'from_address')
    self.from_address = attributes[:'from_address']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'to_address')
    self.to_address = attributes[:'to_address']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



33
34
35
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 33

def amount
  @amount
end

#chainObject

Chain id for broadcast (e.g. ethereum, bitcoin, solana).



26
27
28
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 26

def chain
  @chain
end

#currencyObject

Returns the value of attribute currency.



31
32
33
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 31

def currency
  @currency
end

#from_addressObject

Sender address; must be registered for org when broadcasting.



29
30
31
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 29

def from_address
  @from_address
end

#messageObject

Returns the value of attribute message.



37
38
39
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 37

def message
  @message
end

#signed_txObject

Signed transaction (hex for EVM/UTXO, base64 for Solana, object for Tron). Send as-is in broadcast body.



23
24
25
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 23

def signed_tx
  @signed_tx
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 20

def status
  @status
end

#to_addressObject

Returns the value of attribute to_address.



35
36
37
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 35

def to_address
  @to_address
end

#transaction_idObject

Returns the value of attribute transaction_id.



18
19
20
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 18

def transaction_id
  @transaction_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 62

def self.attribute_map
  {
    :'transaction_id' => :'transactionId',
    :'status' => :'status',
    :'signed_tx' => :'signedTx',
    :'chain' => :'chain',
    :'from_address' => :'fromAddress',
    :'currency' => :'currency',
    :'amount' => :'amount',
    :'to_address' => :'toAddress',
    :'message' => :'message'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 87

def self.openapi_types
  {
    :'transaction_id' => :'String',
    :'status' => :'String',
    :'signed_tx' => :'String',
    :'chain' => :'String',
    :'from_address' => :'String',
    :'currency' => :'String',
    :'amount' => :'Float',
    :'to_address' => :'String',
    :'message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_id == o.transaction_id &&
      status == o.status &&
      signed_tx == o.signed_tx &&
      chain == o.chain &&
      from_address == o.from_address &&
      currency == o.currency &&
      amount == o.amount &&
      to_address == o.to_address &&
      message == o.message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 211

def hash
  [transaction_id, status, signed_tx, chain, from_address, currency, amount, to_address, message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
# File 'lib/mudbase/models/withdraw200_response_data.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["ready_to_broadcast"])
  return false unless status_validator.valid?(@status)
  true
end