Class: Mudbase::AddCustomRoleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AddCustomRoleRequest
- Defined in:
- lib/mudbase/models/add_custom_role_request.rb
Instance Attribute Summary collapse
-
#default_permissions ⇒ Object
Returns the value of attribute default_permissions.
-
#description ⇒ Object
Returns the value of attribute description.
-
#hierarchy ⇒ Object
Returns the value of attribute hierarchy.
-
#name ⇒ Object
Returns the value of attribute name.
-
#signup_endpoint ⇒ Object
Returns the value of attribute signup_endpoint.
-
#slug ⇒ Object
Returns the value of attribute slug.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddCustomRoleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddCustomRoleRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AddCustomRoleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AddCustomRoleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'signup_endpoint') self.signup_endpoint = attributes[:'signup_endpoint'] else self.signup_endpoint = nil end if attributes.key?(:'hierarchy') self.hierarchy = attributes[:'hierarchy'] end if attributes.key?(:'default_permissions') if (value = attributes[:'default_permissions']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#default_permissions ⇒ Object
Returns the value of attribute default_permissions.
28 29 30 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 28 def end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 22 def description @description end |
#hierarchy ⇒ Object
Returns the value of attribute hierarchy.
26 27 28 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 26 def hierarchy @hierarchy end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 20 def name @name end |
#signup_endpoint ⇒ Object
Returns the value of attribute signup_endpoint.
24 25 26 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 24 def signup_endpoint @signup_endpoint end |
#slug ⇒ Object
Returns the value of attribute slug.
18 19 20 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 18 def slug @slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 31 def self.attribute_map { :'slug' => :'slug', :'name' => :'name', :'description' => :'description', :'signup_endpoint' => :'signupEndpoint', :'hierarchy' => :'hierarchy', :'default_permissions' => :'defaultPermissions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 53 def self.openapi_types { :'slug' => :'String', :'name' => :'String', :'description' => :'String', :'signup_endpoint' => :'String', :'hierarchy' => :'Float', :'default_permissions' => :'Array<AddCustomRoleRequestDefaultPermissionsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && slug == o.slug && name == o.name && description == o.description && signup_endpoint == o.signup_endpoint && hierarchy == o.hierarchy && == o. end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 200 def hash [slug, name, description, signup_endpoint, hierarchy, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @signup_endpoint.nil? invalid_properties.push('invalid value for "signup_endpoint", signup_endpoint cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 145 146 147 |
# File 'lib/mudbase/models/add_custom_role_request.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @slug.nil? return false if @name.nil? return false if @signup_endpoint.nil? true end |