Class: Mudbase::AddOnsApi
- Inherits:
-
Object
- Object
- Mudbase::AddOnsApi
- Defined in:
- lib/mudbase/api/add_ons_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#api_addons_get(opts = {}) ⇒ ApiAddonsGet200Response
List the add-on catalog Returns the available add-ons (key, metadata, pricing) the caller can invoke.
-
#api_addons_get_with_http_info(opts = {}) ⇒ Array<(ApiAddonsGet200Response, Integer, Hash)>
List the add-on catalog Returns the available add-ons (key, metadata, pricing) the caller can invoke.
-
#api_projects_project_id_addons_addon_invoke_post(project_id, addon, opts = {}) ⇒ ApiProjectsProjectIdAddonsAddonInvokePost200Response
Invoke an add-on for a project Runs the named add-on against the project.
-
#api_projects_project_id_addons_addon_invoke_post_with_http_info(project_id, addon, opts = {}) ⇒ Array<(ApiProjectsProjectIdAddonsAddonInvokePost200Response, Integer, Hash)>
Invoke an add-on for a project Runs the named add-on against the project.
-
#api_projects_project_id_addons_jobs_id_get(project_id, id, opts = {}) ⇒ ApiProjectsProjectIdAddonsAddonInvokePost200Response
Get an add-on job status.
-
#api_projects_project_id_addons_jobs_id_get_with_http_info(project_id, id, opts = {}) ⇒ Array<(ApiProjectsProjectIdAddonsAddonInvokePost200Response, Integer, Hash)>
Get an add-on job status.
-
#initialize(api_client = ApiClient.default) ⇒ AddOnsApi
constructor
A new instance of AddOnsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/add_ons_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#api_addons_get(opts = {}) ⇒ ApiAddonsGet200Response
List the add-on catalog Returns the available add-ons (key, metadata, pricing) the caller can invoke.
26 27 28 29 |
# File 'lib/mudbase/api/add_ons_api.rb', line 26 def api_addons_get(opts = {}) data, _status_code, _headers = api_addons_get_with_http_info(opts) data end |
#api_addons_get_with_http_info(opts = {}) ⇒ Array<(ApiAddonsGet200Response, Integer, Hash)>
List the add-on catalog Returns the available add-ons (key, metadata, pricing) the caller can invoke.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mudbase/api/add_ons_api.rb', line 35 def api_addons_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddOnsApi.api_addons_get ...' end # resource path local_var_path = '/api/addons' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApiAddonsGet200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OrgBearerAuth'] = opts.merge( :operation => :"AddOnsApi.api_addons_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddOnsApi#api_addons_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#api_projects_project_id_addons_addon_invoke_post(project_id, addon, opts = {}) ⇒ ApiProjectsProjectIdAddonsAddonInvokePost200Response
Invoke an add-on for a project Runs the named add-on against the project. Returns the job synchronously (200) when it completes immediately, or 202 with a pending job when processing continues in the background.
86 87 88 89 |
# File 'lib/mudbase/api/add_ons_api.rb', line 86 def api_projects_project_id_addons_addon_invoke_post(project_id, addon, opts = {}) data, _status_code, _headers = api_projects_project_id_addons_addon_invoke_post_with_http_info(project_id, addon, opts) data end |
#api_projects_project_id_addons_addon_invoke_post_with_http_info(project_id, addon, opts = {}) ⇒ Array<(ApiProjectsProjectIdAddonsAddonInvokePost200Response, Integer, Hash)>
Invoke an add-on for a project Runs the named add-on against the project. Returns the job synchronously (200) when it completes immediately, or 202 with a pending job when processing continues in the background.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/mudbase/api/add_ons_api.rb', line 98 def api_projects_project_id_addons_addon_invoke_post_with_http_info(project_id, addon, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddOnsApi.api_projects_project_id_addons_addon_invoke_post ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling AddOnsApi.api_projects_project_id_addons_addon_invoke_post" end # verify the required parameter 'addon' is set if @api_client.config.client_side_validation && addon.nil? fail ArgumentError, "Missing the required parameter 'addon' when calling AddOnsApi.api_projects_project_id_addons_addon_invoke_post" end # resource path local_var_path = '/api/projects/{projectId}/addons/{addon}/invoke'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'addon' + '}', CGI.escape(addon.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'body']) # return_type return_type = opts[:debug_return_type] || 'ApiProjectsProjectIdAddonsAddonInvokePost200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"AddOnsApi.api_projects_project_id_addons_addon_invoke_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddOnsApi#api_projects_project_id_addons_addon_invoke_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#api_projects_project_id_addons_jobs_id_get(project_id, id, opts = {}) ⇒ ApiProjectsProjectIdAddonsAddonInvokePost200Response
Get an add-on job status
160 161 162 163 |
# File 'lib/mudbase/api/add_ons_api.rb', line 160 def api_projects_project_id_addons_jobs_id_get(project_id, id, opts = {}) data, _status_code, _headers = api_projects_project_id_addons_jobs_id_get_with_http_info(project_id, id, opts) data end |
#api_projects_project_id_addons_jobs_id_get_with_http_info(project_id, id, opts = {}) ⇒ Array<(ApiProjectsProjectIdAddonsAddonInvokePost200Response, Integer, Hash)>
Get an add-on job status
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/mudbase/api/add_ons_api.rb', line 170 def api_projects_project_id_addons_jobs_id_get_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddOnsApi.api_projects_project_id_addons_jobs_id_get ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling AddOnsApi.api_projects_project_id_addons_jobs_id_get" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AddOnsApi.api_projects_project_id_addons_jobs_id_get" end # resource path local_var_path = '/api/projects/{projectId}/addons/jobs/{id}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApiProjectsProjectIdAddonsAddonInvokePost200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'ProjectBearerAuth'] = opts.merge( :operation => :"AddOnsApi.api_projects_project_id_addons_jobs_id_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddOnsApi#api_projects_project_id_addons_jobs_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |