Class: Mudbase::AdminBillingCheckoutLinkRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AdminBillingCheckoutLinkRequest
- Defined in:
- lib/mudbase/models/admin_billing_checkout_link_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount_cents ⇒ Object
Monthly amount in cents (overrides catalog; enterprise default is contract).
-
#billing_cycle ⇒ Object
Returns the value of attribute billing_cycle.
-
#charge_amount_cents ⇒ Object
Exact charge in cents for this checkout (overrides monthly math).
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#email ⇒ Object
Returns the value of attribute email.
-
#message ⇒ Object
Optional note shown in org_billing_checkout email.
-
#name ⇒ Object
Returns the value of attribute name.
-
#plan ⇒ Object
Returns the value of attribute plan.
-
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
-
#send_email ⇒ Object
Returns the value of attribute send_email.
-
#to_email ⇒ Object
Returns the value of attribute to_email.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdminBillingCheckoutLinkRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdminBillingCheckoutLinkRequest
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AdminBillingCheckoutLinkRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AdminBillingCheckoutLinkRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'plan') self.plan = attributes[:'plan'] else self.plan = nil end if attributes.key?(:'billing_cycle') self.billing_cycle = attributes[:'billing_cycle'] else self.billing_cycle = 'monthly' end if attributes.key?(:'amount_cents') self.amount_cents = attributes[:'amount_cents'] end if attributes.key?(:'charge_amount_cents') self.charge_amount_cents = attributes[:'charge_amount_cents'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'send_email') self.send_email = attributes[:'send_email'] else self.send_email = false end if attributes.key?(:'to_email') self.to_email = attributes[:'to_email'] end if attributes.key?(:'message') self. = attributes[:'message'] end end |
Instance Attribute Details
#amount_cents ⇒ Object
Monthly amount in cents (overrides catalog; enterprise default is contract)
23 24 25 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 23 def amount_cents @amount_cents end |
#billing_cycle ⇒ Object
Returns the value of attribute billing_cycle.
20 21 22 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 20 def billing_cycle @billing_cycle end |
#charge_amount_cents ⇒ Object
Exact charge in cents for this checkout (overrides monthly math)
26 27 28 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 26 def charge_amount_cents @charge_amount_cents end |
#currency ⇒ Object
Returns the value of attribute currency.
28 29 30 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 28 def currency @currency end |
#email ⇒ Object
Returns the value of attribute email.
30 31 32 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 30 def email @email end |
#message ⇒ Object
Optional note shown in org_billing_checkout email
41 42 43 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 41 def @message end |
#name ⇒ Object
Returns the value of attribute name.
32 33 34 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 32 def name @name end |
#plan ⇒ Object
Returns the value of attribute plan.
18 19 20 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 18 def plan @plan end |
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
34 35 36 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 34 def redirect_url @redirect_url end |
#send_email ⇒ Object
Returns the value of attribute send_email.
36 37 38 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 36 def send_email @send_email end |
#to_email ⇒ Object
Returns the value of attribute to_email.
38 39 40 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 38 def to_email @to_email end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 66 def self.attribute_map { :'plan' => :'plan', :'billing_cycle' => :'billingCycle', :'amount_cents' => :'amountCents', :'charge_amount_cents' => :'chargeAmountCents', :'currency' => :'currency', :'email' => :'email', :'name' => :'name', :'redirect_url' => :'redirectUrl', :'send_email' => :'sendEmail', :'to_email' => :'toEmail', :'message' => :'message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 297 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 110 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 93 def self.openapi_types { :'plan' => :'String', :'billing_cycle' => :'String', :'amount_cents' => :'Integer', :'charge_amount_cents' => :'Integer', :'currency' => :'String', :'email' => :'String', :'name' => :'String', :'redirect_url' => :'String', :'send_email' => :'Boolean', :'to_email' => :'String', :'message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && plan == o.plan && billing_cycle == o.billing_cycle && amount_cents == o.amount_cents && charge_amount_cents == o.charge_amount_cents && currency == o.currency && email == o.email && name == o.name && redirect_url == o.redirect_url && send_email == o.send_email && to_email == o.to_email && == o. end |
#eql?(o) ⇒ Boolean
284 285 286 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 284 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 290 def hash [plan, billing_cycle, amount_cents, charge_amount_cents, currency, email, name, redirect_url, send_email, to_email, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @plan.nil? invalid_properties.push('invalid value for "plan", plan cannot be nil.') end if !@amount_cents.nil? && @amount_cents < 1 invalid_properties.push('invalid value for "amount_cents", must be greater than or equal to 1.') end if !@charge_amount_cents.nil? && @charge_amount_cents < 1 invalid_properties.push('invalid value for "charge_amount_cents", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/mudbase/models/admin_billing_checkout_link_request.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @plan.nil? plan_validator = EnumAttributeValidator.new('String', ["starter", "growth", "scale", "enterprise"]) return false unless plan_validator.valid?(@plan) billing_cycle_validator = EnumAttributeValidator.new('String', ["monthly", "yearly"]) return false unless billing_cycle_validator.valid?(@billing_cycle) return false if !@amount_cents.nil? && @amount_cents < 1 return false if !@charge_amount_cents.nil? && @charge_amount_cents < 1 true end |