Class: Mudbase::AdminOrgLimitsPatchRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AdminOrgLimitsPatchRequest
- Defined in:
- lib/mudbase/models/admin_org_limits_patch_request.rb
Overview
Partial org limit overrides for platform admins. At least one property required. Keys match PLANS[*].limits in the backend; integers are non-negative or null for unlimited.
Instance Attribute Summary collapse
-
#alerts_per_project ⇒ Object
Returns the value of attribute alerts_per_project.
-
#api_calls ⇒ Object
Returns the value of attribute api_calls.
-
#api_keys_per_project ⇒ Object
Returns the value of attribute api_keys_per_project.
-
#backups_per_project ⇒ Object
Returns the value of attribute backups_per_project.
-
#bandwidth ⇒ Object
Returns the value of attribute bandwidth.
-
#blockchain_chains ⇒ Object
Returns the value of attribute blockchain_chains.
-
#buckets ⇒ Object
Returns the value of attribute buckets.
-
#bug_analysis ⇒ Object
Returns the value of attribute bug_analysis.
-
#chat_channels_per_project ⇒ Object
Returns the value of attribute chat_channels_per_project.
-
#chat_messages_per_month ⇒ Object
Returns the value of attribute chat_messages_per_month.
-
#collections ⇒ Object
Returns the value of attribute collections.
-
#function_invocations_per_month ⇒ Object
Returns the value of attribute function_invocations_per_month.
-
#functions_per_project ⇒ Object
Returns the value of attribute functions_per_project.
-
#integrations_per_project ⇒ Object
Returns the value of attribute integrations_per_project.
-
#messaging_messages_per_month ⇒ Object
Returns the value of attribute messaging_messages_per_month.
-
#monitored_wallets ⇒ Object
Returns the value of attribute monitored_wallets.
-
#projects ⇒ Object
Returns the value of attribute projects.
-
#realtime_connections ⇒ Object
Returns the value of attribute realtime_connections.
-
#realtime_messages ⇒ Object
Returns the value of attribute realtime_messages.
-
#restores_per_month ⇒ Object
Returns the value of attribute restores_per_month.
-
#roles_per_org ⇒ Object
Returns the value of attribute roles_per_org.
-
#sms_per_month ⇒ Object
Returns the value of attribute sms_per_month.
-
#storage ⇒ Object
Returns the value of attribute storage.
-
#team_users ⇒ Object
Returns the value of attribute team_users.
-
#wallet_webhooks_per_org ⇒ Object
Returns the value of attribute wallet_webhooks_per_org.
-
#webhooks_per_project ⇒ Object
Returns the value of attribute webhooks_per_project.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdminOrgLimitsPatchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdminOrgLimitsPatchRequest
Initializes the object
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 178 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AdminOrgLimitsPatchRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AdminOrgLimitsPatchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'projects') self.projects = attributes[:'projects'] end if attributes.key?(:'storage') self.storage = attributes[:'storage'] end if attributes.key?(:'bandwidth') self.bandwidth = attributes[:'bandwidth'] end if attributes.key?(:'api_calls') self.api_calls = attributes[:'api_calls'] end if attributes.key?(:'buckets') self.buckets = attributes[:'buckets'] end if attributes.key?(:'collections') self.collections = attributes[:'collections'] end if attributes.key?(:'realtime_connections') self.realtime_connections = attributes[:'realtime_connections'] end if attributes.key?(:'realtime_messages') self. = attributes[:'realtime_messages'] end if attributes.key?(:'chat_messages_per_month') self. = attributes[:'chat_messages_per_month'] end if attributes.key?(:'monitored_wallets') self.monitored_wallets = attributes[:'monitored_wallets'] end if attributes.key?(:'wallet_webhooks_per_org') self.wallet_webhooks_per_org = attributes[:'wallet_webhooks_per_org'] end if attributes.key?(:'api_keys_per_project') self.api_keys_per_project = attributes[:'api_keys_per_project'] end if attributes.key?(:'webhooks_per_project') self.webhooks_per_project = attributes[:'webhooks_per_project'] end if attributes.key?(:'functions_per_project') self.functions_per_project = attributes[:'functions_per_project'] end if attributes.key?(:'function_invocations_per_month') self.function_invocations_per_month = attributes[:'function_invocations_per_month'] end if attributes.key?(:'messaging_messages_per_month') self. = attributes[:'messaging_messages_per_month'] end if attributes.key?(:'sms_per_month') self.sms_per_month = attributes[:'sms_per_month'] end if attributes.key?(:'chat_channels_per_project') self.chat_channels_per_project = attributes[:'chat_channels_per_project'] end if attributes.key?(:'backups_per_project') self.backups_per_project = attributes[:'backups_per_project'] end if attributes.key?(:'restores_per_month') self.restores_per_month = attributes[:'restores_per_month'] end if attributes.key?(:'integrations_per_project') self.integrations_per_project = attributes[:'integrations_per_project'] end if attributes.key?(:'roles_per_org') self.roles_per_org = attributes[:'roles_per_org'] end if attributes.key?(:'alerts_per_project') self.alerts_per_project = attributes[:'alerts_per_project'] end if attributes.key?(:'blockchain_chains') self.blockchain_chains = attributes[:'blockchain_chains'] end if attributes.key?(:'team_users') self.team_users = attributes[:'team_users'] end if attributes.key?(:'bug_analysis') self.bug_analysis = attributes[:'bug_analysis'] end end |
Instance Attribute Details
#alerts_per_project ⇒ Object
Returns the value of attribute alerts_per_project.
63 64 65 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 63 def alerts_per_project @alerts_per_project end |
#api_calls ⇒ Object
Returns the value of attribute api_calls.
25 26 27 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 25 def api_calls @api_calls end |
#api_keys_per_project ⇒ Object
Returns the value of attribute api_keys_per_project.
41 42 43 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 41 def api_keys_per_project @api_keys_per_project end |
#backups_per_project ⇒ Object
Returns the value of attribute backups_per_project.
55 56 57 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 55 def backups_per_project @backups_per_project end |
#bandwidth ⇒ Object
Returns the value of attribute bandwidth.
23 24 25 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 23 def bandwidth @bandwidth end |
#blockchain_chains ⇒ Object
Returns the value of attribute blockchain_chains.
65 66 67 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 65 def blockchain_chains @blockchain_chains end |
#buckets ⇒ Object
Returns the value of attribute buckets.
27 28 29 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 27 def buckets @buckets end |
#bug_analysis ⇒ Object
Returns the value of attribute bug_analysis.
69 70 71 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 69 def bug_analysis @bug_analysis end |
#chat_channels_per_project ⇒ Object
Returns the value of attribute chat_channels_per_project.
53 54 55 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 53 def chat_channels_per_project @chat_channels_per_project end |
#chat_messages_per_month ⇒ Object
Returns the value of attribute chat_messages_per_month.
35 36 37 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 35 def @chat_messages_per_month end |
#collections ⇒ Object
Returns the value of attribute collections.
29 30 31 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 29 def collections @collections end |
#function_invocations_per_month ⇒ Object
Returns the value of attribute function_invocations_per_month.
47 48 49 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 47 def function_invocations_per_month @function_invocations_per_month end |
#functions_per_project ⇒ Object
Returns the value of attribute functions_per_project.
45 46 47 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 45 def functions_per_project @functions_per_project end |
#integrations_per_project ⇒ Object
Returns the value of attribute integrations_per_project.
59 60 61 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 59 def integrations_per_project @integrations_per_project end |
#messaging_messages_per_month ⇒ Object
Returns the value of attribute messaging_messages_per_month.
49 50 51 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 49 def @messaging_messages_per_month end |
#monitored_wallets ⇒ Object
Returns the value of attribute monitored_wallets.
37 38 39 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 37 def monitored_wallets @monitored_wallets end |
#projects ⇒ Object
Returns the value of attribute projects.
19 20 21 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 19 def projects @projects end |
#realtime_connections ⇒ Object
Returns the value of attribute realtime_connections.
31 32 33 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 31 def realtime_connections @realtime_connections end |
#realtime_messages ⇒ Object
Returns the value of attribute realtime_messages.
33 34 35 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 33 def @realtime_messages end |
#restores_per_month ⇒ Object
Returns the value of attribute restores_per_month.
57 58 59 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 57 def restores_per_month @restores_per_month end |
#roles_per_org ⇒ Object
Returns the value of attribute roles_per_org.
61 62 63 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 61 def roles_per_org @roles_per_org end |
#sms_per_month ⇒ Object
Returns the value of attribute sms_per_month.
51 52 53 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 51 def sms_per_month @sms_per_month end |
#storage ⇒ Object
Returns the value of attribute storage.
21 22 23 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 21 def storage @storage end |
#team_users ⇒ Object
Returns the value of attribute team_users.
67 68 69 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 67 def team_users @team_users end |
#wallet_webhooks_per_org ⇒ Object
Returns the value of attribute wallet_webhooks_per_org.
39 40 41 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 39 def wallet_webhooks_per_org @wallet_webhooks_per_org end |
#webhooks_per_project ⇒ Object
Returns the value of attribute webhooks_per_project.
43 44 45 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 43 def webhooks_per_project @webhooks_per_project end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
104 105 106 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 104 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 109 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 72 def self.attribute_map { :'projects' => :'projects', :'storage' => :'storage', :'bandwidth' => :'bandwidth', :'api_calls' => :'apiCalls', :'buckets' => :'buckets', :'collections' => :'collections', :'realtime_connections' => :'realtimeConnections', :'realtime_messages' => :'realtimeMessages', :'chat_messages_per_month' => :'chatMessagesPerMonth', :'monitored_wallets' => :'monitoredWallets', :'wallet_webhooks_per_org' => :'walletWebhooksPerOrg', :'api_keys_per_project' => :'apiKeysPerProject', :'webhooks_per_project' => :'webhooksPerProject', :'functions_per_project' => :'functionsPerProject', :'function_invocations_per_month' => :'functionInvocationsPerMonth', :'messaging_messages_per_month' => :'messagingMessagesPerMonth', :'sms_per_month' => :'smsPerMonth', :'chat_channels_per_project' => :'chatChannelsPerProject', :'backups_per_project' => :'backupsPerProject', :'restores_per_month' => :'restoresPerMonth', :'integrations_per_project' => :'integrationsPerProject', :'roles_per_org' => :'rolesPerOrg', :'alerts_per_project' => :'alertsPerProject', :'blockchain_chains' => :'blockchainChains', :'team_users' => :'teamUsers', :'bug_analysis' => :'bugAnalysis' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 735 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 146 def self.openapi_nullable Set.new([ :'projects', :'storage', :'bandwidth', :'api_calls', :'buckets', :'collections', :'realtime_connections', :'realtime_messages', :'chat_messages_per_month', :'monitored_wallets', :'wallet_webhooks_per_org', :'api_keys_per_project', :'webhooks_per_project', :'functions_per_project', :'function_invocations_per_month', :'messaging_messages_per_month', :'sms_per_month', :'chat_channels_per_project', :'backups_per_project', :'restores_per_month', :'integrations_per_project', :'roles_per_org', :'alerts_per_project', :'blockchain_chains', :'team_users', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 114 def self.openapi_types { :'projects' => :'Integer', :'storage' => :'Integer', :'bandwidth' => :'Integer', :'api_calls' => :'Integer', :'buckets' => :'Integer', :'collections' => :'Integer', :'realtime_connections' => :'Integer', :'realtime_messages' => :'Integer', :'chat_messages_per_month' => :'Integer', :'monitored_wallets' => :'Integer', :'wallet_webhooks_per_org' => :'Integer', :'api_keys_per_project' => :'Integer', :'webhooks_per_project' => :'Integer', :'functions_per_project' => :'Integer', :'function_invocations_per_month' => :'Integer', :'messaging_messages_per_month' => :'Integer', :'sms_per_month' => :'Integer', :'chat_channels_per_project' => :'Integer', :'backups_per_project' => :'Integer', :'restores_per_month' => :'Integer', :'integrations_per_project' => :'Integer', :'roles_per_org' => :'Integer', :'alerts_per_project' => :'Integer', :'blockchain_chains' => :'Integer', :'team_users' => :'Integer', :'bug_analysis' => :'AdminOrgLimitsPatchRequestBugAnalysis' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 689 def ==(o) return true if self.equal?(o) self.class == o.class && projects == o.projects && storage == o.storage && bandwidth == o.bandwidth && api_calls == o.api_calls && buckets == o.buckets && collections == o.collections && realtime_connections == o.realtime_connections && == o. && == o. && monitored_wallets == o.monitored_wallets && wallet_webhooks_per_org == o.wallet_webhooks_per_org && api_keys_per_project == o.api_keys_per_project && webhooks_per_project == o.webhooks_per_project && functions_per_project == o.functions_per_project && function_invocations_per_month == o.function_invocations_per_month && == o. && sms_per_month == o.sms_per_month && chat_channels_per_project == o.chat_channels_per_project && backups_per_project == o.backups_per_project && restores_per_month == o.restores_per_month && integrations_per_project == o.integrations_per_project && roles_per_org == o.roles_per_org && alerts_per_project == o.alerts_per_project && blockchain_chains == o.blockchain_chains && team_users == o.team_users && bug_analysis == o.bug_analysis end |
#eql?(o) ⇒ Boolean
722 723 724 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 722 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
728 729 730 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 728 def hash [projects, storage, bandwidth, api_calls, buckets, collections, realtime_connections, , , monitored_wallets, wallet_webhooks_per_org, api_keys_per_project, webhooks_per_project, functions_per_project, function_invocations_per_month, , sms_per_month, chat_channels_per_project, backups_per_project, restores_per_month, integrations_per_project, roles_per_org, alerts_per_project, blockchain_chains, team_users, bug_analysis].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 299 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@projects.nil? && @projects < 0 invalid_properties.push('invalid value for "projects", must be greater than or equal to 0.') end if !@storage.nil? && @storage < 0 invalid_properties.push('invalid value for "storage", must be greater than or equal to 0.') end if !@bandwidth.nil? && @bandwidth < 0 invalid_properties.push('invalid value for "bandwidth", must be greater than or equal to 0.') end if !@api_calls.nil? && @api_calls < 0 invalid_properties.push('invalid value for "api_calls", must be greater than or equal to 0.') end if !@buckets.nil? && @buckets < 0 invalid_properties.push('invalid value for "buckets", must be greater than or equal to 0.') end if !@collections.nil? && @collections < 0 invalid_properties.push('invalid value for "collections", must be greater than or equal to 0.') end if !@realtime_connections.nil? && @realtime_connections < 0 invalid_properties.push('invalid value for "realtime_connections", must be greater than or equal to 0.') end if !@realtime_messages.nil? && @realtime_messages < 0 invalid_properties.push('invalid value for "realtime_messages", must be greater than or equal to 0.') end if !@chat_messages_per_month.nil? && @chat_messages_per_month < 0 invalid_properties.push('invalid value for "chat_messages_per_month", must be greater than or equal to 0.') end if !@monitored_wallets.nil? && @monitored_wallets < 0 invalid_properties.push('invalid value for "monitored_wallets", must be greater than or equal to 0.') end if !@wallet_webhooks_per_org.nil? && @wallet_webhooks_per_org < 0 invalid_properties.push('invalid value for "wallet_webhooks_per_org", must be greater than or equal to 0.') end if !@api_keys_per_project.nil? && @api_keys_per_project < 0 invalid_properties.push('invalid value for "api_keys_per_project", must be greater than or equal to 0.') end if !@webhooks_per_project.nil? && @webhooks_per_project < 0 invalid_properties.push('invalid value for "webhooks_per_project", must be greater than or equal to 0.') end if !@functions_per_project.nil? && @functions_per_project < 0 invalid_properties.push('invalid value for "functions_per_project", must be greater than or equal to 0.') end if !@function_invocations_per_month.nil? && @function_invocations_per_month < 0 invalid_properties.push('invalid value for "function_invocations_per_month", must be greater than or equal to 0.') end if !@messaging_messages_per_month.nil? && @messaging_messages_per_month < 0 invalid_properties.push('invalid value for "messaging_messages_per_month", must be greater than or equal to 0.') end if !@sms_per_month.nil? && @sms_per_month < 0 invalid_properties.push('invalid value for "sms_per_month", must be greater than or equal to 0.') end if !@chat_channels_per_project.nil? && @chat_channels_per_project < 0 invalid_properties.push('invalid value for "chat_channels_per_project", must be greater than or equal to 0.') end if !@backups_per_project.nil? && @backups_per_project < 0 invalid_properties.push('invalid value for "backups_per_project", must be greater than or equal to 0.') end if !@restores_per_month.nil? && @restores_per_month < 0 invalid_properties.push('invalid value for "restores_per_month", must be greater than or equal to 0.') end if !@integrations_per_project.nil? && @integrations_per_project < 0 invalid_properties.push('invalid value for "integrations_per_project", must be greater than or equal to 0.') end if !@roles_per_org.nil? && @roles_per_org < 0 invalid_properties.push('invalid value for "roles_per_org", must be greater than or equal to 0.') end if !@alerts_per_project.nil? && @alerts_per_project < 0 invalid_properties.push('invalid value for "alerts_per_project", must be greater than or equal to 0.') end if !@blockchain_chains.nil? && @blockchain_chains < 0 invalid_properties.push('invalid value for "blockchain_chains", must be greater than or equal to 0.') end if !@team_users.nil? && @team_users < 0 invalid_properties.push('invalid value for "team_users", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
757 758 759 760 761 762 763 764 765 766 767 768 769 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 757 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/mudbase/models/admin_org_limits_patch_request.rb', line 407 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@projects.nil? && @projects < 0 return false if !@storage.nil? && @storage < 0 return false if !@bandwidth.nil? && @bandwidth < 0 return false if !@api_calls.nil? && @api_calls < 0 return false if !@buckets.nil? && @buckets < 0 return false if !@collections.nil? && @collections < 0 return false if !@realtime_connections.nil? && @realtime_connections < 0 return false if !@realtime_messages.nil? && @realtime_messages < 0 return false if !@chat_messages_per_month.nil? && @chat_messages_per_month < 0 return false if !@monitored_wallets.nil? && @monitored_wallets < 0 return false if !@wallet_webhooks_per_org.nil? && @wallet_webhooks_per_org < 0 return false if !@api_keys_per_project.nil? && @api_keys_per_project < 0 return false if !@webhooks_per_project.nil? && @webhooks_per_project < 0 return false if !@functions_per_project.nil? && @functions_per_project < 0 return false if !@function_invocations_per_month.nil? && @function_invocations_per_month < 0 return false if !@messaging_messages_per_month.nil? && @messaging_messages_per_month < 0 return false if !@sms_per_month.nil? && @sms_per_month < 0 return false if !@chat_channels_per_project.nil? && @chat_channels_per_project < 0 return false if !@backups_per_project.nil? && @backups_per_project < 0 return false if !@restores_per_month.nil? && @restores_per_month < 0 return false if !@integrations_per_project.nil? && @integrations_per_project < 0 return false if !@roles_per_org.nil? && @roles_per_org < 0 return false if !@alerts_per_project.nil? && @alerts_per_project < 0 return false if !@blockchain_chains.nil? && @blockchain_chains < 0 return false if !@team_users.nil? && @team_users < 0 true end |