Class: Mudbase::AdminPlatformDnsVerificationPatchRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::AdminPlatformDnsVerificationPatchRequest
- Defined in:
- lib/mudbase/models/admin_platform_dns_verification_patch_request.rb
Instance Attribute Summary collapse
-
#notify_org ⇒ Object
When not false (default), email org billing contact with step-3 DNS instructions after save.
-
#record_name ⇒ Object
Returns the value of attribute record_name.
-
#record_type ⇒ Object
Returns the value of attribute record_type.
-
#record_value ⇒ Object
Returns the value of attribute record_value.
-
#reset_customer_platform_dns_submission ⇒ Object
Returns the value of attribute reset_customer_platform_dns_submission.
-
#staff_note ⇒ Object
Returns the value of attribute staff_note.
-
#ttl_seconds ⇒ Object
Returns the value of attribute ttl_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdminPlatformDnsVerificationPatchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdminPlatformDnsVerificationPatchRequest
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::AdminPlatformDnsVerificationPatchRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::AdminPlatformDnsVerificationPatchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'record_type') self.record_type = attributes[:'record_type'] end if attributes.key?(:'record_name') self.record_name = attributes[:'record_name'] else self.record_name = nil end if attributes.key?(:'record_value') self.record_value = attributes[:'record_value'] else self.record_value = nil end if attributes.key?(:'ttl_seconds') self.ttl_seconds = attributes[:'ttl_seconds'] end if attributes.key?(:'staff_note') self.staff_note = attributes[:'staff_note'] end if attributes.key?(:'reset_customer_platform_dns_submission') self.reset_customer_platform_dns_submission = attributes[:'reset_customer_platform_dns_submission'] end if attributes.key?(:'notify_org') self.notify_org = attributes[:'notify_org'] end end |
Instance Attribute Details
#notify_org ⇒ Object
When not false (default), email org billing contact with step-3 DNS instructions after save.
31 32 33 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 31 def notify_org @notify_org end |
#record_name ⇒ Object
Returns the value of attribute record_name.
20 21 22 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 20 def record_name @record_name end |
#record_type ⇒ Object
Returns the value of attribute record_type.
18 19 20 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 18 def record_type @record_type end |
#record_value ⇒ Object
Returns the value of attribute record_value.
22 23 24 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 22 def record_value @record_value end |
#reset_customer_platform_dns_submission ⇒ Object
Returns the value of attribute reset_customer_platform_dns_submission.
28 29 30 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 28 def reset_customer_platform_dns_submission @reset_customer_platform_dns_submission end |
#staff_note ⇒ Object
Returns the value of attribute staff_note.
26 27 28 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 26 def staff_note @staff_note end |
#ttl_seconds ⇒ Object
Returns the value of attribute ttl_seconds.
24 25 26 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 24 def ttl_seconds @ttl_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 34 def self.attribute_map { :'record_type' => :'recordType', :'record_name' => :'recordName', :'record_value' => :'recordValue', :'ttl_seconds' => :'ttlSeconds', :'staff_note' => :'staffNote', :'reset_customer_platform_dns_submission' => :'resetCustomerPlatformDnsSubmission', :'notify_org' => :'notifyOrg' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 276 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 74 75 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 70 def self.openapi_nullable Set.new([ :'ttl_seconds', :'staff_note', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 57 def self.openapi_types { :'record_type' => :'String', :'record_name' => :'String', :'record_value' => :'String', :'ttl_seconds' => :'Integer', :'staff_note' => :'String', :'reset_customer_platform_dns_submission' => :'Boolean', :'notify_org' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && record_type == o.record_type && record_name == o.record_name && record_value == o.record_value && ttl_seconds == o.ttl_seconds && staff_note == o.staff_note && reset_customer_platform_dns_submission == o.reset_customer_platform_dns_submission && notify_org == o.notify_org end |
#eql?(o) ⇒ Boolean
263 264 265 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 263 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 269 def hash [record_type, record_name, record_value, ttl_seconds, staff_note, reset_customer_platform_dns_submission, notify_org].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@record_type.nil? && @record_type.to_s.length > 32 invalid_properties.push('invalid value for "record_type", the character length must be smaller than or equal to 32.') end if @record_name.nil? invalid_properties.push('invalid value for "record_name", record_name cannot be nil.') end if @record_name.to_s.length > 512 invalid_properties.push('invalid value for "record_name", the character length must be smaller than or equal to 512.') end if @record_value.nil? invalid_properties.push('invalid value for "record_value", record_value cannot be nil.') end if @record_value.to_s.length > 4096 invalid_properties.push('invalid value for "record_value", the character length must be smaller than or equal to 4096.') end if !@ttl_seconds.nil? && @ttl_seconds > 86400 invalid_properties.push('invalid value for "ttl_seconds", must be smaller than or equal to 86400.') end if !@ttl_seconds.nil? && @ttl_seconds < 0 invalid_properties.push('invalid value for "ttl_seconds", must be greater than or equal to 0.') end if !@staff_note.nil? && @staff_note.to_s.length > 4000 invalid_properties.push('invalid value for "staff_note", the character length must be smaller than or equal to 4000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/mudbase/models/admin_platform_dns_verification_patch_request.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@record_type.nil? && @record_type.to_s.length > 32 return false if @record_name.nil? return false if @record_name.to_s.length > 512 return false if @record_value.nil? return false if @record_value.to_s.length > 4096 return false if !@ttl_seconds.nil? && @ttl_seconds > 86400 return false if !@ttl_seconds.nil? && @ttl_seconds < 0 return false if !@staff_note.nil? && @staff_note.to_s.length > 4000 true end |