Class: Mudbase::CollectionsApi
- Inherits:
-
Object
- Object
- Mudbase::CollectionsApi
- Defined in:
- lib/mudbase/api/collections_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#collections_create(project_id, create_collection_request, opts = {}) ⇒ CollectionsCreate201Response
Create new collection Create a new collection in a project.
-
#collections_create_with_http_info(project_id, create_collection_request, opts = {}) ⇒ Array<(CollectionsCreate201Response, Integer, Hash)>
Create new collection Create a new collection in a project.
-
#collections_delete(project_id, collection_id, opts = {}) ⇒ MessageResponse
Delete collection Delete a collection permanently.
-
#collections_delete_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Delete collection Delete a collection permanently.
-
#collections_get(project_id, collection_id, opts = {}) ⇒ Collection
Get single collection Get collection details by ID.
-
#collections_get_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(Collection, Integer, Hash)>
Get single collection Get collection details by ID.
-
#collections_list(project_id, opts = {}) ⇒ CollectionsList200Response
List collections in project List all collections in a project.
-
#collections_list_with_http_info(project_id, opts = {}) ⇒ Array<(CollectionsList200Response, Integer, Hash)>
List collections in project List all collections in a project.
-
#collections_update(project_id, collection_id, update_collection_request, opts = {}) ⇒ CollectionsCreate201Response
Update collection Update collection configuration (name, fields, permissions).
-
#collections_update_with_http_info(project_id, collection_id, update_collection_request, opts = {}) ⇒ Array<(CollectionsCreate201Response, Integer, Hash)>
Update collection Update collection configuration (name, fields, permissions).
-
#initialize(api_client = ApiClient.default) ⇒ CollectionsApi
constructor
A new instance of CollectionsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CollectionsApi
Returns a new instance of CollectionsApi.
19 20 21 |
# File 'lib/mudbase/api/collections_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/collections_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#collections_create(project_id, create_collection_request, opts = {}) ⇒ CollectionsCreate201Response
Create new collection Create a new collection in a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
28 29 30 31 |
# File 'lib/mudbase/api/collections_api.rb', line 28 def collections_create(project_id, create_collection_request, opts = {}) data, _status_code, _headers = collections_create_with_http_info(project_id, create_collection_request, opts) data end |
#collections_create_with_http_info(project_id, create_collection_request, opts = {}) ⇒ Array<(CollectionsCreate201Response, Integer, Hash)>
Create new collection Create a new collection in a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/mudbase/api/collections_api.rb', line 39 def collections_create_with_http_info(project_id, create_collection_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CollectionsApi.collections_create ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CollectionsApi.collections_create" end # verify the required parameter 'create_collection_request' is set if @api_client.config.client_side_validation && create_collection_request.nil? fail ArgumentError, "Missing the required parameter 'create_collection_request' when calling CollectionsApi.collections_create" end # resource path local_var_path = '/api/schemas/projects/{projectId}/collections'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_collection_request) # return_type return_type = opts[:debug_return_type] || 'CollectionsCreate201Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"CollectionsApi.collections_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CollectionsApi#collections_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#collections_delete(project_id, collection_id, opts = {}) ⇒ MessageResponse
Delete collection Delete a collection permanently. This is a destructive operation. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
102 103 104 105 |
# File 'lib/mudbase/api/collections_api.rb', line 102 def collections_delete(project_id, collection_id, opts = {}) data, _status_code, _headers = collections_delete_with_http_info(project_id, collection_id, opts) data end |
#collections_delete_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Delete collection Delete a collection permanently. This is a destructive operation. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/mudbase/api/collections_api.rb', line 113 def collections_delete_with_http_info(project_id, collection_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CollectionsApi.collections_delete ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CollectionsApi.collections_delete" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling CollectionsApi.collections_delete" end # resource path local_var_path = '/api/schemas/projects/{projectId}/collections/{collectionId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MessageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"CollectionsApi.collections_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CollectionsApi#collections_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#collections_get(project_id, collection_id, opts = {}) ⇒ Collection
Get single collection Get collection details by ID. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
171 172 173 174 |
# File 'lib/mudbase/api/collections_api.rb', line 171 def collections_get(project_id, collection_id, opts = {}) data, _status_code, _headers = collections_get_with_http_info(project_id, collection_id, opts) data end |
#collections_get_with_http_info(project_id, collection_id, opts = {}) ⇒ Array<(Collection, Integer, Hash)>
Get single collection Get collection details by ID. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/mudbase/api/collections_api.rb', line 182 def collections_get_with_http_info(project_id, collection_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CollectionsApi.collections_get ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CollectionsApi.collections_get" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling CollectionsApi.collections_get" end # resource path local_var_path = '/api/schemas/projects/{projectId}/collections/{collectionId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Collection' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"CollectionsApi.collections_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CollectionsApi#collections_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#collections_list(project_id, opts = {}) ⇒ CollectionsList200Response
List collections in project List all collections in a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
239 240 241 242 |
# File 'lib/mudbase/api/collections_api.rb', line 239 def collections_list(project_id, opts = {}) data, _status_code, _headers = collections_list_with_http_info(project_id, opts) data end |
#collections_list_with_http_info(project_id, opts = {}) ⇒ Array<(CollectionsList200Response, Integer, Hash)>
List collections in project List all collections in a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/mudbase/api/collections_api.rb', line 249 def collections_list_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CollectionsApi.collections_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CollectionsApi.collections_list" end # resource path local_var_path = '/api/schemas/projects/{projectId}/collections'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CollectionsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"CollectionsApi.collections_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CollectionsApi#collections_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#collections_update(project_id, collection_id, update_collection_request, opts = {}) ⇒ CollectionsCreate201Response
Update collection Update collection configuration (name, fields, permissions). Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
304 305 306 307 |
# File 'lib/mudbase/api/collections_api.rb', line 304 def collections_update(project_id, collection_id, update_collection_request, opts = {}) data, _status_code, _headers = collections_update_with_http_info(project_id, collection_id, update_collection_request, opts) data end |
#collections_update_with_http_info(project_id, collection_id, update_collection_request, opts = {}) ⇒ Array<(CollectionsCreate201Response, Integer, Hash)>
Update collection Update collection configuration (name, fields, permissions). Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/mudbase/api/collections_api.rb', line 316 def collections_update_with_http_info(project_id, collection_id, update_collection_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CollectionsApi.collections_update ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CollectionsApi.collections_update" end # verify the required parameter 'collection_id' is set if @api_client.config.client_side_validation && collection_id.nil? fail ArgumentError, "Missing the required parameter 'collection_id' when calling CollectionsApi.collections_update" end # verify the required parameter 'update_collection_request' is set if @api_client.config.client_side_validation && update_collection_request.nil? fail ArgumentError, "Missing the required parameter 'update_collection_request' when calling CollectionsApi.collections_update" end # resource path local_var_path = '/api/schemas/projects/{projectId}/collections/{collectionId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'collectionId' + '}', CGI.escape(collection_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_collection_request) # return_type return_type = opts[:debug_return_type] || 'CollectionsCreate201Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"CollectionsApi.collections_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CollectionsApi#collections_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |