Class: Mudbase::CreateApiKeyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::CreateApiKeyRequest
- Defined in:
- lib/mudbase/models/create_api_key_request.rb
Overview
Payload to create an API key (name, projectId, permissions, rateLimit, expiresAt).
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
Optional.
-
#name ⇒ Object
Returns the value of attribute name.
-
#permissions ⇒ Object
Optional.
-
#project_id ⇒ Object
MongoDB ObjectId of the project.
-
#rate_limit ⇒ Object
Returns the value of attribute rate_limit.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApiKeyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateApiKeyRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::CreateApiKeyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::CreateApiKeyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'rate_limit') self.rate_limit = attributes[:'rate_limit'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end end |
Instance Attribute Details
#expires_at ⇒ Object
Optional. When provided, must be a valid ISO 8601 date-time in the future. Omit for no expiration.
30 31 32 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 30 def expires_at @expires_at end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 19 def name @name end |
#permissions ⇒ Object
Optional. Permission objects (resource + actions). Omit or pass [] for full access (all resources and actions). Include only the entries you want; remove resources or actions to restrict the key.
25 26 27 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 25 def end |
#project_id ⇒ Object
MongoDB ObjectId of the project
22 23 24 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 22 def project_id @project_id end |
#rate_limit ⇒ Object
Returns the value of attribute rate_limit.
27 28 29 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 27 def rate_limit @rate_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 33 def self.attribute_map { :'name' => :'name', :'project_id' => :'projectId', :'permissions' => :'permissions', :'rate_limit' => :'rateLimit', :'expires_at' => :'expiresAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 54 def self.openapi_types { :'name' => :'String', :'project_id' => :'String', :'permissions' => :'Array<ApiKeyPermission>', :'rate_limit' => :'RateLimit', :'expires_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 189 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && project_id == o.project_id && == o. && rate_limit == o.rate_limit && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 207 def hash [name, project_id, , rate_limit, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 2 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.') end if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end pattern = Regexp.new(/^[0-9a-fA-F]{24}$/) if @project_id !~ pattern invalid_properties.push("invalid value for \"project_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 152 |
# File 'lib/mudbase/models/create_api_key_request.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 2 return false if @project_id.nil? return false if @project_id !~ Regexp.new(/^[0-9a-fA-F]{24}$/) true end |