Class: Mudbase::CreateCheckoutSession200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::CreateCheckoutSession200ResponseData
- Defined in:
- lib/mudbase/models/create_checkout_session200_response_data.rb
Instance Attribute Summary collapse
-
#access_code ⇒ Object
Flutterwave access code.
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#asset ⇒ Object
Returns the value of attribute asset.
-
#authorization_url ⇒ Object
Flutterwave redirect URL (when Flutterwave is used).
-
#checkout_url ⇒ Object
Checkout/page URL (crypto) or null when Flutterwave.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#network ⇒ Object
Returns the value of attribute network.
-
#payment_address ⇒ Object
Returns the value of attribute payment_address.
-
#payment_id ⇒ Object
Payment intent ID (crypto).
-
#payment_options ⇒ Object
Multi-chain payment options (crypto).
-
#reference ⇒ Object
Payment reference (e.g. mudbase_xxx or pmt_xxx).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseData
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::CreateCheckoutSession200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::CreateCheckoutSession200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'checkout_url') self.checkout_url = attributes[:'checkout_url'] end if attributes.key?(:'authorization_url') self. = attributes[:'authorization_url'] end if attributes.key?(:'access_code') self.access_code = attributes[:'access_code'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'payment_id') self.payment_id = attributes[:'payment_id'] end if attributes.key?(:'payment_options') if (value = attributes[:'payment_options']).is_a?(Array) self. = value end end if attributes.key?(:'payment_address') self.payment_address = attributes[:'payment_address'] end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'asset') self.asset = attributes[:'asset'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end end |
Instance Attribute Details
#access_code ⇒ Object
Flutterwave access code
25 26 27 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 25 def access_code @access_code end |
#amount ⇒ Object
Returns the value of attribute amount.
42 43 44 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 42 def amount @amount end |
#asset ⇒ Object
Returns the value of attribute asset.
40 41 42 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 40 def asset @asset end |
#authorization_url ⇒ Object
Flutterwave redirect URL (when Flutterwave is used)
22 23 24 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 22 def end |
#checkout_url ⇒ Object
Checkout/page URL (crypto) or null when Flutterwave
19 20 21 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 19 def checkout_url @checkout_url end |
#currency ⇒ Object
Returns the value of attribute currency.
44 45 46 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 44 def currency @currency end |
#network ⇒ Object
Returns the value of attribute network.
38 39 40 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 38 def network @network end |
#payment_address ⇒ Object
Returns the value of attribute payment_address.
36 37 38 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 36 def payment_address @payment_address end |
#payment_id ⇒ Object
Payment intent ID (crypto)
31 32 33 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 31 def payment_id @payment_id end |
#payment_options ⇒ Object
Multi-chain payment options (crypto)
34 35 36 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 34 def end |
#reference ⇒ Object
Payment reference (e.g. mudbase_xxx or pmt_xxx)
28 29 30 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 28 def reference @reference end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 47 def self.attribute_map { :'checkout_url' => :'checkoutUrl', :'authorization_url' => :'authorizationUrl', :'access_code' => :'accessCode', :'reference' => :'reference', :'payment_id' => :'paymentId', :'payment_options' => :'paymentOptions', :'payment_address' => :'paymentAddress', :'network' => :'network', :'asset' => :'asset', :'amount' => :'amount', :'currency' => :'currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 74 def self.openapi_types { :'checkout_url' => :'String', :'authorization_url' => :'String', :'access_code' => :'String', :'reference' => :'String', :'payment_id' => :'String', :'payment_options' => :'Array<CreateCheckoutSession200ResponseDataPaymentOptionsInner>', :'payment_address' => :'String', :'network' => :'String', :'asset' => :'String', :'amount' => :'Float', :'currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && checkout_url == o.checkout_url && == o. && access_code == o.access_code && reference == o.reference && payment_id == o.payment_id && == o. && payment_address == o.payment_address && network == o.network && asset == o.asset && amount == o.amount && currency == o.currency end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 200 def hash [checkout_url, , access_code, reference, payment_id, , payment_address, network, asset, amount, currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 |
# File 'lib/mudbase/models/create_checkout_session200_response_data.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |