Class: Mudbase::CreateCheckoutSession200ResponseDataPaymentOptionsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::CreateCheckoutSession200ResponseDataPaymentOptionsInner
- Defined in:
- lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#asset ⇒ Object
Returns the value of attribute asset.
-
#chain ⇒ Object
Returns the value of attribute chain.
-
#invoice ⇒ Object
Returns the value of attribute invoice.
-
#network_fee ⇒ Object
Returns the value of attribute network_fee.
-
#total_due ⇒ Object
Returns the value of attribute total_due.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseDataPaymentOptionsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCheckoutSession200ResponseDataPaymentOptionsInner
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::CreateCheckoutSession200ResponseDataPaymentOptionsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::CreateCheckoutSession200ResponseDataPaymentOptionsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chain') self.chain = attributes[:'chain'] end if attributes.key?(:'asset') self.asset = attributes[:'asset'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'invoice') self.invoice = attributes[:'invoice'] end if attributes.key?(:'network_fee') self.network_fee = attributes[:'network_fee'] end if attributes.key?(:'total_due') self.total_due = attributes[:'total_due'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
22 23 24 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 22 def address @address end |
#asset ⇒ Object
Returns the value of attribute asset.
20 21 22 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 20 def asset @asset end |
#chain ⇒ Object
Returns the value of attribute chain.
18 19 20 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 18 def chain @chain end |
#invoice ⇒ Object
Returns the value of attribute invoice.
24 25 26 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 24 def invoice @invoice end |
#network_fee ⇒ Object
Returns the value of attribute network_fee.
26 27 28 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 26 def network_fee @network_fee end |
#total_due ⇒ Object
Returns the value of attribute total_due.
28 29 30 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 28 def total_due @total_due end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 53 def self.attribute_map { :'chain' => :'chain', :'asset' => :'asset', :'address' => :'address', :'invoice' => :'invoice', :'network_fee' => :'networkFee', :'total_due' => :'totalDue' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 75 def self.openapi_types { :'chain' => :'String', :'asset' => :'String', :'address' => :'String', :'invoice' => :'String', :'network_fee' => :'String', :'total_due' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 174 def ==(o) return true if self.equal?(o) self.class == o.class && chain == o.chain && asset == o.asset && address == o.address && invoice == o.invoice && network_fee == o.network_fee && total_due == o.total_due end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 193 def hash [chain, asset, address, invoice, network_fee, total_due].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 |
# File 'lib/mudbase/models/create_checkout_session200_response_data_payment_options_inner.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' chain_validator = EnumAttributeValidator.new('String', ["polygon", "arbitrum", "tron", "solana", "lightning", "ton"]) return false unless chain_validator.valid?(@chain) asset_validator = EnumAttributeValidator.new('String', ["USDC", "USDT", "BTC"]) return false unless asset_validator.valid?(@asset) true end |