Class: Mudbase::FileMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::FileMetadata
- Defined in:
- lib/mudbase/models/file_metadata.rb
Overview
File metadata (id, filename, originalName, mimeType, size, url).
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#bucket ⇒ Object
Returns the value of attribute bucket.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#is_public ⇒ Object
Returns the value of attribute is_public.
-
#mime_type ⇒ Object
Returns the value of attribute mime_type.
-
#original_name ⇒ Object
Returns the value of attribute original_name.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#public_url ⇒ Object
Returns the value of attribute public_url.
-
#size ⇒ Object
Returns the value of attribute size.
-
#uploaded_by ⇒ Object
Returns the value of attribute uploaded_by.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FileMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FileMetadata
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/mudbase/models/file_metadata.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::FileMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::FileMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'filename') self.filename = attributes[:'filename'] end if attributes.key?(:'original_name') self.original_name = attributes[:'original_name'] end if attributes.key?(:'mime_type') self.mime_type = attributes[:'mime_type'] end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'public_url') self.public_url = attributes[:'public_url'] end if attributes.key?(:'bucket') self.bucket = attributes[:'bucket'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] end if attributes.key?(:'uploaded_by') self.uploaded_by = attributes[:'uploaded_by'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/file_metadata.rb', line 19 def _id @_id end |
#bucket ⇒ Object
Returns the value of attribute bucket.
33 34 35 |
# File 'lib/mudbase/models/file_metadata.rb', line 33 def bucket @bucket end |
#created_at ⇒ Object
Returns the value of attribute created_at.
41 42 43 |
# File 'lib/mudbase/models/file_metadata.rb', line 41 def created_at @created_at end |
#filename ⇒ Object
Returns the value of attribute filename.
21 22 23 |
# File 'lib/mudbase/models/file_metadata.rb', line 21 def filename @filename end |
#is_public ⇒ Object
Returns the value of attribute is_public.
37 38 39 |
# File 'lib/mudbase/models/file_metadata.rb', line 37 def is_public @is_public end |
#mime_type ⇒ Object
Returns the value of attribute mime_type.
25 26 27 |
# File 'lib/mudbase/models/file_metadata.rb', line 25 def mime_type @mime_type end |
#original_name ⇒ Object
Returns the value of attribute original_name.
23 24 25 |
# File 'lib/mudbase/models/file_metadata.rb', line 23 def original_name @original_name end |
#project_id ⇒ Object
Returns the value of attribute project_id.
35 36 37 |
# File 'lib/mudbase/models/file_metadata.rb', line 35 def project_id @project_id end |
#public_url ⇒ Object
Returns the value of attribute public_url.
31 32 33 |
# File 'lib/mudbase/models/file_metadata.rb', line 31 def public_url @public_url end |
#size ⇒ Object
Returns the value of attribute size.
27 28 29 |
# File 'lib/mudbase/models/file_metadata.rb', line 27 def size @size end |
#uploaded_by ⇒ Object
Returns the value of attribute uploaded_by.
39 40 41 |
# File 'lib/mudbase/models/file_metadata.rb', line 39 def uploaded_by @uploaded_by end |
#url ⇒ Object
Returns the value of attribute url.
29 30 31 |
# File 'lib/mudbase/models/file_metadata.rb', line 29 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/mudbase/models/file_metadata.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/mudbase/models/file_metadata.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mudbase/models/file_metadata.rb', line 44 def self.attribute_map { :'_id' => :'_id', :'filename' => :'filename', :'original_name' => :'originalName', :'mime_type' => :'mimeType', :'size' => :'size', :'url' => :'url', :'public_url' => :'publicUrl', :'bucket' => :'bucket', :'project_id' => :'projectId', :'is_public' => :'isPublic', :'uploaded_by' => :'uploadedBy', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/mudbase/models/file_metadata.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/mudbase/models/file_metadata.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mudbase/models/file_metadata.rb', line 72 def self.openapi_types { :'_id' => :'String', :'filename' => :'String', :'original_name' => :'String', :'mime_type' => :'String', :'size' => :'Integer', :'url' => :'String', :'public_url' => :'String', :'bucket' => :'String', :'project_id' => :'String', :'is_public' => :'Boolean', :'uploaded_by' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/mudbase/models/file_metadata.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && filename == o.filename && original_name == o.original_name && mime_type == o.mime_type && size == o.size && url == o.url && public_url == o.public_url && bucket == o.bucket && project_id == o.project_id && is_public == o.is_public && uploaded_by == o.uploaded_by && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/mudbase/models/file_metadata.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/mudbase/models/file_metadata.rb', line 202 def hash [_id, filename, original_name, mime_type, size, url, public_url, bucket, project_id, is_public, uploaded_by, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 |
# File 'lib/mudbase/models/file_metadata.rb', line 162 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/mudbase/models/file_metadata.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 |
# File 'lib/mudbase/models/file_metadata.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |