Class: Mudbase::Function
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::Function
- Defined in:
- lib/mudbase/models/function.rb
Overview
Serverless function entity (id, name, description, projectId, trigger, stats, isActive).
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#description ⇒ Object
Returns the value of attribute description.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#stats ⇒ Object
Returns the value of attribute stats.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Function
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Function
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/mudbase/models/function.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Function` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Function`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/function.rb', line 19 def _id @_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
35 36 37 |
# File 'lib/mudbase/models/function.rb', line 35 def created_at @created_at end |
#created_by ⇒ Object
Returns the value of attribute created_by.
33 34 35 |
# File 'lib/mudbase/models/function.rb', line 33 def created_by @created_by end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/mudbase/models/function.rb', line 23 def description @description end |
#is_active ⇒ Object
Returns the value of attribute is_active.
31 32 33 |
# File 'lib/mudbase/models/function.rb', line 31 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/mudbase/models/function.rb', line 21 def name @name end |
#project_id ⇒ Object
Returns the value of attribute project_id.
25 26 27 |
# File 'lib/mudbase/models/function.rb', line 25 def project_id @project_id end |
#stats ⇒ Object
Returns the value of attribute stats.
29 30 31 |
# File 'lib/mudbase/models/function.rb', line 29 def stats @stats end |
#trigger ⇒ Object
Returns the value of attribute trigger.
27 28 29 |
# File 'lib/mudbase/models/function.rb', line 27 def trigger @trigger end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
37 38 39 |
# File 'lib/mudbase/models/function.rb', line 37 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/mudbase/models/function.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/mudbase/models/function.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/mudbase/models/function.rb', line 40 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'description' => :'description', :'project_id' => :'projectId', :'trigger' => :'trigger', :'stats' => :'stats', :'is_active' => :'isActive', :'created_by' => :'createdBy', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/mudbase/models/function.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/mudbase/models/function.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mudbase/models/function.rb', line 66 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'description' => :'String', :'project_id' => :'String', :'trigger' => :'FunctionTrigger', :'stats' => :'FunctionStats', :'is_active' => :'Boolean', :'created_by' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/mudbase/models/function.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && description == o.description && project_id == o.project_id && trigger == o.trigger && stats == o.stats && is_active == o.is_active && created_by == o.created_by && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/mudbase/models/function.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/mudbase/models/function.rb', line 184 def hash [_id, name, description, project_id, trigger, stats, is_active, created_by, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/mudbase/models/function.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/mudbase/models/function.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/mudbase/models/function.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |