Class: Mudbase::FunctionExecution

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/function_execution.rb

Overview

Single function execution record (id, executedAt, executionTime, success, payload, result, error).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FunctionExecution

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/mudbase/models/function_execution.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::FunctionExecution` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::FunctionExecution`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'executed_at')
    self.executed_at = attributes[:'executed_at']
  end

  if attributes.key?(:'execution_time')
    self.execution_time = attributes[:'execution_time']
  end

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'trigger_type')
    self.trigger_type = attributes[:'trigger_type']
  end

  if attributes.key?(:'trigger_event')
    self.trigger_event = attributes[:'trigger_event']
  end

  if attributes.key?(:'invoked_by')
    self.invoked_by = attributes[:'invoked_by']
  end

  if attributes.key?(:'retry_count')
    self.retry_count = attributes[:'retry_count']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



19
20
21
# File 'lib/mudbase/models/function_execution.rb', line 19

def _id
  @_id
end

#errorObject

Returns the value of attribute error.



31
32
33
# File 'lib/mudbase/models/function_execution.rb', line 31

def error
  @error
end

#executed_atObject

Returns the value of attribute executed_at.



21
22
23
# File 'lib/mudbase/models/function_execution.rb', line 21

def executed_at
  @executed_at
end

#execution_timeObject

Returns the value of attribute execution_time.



23
24
25
# File 'lib/mudbase/models/function_execution.rb', line 23

def execution_time
  @execution_time
end

#invoked_byObject

Returns the value of attribute invoked_by.



37
38
39
# File 'lib/mudbase/models/function_execution.rb', line 37

def invoked_by
  @invoked_by
end

#payloadObject

Returns the value of attribute payload.



27
28
29
# File 'lib/mudbase/models/function_execution.rb', line 27

def payload
  @payload
end

#resultObject

Returns the value of attribute result.



29
30
31
# File 'lib/mudbase/models/function_execution.rb', line 29

def result
  @result
end

#retry_countObject

Returns the value of attribute retry_count.



39
40
41
# File 'lib/mudbase/models/function_execution.rb', line 39

def retry_count
  @retry_count
end

#successObject

Returns the value of attribute success.



25
26
27
# File 'lib/mudbase/models/function_execution.rb', line 25

def success
  @success
end

#trigger_eventObject

Returns the value of attribute trigger_event.



35
36
37
# File 'lib/mudbase/models/function_execution.rb', line 35

def trigger_event
  @trigger_event
end

#trigger_typeObject

Returns the value of attribute trigger_type.



33
34
35
# File 'lib/mudbase/models/function_execution.rb', line 33

def trigger_type
  @trigger_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/mudbase/models/function_execution.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/mudbase/models/function_execution.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/mudbase/models/function_execution.rb', line 64

def self.attribute_map
  {
    :'_id' => :'_id',
    :'executed_at' => :'executedAt',
    :'execution_time' => :'executionTime',
    :'success' => :'success',
    :'payload' => :'payload',
    :'result' => :'result',
    :'error' => :'error',
    :'trigger_type' => :'triggerType',
    :'trigger_event' => :'triggerEvent',
    :'invoked_by' => :'invokedBy',
    :'retry_count' => :'retryCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/mudbase/models/function_execution.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/mudbase/models/function_execution.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/mudbase/models/function_execution.rb', line 91

def self.openapi_types
  {
    :'_id' => :'String',
    :'executed_at' => :'Time',
    :'execution_time' => :'Integer',
    :'success' => :'Boolean',
    :'payload' => :'Object',
    :'result' => :'Object',
    :'error' => :'String',
    :'trigger_type' => :'String',
    :'trigger_event' => :'String',
    :'invoked_by' => :'String',
    :'retry_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/mudbase/models/function_execution.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      executed_at == o.executed_at &&
      execution_time == o.execution_time &&
      success == o.success &&
      payload == o.payload &&
      result == o.result &&
      error == o.error &&
      trigger_type == o.trigger_type &&
      trigger_event == o.trigger_event &&
      invoked_by == o.invoked_by &&
      retry_count == o.retry_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


221
222
223
# File 'lib/mudbase/models/function_execution.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



227
228
229
# File 'lib/mudbase/models/function_execution.rb', line 227

def hash
  [_id, executed_at, execution_time, success, payload, result, error, trigger_type, trigger_event, invoked_by, retry_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
# File 'lib/mudbase/models/function_execution.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/mudbase/models/function_execution.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



184
185
186
187
188
189
# File 'lib/mudbase/models/function_execution.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  invoked_by_validator = EnumAttributeValidator.new('String', ["manual", "api_key", "trigger", "cron"])
  return false unless invoked_by_validator.valid?(@invoked_by)
  true
end