Class: Mudbase::GetSubscriptionTiers200ResponsePlansInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::GetSubscriptionTiers200ResponsePlansInner
- Defined in:
- lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#description ⇒ Object
Returns the value of attribute description.
-
#enforcement ⇒ Object
Per-resource enforcement (blocking, billing_only, etc.).
-
#id ⇒ Object
Returns the value of attribute id.
-
#limits ⇒ Object
Returns the value of attribute limits.
-
#name ⇒ Object
Returns the value of attribute name.
-
#overages ⇒ Object
Returns the value of attribute overages.
-
#price ⇒ Object
Monthly price in cents.
-
#price_id ⇒ Object
Returns the value of attribute price_id.
-
#price_yearly ⇒ Object
Yearly price in cents (8% off).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetSubscriptionTiers200ResponsePlansInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetSubscriptionTiers200ResponsePlansInner
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetSubscriptionTiers200ResponsePlansInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetSubscriptionTiers200ResponsePlansInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'price_yearly') self.price_yearly = attributes[:'price_yearly'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'price_id') self.price_id = attributes[:'price_id'] end if attributes.key?(:'limits') self.limits = attributes[:'limits'] end if attributes.key?(:'overages') self.overages = attributes[:'overages'] end if attributes.key?(:'enforcement') self.enforcement = attributes[:'enforcement'] end end |
Instance Attribute Details
#currency ⇒ Object
Returns the value of attribute currency.
30 31 32 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 30 def currency @currency end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 22 def description @description end |
#enforcement ⇒ Object
Per-resource enforcement (blocking, billing_only, etc.)
39 40 41 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 39 def enforcement @enforcement end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 18 def id @id end |
#limits ⇒ Object
Returns the value of attribute limits.
34 35 36 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 34 def limits @limits end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 20 def name @name end |
#overages ⇒ Object
Returns the value of attribute overages.
36 37 38 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 36 def overages @overages end |
#price ⇒ Object
Monthly price in cents
25 26 27 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 25 def price @price end |
#price_id ⇒ Object
Returns the value of attribute price_id.
32 33 34 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 32 def price_id @price_id end |
#price_yearly ⇒ Object
Yearly price in cents (8% off)
28 29 30 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 28 def price_yearly @price_yearly end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 42 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'price' => :'price', :'price_yearly' => :'priceYearly', :'currency' => :'currency', :'price_id' => :'priceId', :'limits' => :'limits', :'overages' => :'overages', :'enforcement' => :'enforcement' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 84 def self.openapi_nullable Set.new([ :'price_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 68 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'price' => :'Float', :'price_yearly' => :'Float', :'currency' => :'String', :'price_id' => :'String', :'limits' => :'Object', :'overages' => :'Object', :'enforcement' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && price == o.price && price_yearly == o.price_yearly && currency == o.currency && price_id == o.price_id && limits == o.limits && overages == o.overages && enforcement == o.enforcement end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 187 def hash [id, name, description, price, price_yearly, currency, price_id, limits, overages, enforcement].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 |
# File 'lib/mudbase/models/get_subscription_tiers200_response_plans_inner.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |