Class: Mudbase::GetTransaction200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/get_transaction200_response_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetTransaction200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::GetTransaction200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::GetTransaction200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'to_address')
    self.to_address = attributes[:'to_address']
  end

  if attributes.key?(:'from_address')
    self.from_address = attributes[:'from_address']
  end

  if attributes.key?(:'main_tx_hash')
    self.main_tx_hash = attributes[:'main_tx_hash']
  end

  if attributes.key?(:'main_tx_status')
    self.main_tx_status = attributes[:'main_tx_status']
  end

  if attributes.key?(:'network_fee')
    self.network_fee = attributes[:'network_fee']
  end

  if attributes.key?(:'platform_fee')
    self.platform_fee = attributes[:'platform_fee']
  end

  if attributes.key?(:'project_fee')
    self.project_fee = attributes[:'project_fee']
  end

  if attributes.key?(:'refund_tx_hash')
    self.refund_tx_hash = attributes[:'refund_tx_hash']
  end

  if attributes.key?(:'refund_status')
    self.refund_status = attributes[:'refund_status']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 18

def _id
  @_id
end

#amountObject

Returns the value of attribute amount.



24
25
26
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 24

def amount
  @amount
end

#created_atObject

Returns the value of attribute created_at.



48
49
50
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 48

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



22
23
24
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 22

def currency
  @currency
end

#errorObject

Returns the value of attribute error.



46
47
48
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 46

def error
  @error
end

#from_addressObject

Returns the value of attribute from_address.



28
29
30
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 28

def from_address
  @from_address
end

#main_tx_hashObject

Returns the value of attribute main_tx_hash.



30
31
32
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 30

def main_tx_hash
  @main_tx_hash
end

#main_tx_statusObject

Returns the value of attribute main_tx_status.



32
33
34
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 32

def main_tx_status
  @main_tx_status
end

#network_feeObject

Returns the value of attribute network_fee.



34
35
36
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 34

def network_fee
  @network_fee
end

#platform_feeObject

Returns the value of attribute platform_fee.



36
37
38
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 36

def platform_fee
  @platform_fee
end

#project_feeObject

Returns the value of attribute project_fee.



38
39
40
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 38

def project_fee
  @project_fee
end

#refund_statusObject

Returns the value of attribute refund_status.



42
43
44
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 42

def refund_status
  @refund_status
end

#refund_tx_hashObject

Returns the value of attribute refund_tx_hash.



40
41
42
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 40

def refund_tx_hash
  @refund_tx_hash
end

#statusObject

Returns the value of attribute status.



44
45
46
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 44

def status
  @status
end

#to_addressObject

Returns the value of attribute to_address.



26
27
28
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 26

def to_address
  @to_address
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 73

def self.attribute_map
  {
    :'_id' => :'_id',
    :'type' => :'type',
    :'currency' => :'currency',
    :'amount' => :'amount',
    :'to_address' => :'toAddress',
    :'from_address' => :'fromAddress',
    :'main_tx_hash' => :'mainTxHash',
    :'main_tx_status' => :'mainTxStatus',
    :'network_fee' => :'networkFee',
    :'platform_fee' => :'platformFee',
    :'project_fee' => :'projectFee',
    :'refund_tx_hash' => :'refundTxHash',
    :'refund_status' => :'refundStatus',
    :'status' => :'status',
    :'error' => :'error',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 105

def self.openapi_types
  {
    :'_id' => :'String',
    :'type' => :'String',
    :'currency' => :'String',
    :'amount' => :'Float',
    :'to_address' => :'String',
    :'from_address' => :'String',
    :'main_tx_hash' => :'String',
    :'main_tx_status' => :'String',
    :'network_fee' => :'Float',
    :'platform_fee' => :'Float',
    :'project_fee' => :'Float',
    :'refund_tx_hash' => :'String',
    :'refund_status' => :'String',
    :'status' => :'String',
    :'error' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 278

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      type == o.type &&
      currency == o.currency &&
      amount == o.amount &&
      to_address == o.to_address &&
      from_address == o.from_address &&
      main_tx_hash == o.main_tx_hash &&
      main_tx_status == o.main_tx_status &&
      network_fee == o.network_fee &&
      platform_fee == o.platform_fee &&
      project_fee == o.project_fee &&
      refund_tx_hash == o.refund_tx_hash &&
      refund_status == o.refund_status &&
      status == o.status &&
      error == o.error &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 307

def hash
  [_id, type, currency, amount, to_address, from_address, main_tx_hash, main_tx_status, network_fee, platform_fee, project_fee, refund_tx_hash, refund_status, status, error, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 215

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/mudbase/models/get_transaction200_response_data.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["withdrawal", "deposit", "fee_refund", "platform_fee_deduction"])
  return false unless type_validator.valid?(@type)
  main_tx_status_validator = EnumAttributeValidator.new('String', ["pending", "broadcast", "confirmed", "failed"])
  return false unless main_tx_status_validator.valid?(@main_tx_status)
  refund_status_validator = EnumAttributeValidator.new('String', ["pending", "broadcast", "confirmed", "failed"])
  return false unless refund_status_validator.valid?(@refund_status)
  status_validator = EnumAttributeValidator.new('String', ["processing", "completed", "partial", "failed"])
  return false unless status_validator.valid?(@status)
  true
end