Class: Mudbase::HealthResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::HealthResponse
- Defined in:
- lib/mudbase/models/health_response.rb
Overview
Health check response (status, timestamp, services, version, uptime).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#services ⇒ Object
Returns the value of attribute services.
-
#status ⇒ Object
Returns the value of attribute status.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
-
#uptime ⇒ Object
Returns the value of attribute uptime.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HealthResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ HealthResponse
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/mudbase/models/health_response.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::HealthResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::HealthResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'services') self.services = attributes[:'services'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'uptime') self.uptime = attributes[:'uptime'] end end |
Instance Attribute Details
#services ⇒ Object
Returns the value of attribute services.
23 24 25 |
# File 'lib/mudbase/models/health_response.rb', line 23 def services @services end |
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/mudbase/models/health_response.rb', line 19 def status @status end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
21 22 23 |
# File 'lib/mudbase/models/health_response.rb', line 21 def end |
#uptime ⇒ Object
Returns the value of attribute uptime.
27 28 29 |
# File 'lib/mudbase/models/health_response.rb', line 27 def uptime @uptime end |
#version ⇒ Object
Returns the value of attribute version.
25 26 27 |
# File 'lib/mudbase/models/health_response.rb', line 25 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/mudbase/models/health_response.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/mudbase/models/health_response.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 |
# File 'lib/mudbase/models/health_response.rb', line 52 def self.attribute_map { :'status' => :'status', :'timestamp' => :'timestamp', :'services' => :'services', :'version' => :'version', :'uptime' => :'uptime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/mudbase/models/health_response.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/mudbase/models/health_response.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/mudbase/models/health_response.rb', line 73 def self.openapi_types { :'status' => :'String', :'timestamp' => :'Time', :'services' => :'HealthResponseServices', :'version' => :'String', :'uptime' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 |
# File 'lib/mudbase/models/health_response.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && == o. && services == o.services && version == o.version && uptime == o.uptime end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/mudbase/models/health_response.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/mudbase/models/health_response.rb', line 173 def hash [status, , services, version, uptime].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 |
# File 'lib/mudbase/models/health_response.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/mudbase/models/health_response.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 |
# File 'lib/mudbase/models/health_response.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["healthy", "unhealthy"]) return false unless status_validator.valid?(@status) true end |