Class: Mudbase::IntegrationsApi
- Inherits:
-
Object
- Object
- Mudbase::IntegrationsApi
- Defined in:
- lib/mudbase/api/integrations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ IntegrationsApi
constructor
A new instance of IntegrationsApi.
-
#integrations_execute(project_id, integration_id, integrations_execute_request, opts = {}) ⇒ WalletTestWebhook200Response
Execute integration Execute an integration action (API call) with specified endpoint and parameters.
-
#integrations_execute_with_http_info(project_id, integration_id, integrations_execute_request, opts = {}) ⇒ Array<(WalletTestWebhook200Response, Integer, Hash)>
Execute integration Execute an integration action (API call) with specified endpoint and parameters.
-
#integrations_list(project_id, opts = {}) ⇒ IntegrationsList200Response
Get project integrations List all integrations configured for a project.
-
#integrations_list_with_http_info(project_id, opts = {}) ⇒ Array<(IntegrationsList200Response, Integer, Hash)>
Get project integrations List all integrations configured for a project.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IntegrationsApi
Returns a new instance of IntegrationsApi.
19 20 21 |
# File 'lib/mudbase/api/integrations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/integrations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#integrations_execute(project_id, integration_id, integrations_execute_request, opts = {}) ⇒ WalletTestWebhook200Response
Execute integration Execute an integration action (API call) with specified endpoint and parameters. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
29 30 31 32 |
# File 'lib/mudbase/api/integrations_api.rb', line 29 def integrations_execute(project_id, integration_id, integrations_execute_request, opts = {}) data, _status_code, _headers = integrations_execute_with_http_info(project_id, integration_id, integrations_execute_request, opts) data end |
#integrations_execute_with_http_info(project_id, integration_id, integrations_execute_request, opts = {}) ⇒ Array<(WalletTestWebhook200Response, Integer, Hash)>
Execute integration Execute an integration action (API call) with specified endpoint and parameters. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/mudbase/api/integrations_api.rb', line 41 def integrations_execute_with_http_info(project_id, integration_id, integrations_execute_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_execute ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling IntegrationsApi.integrations_execute" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsApi.integrations_execute" end # verify the required parameter 'integrations_execute_request' is set if @api_client.config.client_side_validation && integrations_execute_request.nil? fail ArgumentError, "Missing the required parameter 'integrations_execute_request' when calling IntegrationsApi.integrations_execute" end # resource path local_var_path = '/api/integrations/projects/{projectId}/integrations/{integrationId}/execute'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(integrations_execute_request) # return_type return_type = opts[:debug_return_type] || 'WalletTestWebhook200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"IntegrationsApi.integrations_execute", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_execute\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_list(project_id, opts = {}) ⇒ IntegrationsList200Response
Get project integrations List all integrations configured for a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
107 108 109 110 |
# File 'lib/mudbase/api/integrations_api.rb', line 107 def integrations_list(project_id, opts = {}) data, _status_code, _headers = integrations_list_with_http_info(project_id, opts) data end |
#integrations_list_with_http_info(project_id, opts = {}) ⇒ Array<(IntegrationsList200Response, Integer, Hash)>
Get project integrations List all integrations configured for a project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/mudbase/api/integrations_api.rb', line 117 def integrations_list_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling IntegrationsApi.integrations_list" end # resource path local_var_path = '/api/integrations/projects/{projectId}/integrations'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IntegrationsList200Response' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"IntegrationsApi.integrations_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |