Class: Mudbase::Message
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::Message
- Defined in:
- lib/mudbase/models/message.rb
Overview
Single message record (id, type, title, body, recipients, status, sentAt).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#body ⇒ Object
Returns the value of attribute body.
-
#failure_count ⇒ Object
Returns the value of attribute failure_count.
-
#recipients ⇒ Object
Returns the value of attribute recipients.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#success_count ⇒ Object
Returns the value of attribute success_count.
-
#title ⇒ Object
Returns the value of attribute title.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Message
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Message
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/mudbase/models/message.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Message` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Message`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'recipients') self.recipients = attributes[:'recipients'] end if attributes.key?(:'success_count') self.success_count = attributes[:'success_count'] end if attributes.key?(:'failure_count') self.failure_count = attributes[:'failure_count'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/message.rb', line 19 def _id @_id end |
#body ⇒ Object
Returns the value of attribute body.
25 26 27 |
# File 'lib/mudbase/models/message.rb', line 25 def body @body end |
#failure_count ⇒ Object
Returns the value of attribute failure_count.
33 34 35 |
# File 'lib/mudbase/models/message.rb', line 33 def failure_count @failure_count end |
#recipients ⇒ Object
Returns the value of attribute recipients.
29 30 31 |
# File 'lib/mudbase/models/message.rb', line 29 def recipients @recipients end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
37 38 39 |
# File 'lib/mudbase/models/message.rb', line 37 def sent_at @sent_at end |
#status ⇒ Object
Returns the value of attribute status.
35 36 37 |
# File 'lib/mudbase/models/message.rb', line 35 def status @status end |
#subject ⇒ Object
Returns the value of attribute subject.
27 28 29 |
# File 'lib/mudbase/models/message.rb', line 27 def subject @subject end |
#success_count ⇒ Object
Returns the value of attribute success_count.
31 32 33 |
# File 'lib/mudbase/models/message.rb', line 31 def success_count @success_count end |
#title ⇒ Object
Returns the value of attribute title.
23 24 25 |
# File 'lib/mudbase/models/message.rb', line 23 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
21 22 23 |
# File 'lib/mudbase/models/message.rb', line 21 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/mudbase/models/message.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/mudbase/models/message.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mudbase/models/message.rb', line 62 def self.attribute_map { :'_id' => :'_id', :'type' => :'type', :'title' => :'title', :'body' => :'body', :'subject' => :'subject', :'recipients' => :'recipients', :'success_count' => :'successCount', :'failure_count' => :'failureCount', :'status' => :'status', :'sent_at' => :'sentAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/mudbase/models/message.rb', line 237 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/mudbase/models/message.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/mudbase/models/message.rb', line 88 def self.openapi_types { :'_id' => :'String', :'type' => :'String', :'title' => :'String', :'body' => :'String', :'subject' => :'String', :'recipients' => :'Integer', :'success_count' => :'Integer', :'failure_count' => :'Integer', :'status' => :'String', :'sent_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/mudbase/models/message.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && type == o.type && title == o.title && body == o.body && subject == o.subject && recipients == o.recipients && success_count == o.success_count && failure_count == o.failure_count && status == o.status && sent_at == o.sent_at end |
#eql?(o) ⇒ Boolean
224 225 226 |
# File 'lib/mudbase/models/message.rb', line 224 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
230 231 232 |
# File 'lib/mudbase/models/message.rb', line 230 def hash [_id, type, title, body, subject, recipients, success_count, failure_count, status, sent_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 |
# File 'lib/mudbase/models/message.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/mudbase/models/message.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 |
# File 'lib/mudbase/models/message.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["push", "email", "sms"]) return false unless type_validator.valid?(@type) status_validator = EnumAttributeValidator.new('String', ["sent", "failed", "pending"]) return false unless status_validator.valid?(@status) true end |