Class: Mudbase::OrgDomainsListResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::OrgDomainsListResponse
- Defined in:
- lib/mudbase/models/org_domains_list_response.rb
Instance Attribute Summary collapse
-
#api_base_url ⇒ Object
Returns the value of attribute api_base_url.
-
#custom_domain_allowed ⇒ Object
Returns the value of attribute custom_domain_allowed.
-
#dns_verification_instructions ⇒ Object
Plain-language reminder to add the ownership TXT from each domain’s DNS checklist, then use Verify DNS in the organization’s domain settings.
-
#domains ⇒ Object
Returns the value of attribute domains.
-
#max_domains ⇒ Object
Returns the value of attribute max_domains.
-
#primary_hostname ⇒ Object
Returns the value of attribute primary_hostname.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrgDomainsListResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrgDomainsListResponse
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::OrgDomainsListResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::OrgDomainsListResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'domains') if (value = attributes[:'domains']).is_a?(Array) self.domains = value end end if attributes.key?(:'dns_verification_instructions') self.dns_verification_instructions = attributes[:'dns_verification_instructions'] end if attributes.key?(:'primary_hostname') self.primary_hostname = attributes[:'primary_hostname'] end if attributes.key?(:'api_base_url') self.api_base_url = attributes[:'api_base_url'] end if attributes.key?(:'max_domains') self.max_domains = attributes[:'max_domains'] end if attributes.key?(:'custom_domain_allowed') self.custom_domain_allowed = attributes[:'custom_domain_allowed'] end end |
Instance Attribute Details
#api_base_url ⇒ Object
Returns the value of attribute api_base_url.
25 26 27 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 25 def api_base_url @api_base_url end |
#custom_domain_allowed ⇒ Object
Returns the value of attribute custom_domain_allowed.
29 30 31 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 29 def custom_domain_allowed @custom_domain_allowed end |
#dns_verification_instructions ⇒ Object
Plain-language reminder to add the ownership TXT from each domain’s DNS checklist, then use Verify DNS in the organization’s domain settings.
21 22 23 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 21 def dns_verification_instructions @dns_verification_instructions end |
#domains ⇒ Object
Returns the value of attribute domains.
18 19 20 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 18 def domains @domains end |
#max_domains ⇒ Object
Returns the value of attribute max_domains.
27 28 29 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 27 def max_domains @max_domains end |
#primary_hostname ⇒ Object
Returns the value of attribute primary_hostname.
23 24 25 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 23 def primary_hostname @primary_hostname end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 32 def self.attribute_map { :'domains' => :'domains', :'dns_verification_instructions' => :'dnsVerificationInstructions', :'primary_hostname' => :'primaryHostname', :'api_base_url' => :'apiBaseUrl', :'max_domains' => :'maxDomains', :'custom_domain_allowed' => :'customDomainAllowed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 66 def self.openapi_nullable Set.new([ :'primary_hostname', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 54 def self.openapi_types { :'domains' => :'Array<OrgDomainEntryOrgConsole>', :'dns_verification_instructions' => :'String', :'primary_hostname' => :'String', :'api_base_url' => :'String', :'max_domains' => :'Integer', :'custom_domain_allowed' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && domains == o.domains && dns_verification_instructions == o.dns_verification_instructions && primary_hostname == o.primary_hostname && api_base_url == o.api_base_url && max_domains == o.max_domains && custom_domain_allowed == o.custom_domain_allowed end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 151 def hash [domains, dns_verification_instructions, primary_hostname, api_base_url, max_domains, custom_domain_allowed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 |
# File 'lib/mudbase/models/org_domains_list_response.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |