Class: Mudbase::Organization

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/organization.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Organization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/mudbase/models/organization.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Organization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Organization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'logo')
    self. = attributes[:'logo']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'limits')
    self.limits = attributes[:'limits']
  end

  if attributes.key?(:'billing')
    self.billing = attributes[:'billing']
  end

  if attributes.key?(:'settings')
    self.settings = attributes[:'settings']
  end

  if attributes.key?(:'deployment_type')
    self.deployment_type = attributes[:'deployment_type']
  end

  if attributes.key?(:'dedicated')
    self.dedicated = attributes[:'dedicated']
  end

  if attributes.key?(:'preferred_region')
    self.preferred_region = attributes[:'preferred_region']
  end

  if attributes.key?(:'infrastructure_environments')
    if (value = attributes[:'infrastructure_environments']).is_a?(Array)
      self.infrastructure_environments = value
    end
  end

  if attributes.key?(:'allowed_domains')
    if (value = attributes[:'allowed_domains']).is_a?(Array)
      self.allowed_domains = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/mudbase/models/organization.rb', line 18

def _id
  @_id
end

#allowed_domainsObject

Returns the value of attribute allowed_domains.



51
52
53
# File 'lib/mudbase/models/organization.rb', line 51

def allowed_domains
  @allowed_domains
end

#billingObject

Returns the value of attribute billing.



37
38
39
# File 'lib/mudbase/models/organization.rb', line 37

def billing
  @billing
end

#created_atObject

Returns the value of attribute created_at.



53
54
55
# File 'lib/mudbase/models/organization.rb', line 53

def created_at
  @created_at
end

#dedicatedObject

Dedicated API/DB routing; may include edgeTlsStatus, infraMeteringLastReportAt.



45
46
47
# File 'lib/mudbase/models/organization.rb', line 45

def dedicated
  @dedicated
end

#deployment_typeObject

Returns the value of attribute deployment_type.



42
43
44
# File 'lib/mudbase/models/organization.rb', line 42

def deployment_type
  @deployment_type
end

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/mudbase/models/organization.rb', line 24

def description
  @description
end

#infrastructure_environmentsObject

Returns the value of attribute infrastructure_environments.



49
50
51
# File 'lib/mudbase/models/organization.rb', line 49

def infrastructure_environments
  @infrastructure_environments
end

#limitsObject

Returns the value of attribute limits.



35
36
37
# File 'lib/mudbase/models/organization.rb', line 35

def limits
  @limits
end

#logoObject

Optional logo URL. Org-related emails use the platform logo (env); this field is for legacy or future UI use only.



27
28
29
# File 'lib/mudbase/models/organization.rb', line 27

def 
  @logo
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/mudbase/models/organization.rb', line 20

def name
  @name
end

#planObject

Returns the value of attribute plan.



31
32
33
# File 'lib/mudbase/models/organization.rb', line 31

def plan
  @plan
end

#preferred_regionObject

Returns the value of attribute preferred_region.



47
48
49
# File 'lib/mudbase/models/organization.rb', line 47

def preferred_region
  @preferred_region
end

#settingsObject

May include customDomainAddon (optional billing/legacy flag; not required for custom domains on Growth/Scale).



40
41
42
# File 'lib/mudbase/models/organization.rb', line 40

def settings
  @settings
end

#slugObject

Returns the value of attribute slug.



22
23
24
# File 'lib/mudbase/models/organization.rb', line 22

def slug
  @slug
end

#updated_atObject

Returns the value of attribute updated_at.



55
56
57
# File 'lib/mudbase/models/organization.rb', line 55

def updated_at
  @updated_at
end

#usageObject

Returns the value of attribute usage.



33
34
35
# File 'lib/mudbase/models/organization.rb', line 33

def usage
  @usage
end

#websiteObject

Returns the value of attribute website.



29
30
31
# File 'lib/mudbase/models/organization.rb', line 29

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



104
105
106
# File 'lib/mudbase/models/organization.rb', line 104

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/mudbase/models/organization.rb', line 109

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/mudbase/models/organization.rb', line 80

def self.attribute_map
  {
    :'_id' => :'_id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'description' => :'description',
    :'logo' => :'logo',
    :'website' => :'website',
    :'plan' => :'plan',
    :'usage' => :'usage',
    :'limits' => :'limits',
    :'billing' => :'billing',
    :'settings' => :'settings',
    :'deployment_type' => :'deploymentType',
    :'dedicated' => :'dedicated',
    :'preferred_region' => :'preferredRegion',
    :'infrastructure_environments' => :'infrastructureEnvironments',
    :'allowed_domains' => :'allowedDomains',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/mudbase/models/organization.rb', line 304

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
# File 'lib/mudbase/models/organization.rb', line 138

def self.openapi_nullable
  Set.new([
    :'preferred_region',
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/mudbase/models/organization.rb', line 114

def self.openapi_types
  {
    :'_id' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'description' => :'String',
    :'logo' => :'String',
    :'website' => :'String',
    :'plan' => :'Plan',
    :'usage' => :'Usage',
    :'limits' => :'Limits',
    :'billing' => :'Billing',
    :'settings' => :'Object',
    :'deployment_type' => :'String',
    :'dedicated' => :'Object',
    :'preferred_region' => :'String',
    :'infrastructure_environments' => :'Array<Object>',
    :'allowed_domains' => :'Array<Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/mudbase/models/organization.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      name == o.name &&
      slug == o.slug &&
      description == o.description &&
       == o. &&
      website == o.website &&
      plan == o.plan &&
      usage == o.usage &&
      limits == o.limits &&
      billing == o.billing &&
      settings == o.settings &&
      deployment_type == o.deployment_type &&
      dedicated == o.dedicated &&
      preferred_region == o.preferred_region &&
      infrastructure_environments == o.infrastructure_environments &&
      allowed_domains == o.allowed_domains &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


291
292
293
# File 'lib/mudbase/models/organization.rb', line 291

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



297
298
299
# File 'lib/mudbase/models/organization.rb', line 297

def hash
  [_id, name, slug, description, , website, plan, usage, limits, billing, settings, deployment_type, dedicated, preferred_region, infrastructure_environments, allowed_domains, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



239
240
241
242
243
# File 'lib/mudbase/models/organization.rb', line 239

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/mudbase/models/organization.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
# File 'lib/mudbase/models/organization.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  deployment_type_validator = EnumAttributeValidator.new('String', ["shared", "dedicated"])
  return false unless deployment_type_validator.valid?(@deployment_type)
  true
end