Class: Mudbase::Organization

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/organization.rb

Overview

Organization (org) entity with plan, usage, limits, and billing.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Organization

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/mudbase/models/organization.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Organization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Organization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'logo')
    self. = attributes[:'logo']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'limits')
    self.limits = attributes[:'limits']
  end

  if attributes.key?(:'billing')
    self.billing = attributes[:'billing']
  end

  if attributes.key?(:'settings')
    self.settings = attributes[:'settings']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



19
20
21
# File 'lib/mudbase/models/organization.rb', line 19

def _id
  @_id
end

#billingObject

Returns the value of attribute billing.



38
39
40
# File 'lib/mudbase/models/organization.rb', line 38

def billing
  @billing
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/mudbase/models/organization.rb', line 42

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/mudbase/models/organization.rb', line 25

def description
  @description
end

#limitsObject

Returns the value of attribute limits.



36
37
38
# File 'lib/mudbase/models/organization.rb', line 36

def limits
  @limits
end

#logoObject

Optional logo URL. Org-related emails use the platform logo (env); this field is for legacy or future UI use only.



28
29
30
# File 'lib/mudbase/models/organization.rb', line 28

def 
  
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/mudbase/models/organization.rb', line 21

def name
  @name
end

#planObject

Returns the value of attribute plan.



32
33
34
# File 'lib/mudbase/models/organization.rb', line 32

def plan
  @plan
end

#settingsObject

Returns the value of attribute settings.



40
41
42
# File 'lib/mudbase/models/organization.rb', line 40

def settings
  @settings
end

#slugObject

Returns the value of attribute slug.



23
24
25
# File 'lib/mudbase/models/organization.rb', line 23

def slug
  @slug
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/mudbase/models/organization.rb', line 44

def updated_at
  @updated_at
end

#usageObject

Returns the value of attribute usage.



34
35
36
# File 'lib/mudbase/models/organization.rb', line 34

def usage
  @usage
end

#websiteObject

Returns the value of attribute website.



30
31
32
# File 'lib/mudbase/models/organization.rb', line 30

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/mudbase/models/organization.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/mudbase/models/organization.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/mudbase/models/organization.rb', line 47

def self.attribute_map
  {
    :'_id' => :'_id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'description' => :'description',
    :'logo' => :'logo',
    :'website' => :'website',
    :'plan' => :'plan',
    :'usage' => :'usage',
    :'limits' => :'limits',
    :'billing' => :'billing',
    :'settings' => :'settings',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/mudbase/models/organization.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/mudbase/models/organization.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/mudbase/models/organization.rb', line 76

def self.openapi_types
  {
    :'_id' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'description' => :'String',
    :'logo' => :'String',
    :'website' => :'String',
    :'plan' => :'Plan',
    :'usage' => :'Usage',
    :'limits' => :'Limits',
    :'billing' => :'Billing',
    :'settings' => :'Object',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/mudbase/models/organization.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      name == o.name &&
      slug == o.slug &&
      description == o.description &&
       == o. &&
      website == o.website &&
      plan == o.plan &&
      usage == o.usage &&
      limits == o.limits &&
      billing == o.billing &&
      settings == o.settings &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


206
207
208
# File 'lib/mudbase/models/organization.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



212
213
214
# File 'lib/mudbase/models/organization.rb', line 212

def hash
  [_id, name, slug, description, , website, plan, usage, limits, billing, settings, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
# File 'lib/mudbase/models/organization.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/mudbase/models/organization.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



179
180
181
182
# File 'lib/mudbase/models/organization.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end