Class: Mudbase::PaymentRefund
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::PaymentRefund
- Defined in:
- lib/mudbase/models/payment_refund.rb
Overview
Payment refund record (id, paymentId, amount, status, reason, createdAt).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#amount ⇒ Object
Refund amount.
-
#approved_at ⇒ Object
Returns the value of attribute approved_at.
-
#approved_by ⇒ Object
User ID who approved.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#is_cross_chain ⇒ Object
True if cross-chain refund.
-
#merchant ⇒ Object
Merchant ID.
-
#payment_intent ⇒ Object
Payment intent ID.
-
#reason ⇒ Object
Refund reason.
-
#refund_tx ⇒ Object
Refund transaction hash.
-
#refunded_at ⇒ Object
Returns the value of attribute refunded_at.
-
#source_network ⇒ Object
Source network for refund.
-
#status ⇒ Object
Returns the value of attribute status.
-
#target_network ⇒ Object
Target network for cross-chain refund.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentRefund
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PaymentRefund
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/mudbase/models/payment_refund.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::PaymentRefund` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::PaymentRefund`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'payment_intent') self.payment_intent = attributes[:'payment_intent'] end if attributes.key?(:'merchant') self.merchant = attributes[:'merchant'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'is_cross_chain') self.is_cross_chain = attributes[:'is_cross_chain'] else self.is_cross_chain = false end if attributes.key?(:'source_network') self.source_network = attributes[:'source_network'] end if attributes.key?(:'target_network') self.target_network = attributes[:'target_network'] end if attributes.key?(:'approved_by') self.approved_by = attributes[:'approved_by'] end if attributes.key?(:'approved_at') self.approved_at = attributes[:'approved_at'] end if attributes.key?(:'refund_tx') self.refund_tx = attributes[:'refund_tx'] end if attributes.key?(:'refunded_at') self.refunded_at = attributes[:'refunded_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/payment_refund.rb', line 19 def _id @_id end |
#amount ⇒ Object
Refund amount
28 29 30 |
# File 'lib/mudbase/models/payment_refund.rb', line 28 def amount @amount end |
#approved_at ⇒ Object
Returns the value of attribute approved_at.
47 48 49 |
# File 'lib/mudbase/models/payment_refund.rb', line 47 def approved_at @approved_at end |
#approved_by ⇒ Object
User ID who approved
45 46 47 |
# File 'lib/mudbase/models/payment_refund.rb', line 45 def approved_by @approved_by end |
#created_at ⇒ Object
Returns the value of attribute created_at.
54 55 56 |
# File 'lib/mudbase/models/payment_refund.rb', line 54 def created_at @created_at end |
#is_cross_chain ⇒ Object
True if cross-chain refund
36 37 38 |
# File 'lib/mudbase/models/payment_refund.rb', line 36 def is_cross_chain @is_cross_chain end |
#merchant ⇒ Object
Merchant ID
25 26 27 |
# File 'lib/mudbase/models/payment_refund.rb', line 25 def merchant @merchant end |
#payment_intent ⇒ Object
Payment intent ID
22 23 24 |
# File 'lib/mudbase/models/payment_refund.rb', line 22 def payment_intent @payment_intent end |
#reason ⇒ Object
Refund reason
31 32 33 |
# File 'lib/mudbase/models/payment_refund.rb', line 31 def reason @reason end |
#refund_tx ⇒ Object
Refund transaction hash
50 51 52 |
# File 'lib/mudbase/models/payment_refund.rb', line 50 def refund_tx @refund_tx end |
#refunded_at ⇒ Object
Returns the value of attribute refunded_at.
52 53 54 |
# File 'lib/mudbase/models/payment_refund.rb', line 52 def refunded_at @refunded_at end |
#source_network ⇒ Object
Source network for refund
39 40 41 |
# File 'lib/mudbase/models/payment_refund.rb', line 39 def source_network @source_network end |
#status ⇒ Object
Returns the value of attribute status.
33 34 35 |
# File 'lib/mudbase/models/payment_refund.rb', line 33 def status @status end |
#target_network ⇒ Object
Target network for cross-chain refund
42 43 44 |
# File 'lib/mudbase/models/payment_refund.rb', line 42 def target_network @target_network end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
56 57 58 |
# File 'lib/mudbase/models/payment_refund.rb', line 56 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
102 103 104 |
# File 'lib/mudbase/models/payment_refund.rb', line 102 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
107 108 109 |
# File 'lib/mudbase/models/payment_refund.rb', line 107 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/mudbase/models/payment_refund.rb', line 81 def self.attribute_map { :'_id' => :'_id', :'payment_intent' => :'paymentIntent', :'merchant' => :'merchant', :'amount' => :'amount', :'reason' => :'reason', :'status' => :'status', :'is_cross_chain' => :'isCrossChain', :'source_network' => :'sourceNetwork', :'target_network' => :'targetNetwork', :'approved_by' => :'approvedBy', :'approved_at' => :'approvedAt', :'refund_tx' => :'refundTx', :'refunded_at' => :'refundedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/mudbase/models/payment_refund.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 |
# File 'lib/mudbase/models/payment_refund.rb', line 133 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/mudbase/models/payment_refund.rb', line 112 def self.openapi_types { :'_id' => :'String', :'payment_intent' => :'String', :'merchant' => :'String', :'amount' => :'Float', :'reason' => :'String', :'status' => :'String', :'is_cross_chain' => :'Boolean', :'source_network' => :'String', :'target_network' => :'String', :'approved_by' => :'String', :'approved_at' => :'Time', :'refund_tx' => :'String', :'refunded_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/mudbase/models/payment_refund.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && payment_intent == o.payment_intent && merchant == o.merchant && amount == o.amount && reason == o.reason && status == o.status && is_cross_chain == o.is_cross_chain && source_network == o.source_network && target_network == o.target_network && approved_by == o.approved_by && approved_at == o.approved_at && refund_tx == o.refund_tx && refunded_at == o.refunded_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/mudbase/models/payment_refund.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/mudbase/models/payment_refund.rb', line 274 def hash [_id, payment_intent, merchant, amount, reason, status, is_cross_chain, source_network, target_network, approved_by, approved_at, refund_tx, refunded_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 223 |
# File 'lib/mudbase/models/payment_refund.rb', line 219 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/mudbase/models/payment_refund.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 |
# File 'lib/mudbase/models/payment_refund.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "rejected", "processed", "failed"]) return false unless status_validator.valid?(@status) true end |