Class: Mudbase::PresignedPostResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::PresignedPostResponse
- Defined in:
- lib/mudbase/models/presigned_post_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expires_in ⇒ Object
Expiration of the presigned URL in seconds.
-
#headers ⇒ Object
Headers the client must send with the PUT request (e.g. Content-Type) - mismatching these from what was signed causes a SignatureDoesNotMatch error.
-
#key ⇒ Object
Object key (S3) clients should upload to.
-
#max_file_upload_bytes ⇒ Object
Maximum upload size in bytes for this org plan.
-
#method ⇒ Object
HTTP method the client must use against
url(always PUT - R2 does not implement the S3 POST Object API). -
#url ⇒ Object
Presigned URL to PUT the file body to directly.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PresignedPostResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PresignedPostResponse
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::PresignedPostResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::PresignedPostResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'method') self.method = attributes[:'method'] end if attributes.key?(:'headers') self.headers = attributes[:'headers'] end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] end if attributes.key?(:'max_file_upload_bytes') self.max_file_upload_bytes = attributes[:'max_file_upload_bytes'] end end |
Instance Attribute Details
#expires_in ⇒ Object
Expiration of the presigned URL in seconds
31 32 33 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 31 def expires_in @expires_in end |
#headers ⇒ Object
Headers the client must send with the PUT request (e.g. Content-Type) - mismatching these from what was signed causes a SignatureDoesNotMatch error
28 29 30 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 28 def headers @headers end |
#key ⇒ Object
Object key (S3) clients should upload to
19 20 21 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 19 def key @key end |
#max_file_upload_bytes ⇒ Object
Maximum upload size in bytes for this org plan. Not enforced by the presigned URL itself (PUT has no content-length-range equivalent) - checked server-side by /api/files/upload/confirm after the upload completes
34 35 36 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 34 def max_file_upload_bytes @max_file_upload_bytes end |
#method ⇒ Object
HTTP method the client must use against url (always PUT - R2 does not implement the S3 POST Object API)
25 26 27 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 25 def method @method end |
#url ⇒ Object
Presigned URL to PUT the file body to directly
22 23 24 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 59 def self.attribute_map { :'key' => :'key', :'url' => :'url', :'method' => :'method', :'headers' => :'headers', :'expires_in' => :'expiresIn', :'max_file_upload_bytes' => :'maxFileUploadBytes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 81 def self.openapi_types { :'key' => :'String', :'url' => :'String', :'method' => :'String', :'headers' => :'Object', :'expires_in' => :'Integer', :'max_file_upload_bytes' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && url == o.url && method == o.method && headers == o.headers && expires_in == o.expires_in && max_file_upload_bytes == o.max_file_upload_bytes end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 187 def hash [key, url, method, headers, expires_in, max_file_upload_bytes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/mudbase/models/presigned_post_response.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' method_validator = EnumAttributeValidator.new('String', ["PUT"]) return false unless method_validator.valid?(@method) true end |