Class: Mudbase::Project
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::Project
- Defined in:
- lib/mudbase/models/project.rb
Overview
Project entity (id, name, config, usage).
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#auth ⇒ Object
Returns the value of attribute auth.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#database ⇒ Object
Returns the value of attribute database.
-
#description ⇒ Object
Returns the value of attribute description.
-
#name ⇒ Object
Returns the value of attribute name.
-
#org ⇒ Object
Returns the value of attribute org.
-
#settings ⇒ Object
Returns the value of attribute settings.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#storage ⇒ Object
Returns the value of attribute storage.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#usage ⇒ Object
Returns the value of attribute usage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Project
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Project
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/mudbase/models/project.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::Project` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::Project`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'org') self.org = attributes[:'org'] end if attributes.key?(:'auth') self.auth = attributes[:'auth'] end if attributes.key?(:'database') self.database = attributes[:'database'] end if attributes.key?(:'storage') self.storage = attributes[:'storage'] end if attributes.key?(:'settings') self.settings = attributes[:'settings'] end if attributes.key?(:'usage') self.usage = attributes[:'usage'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/project.rb', line 19 def _id @_id end |
#auth ⇒ Object
Returns the value of attribute auth.
29 30 31 |
# File 'lib/mudbase/models/project.rb', line 29 def auth @auth end |
#created_at ⇒ Object
Returns the value of attribute created_at.
39 40 41 |
# File 'lib/mudbase/models/project.rb', line 39 def created_at @created_at end |
#database ⇒ Object
Returns the value of attribute database.
31 32 33 |
# File 'lib/mudbase/models/project.rb', line 31 def database @database end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/mudbase/models/project.rb', line 23 def description @description end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/mudbase/models/project.rb', line 21 def name @name end |
#org ⇒ Object
Returns the value of attribute org.
27 28 29 |
# File 'lib/mudbase/models/project.rb', line 27 def org @org end |
#settings ⇒ Object
Returns the value of attribute settings.
35 36 37 |
# File 'lib/mudbase/models/project.rb', line 35 def settings @settings end |
#slug ⇒ Object
Returns the value of attribute slug.
25 26 27 |
# File 'lib/mudbase/models/project.rb', line 25 def slug @slug end |
#storage ⇒ Object
Returns the value of attribute storage.
33 34 35 |
# File 'lib/mudbase/models/project.rb', line 33 def storage @storage end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
41 42 43 |
# File 'lib/mudbase/models/project.rb', line 41 def updated_at @updated_at end |
#usage ⇒ Object
Returns the value of attribute usage.
37 38 39 |
# File 'lib/mudbase/models/project.rb', line 37 def usage @usage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/mudbase/models/project.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/mudbase/models/project.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mudbase/models/project.rb', line 44 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'description' => :'description', :'slug' => :'slug', :'org' => :'org', :'auth' => :'auth', :'database' => :'database', :'storage' => :'storage', :'settings' => :'settings', :'usage' => :'usage', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/mudbase/models/project.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/mudbase/models/project.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mudbase/models/project.rb', line 72 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'description' => :'String', :'slug' => :'String', :'org' => :'String', :'auth' => :'AuthConfig', :'database' => :'DatabaseConfig', :'storage' => :'StorageConfig', :'settings' => :'ProjectSettings', :'usage' => :'ProjectUsage', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/mudbase/models/project.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && description == o.description && slug == o.slug && org == o.org && auth == o.auth && database == o.database && storage == o.storage && settings == o.settings && usage == o.usage && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/mudbase/models/project.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/mudbase/models/project.rb', line 202 def hash [_id, name, description, slug, org, auth, database, storage, settings, usage, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 |
# File 'lib/mudbase/models/project.rb', line 162 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/mudbase/models/project.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 |
# File 'lib/mudbase/models/project.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |