Class: Mudbase::SimulateAppPermissionsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/mudbase/models/simulate_app_permissions_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SimulateAppPermissionsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::SimulateAppPermissionsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::SimulateAppPermissionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'role_slug')
    self.role_slug = attributes[:'role_slug']
  end

  if attributes.key?(:'operation_id')
    self.operation_id = attributes[:'operation_id']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'pathname')
    self.pathname = attributes[:'pathname']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end
end

Instance Attribute Details

#methodObject

Returns the value of attribute method.



27
28
29
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 27

def method
  @method
end

#operation_idObject

OpenAPI operationId (e.g. sendEmail, executeIntegration). When set, path simulation is optional.



25
26
27
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 25

def operation_id
  @operation_id
end

#pathObject

Alias for pathname



33
34
35
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 33

def path
  @path
end

#pathnameObject

Full path e.g. /api/messaging/projects/{id}/messaging/email



30
31
32
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 30

def pathname
  @pathname
end

#roleObject

App role slug (same as roleSlug elsewhere)



19
20
21
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 19

def role
  @role
end

#role_slugObject

Alias for role



22
23
24
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 22

def role_slug
  @role_slug
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 36

def self.attribute_map
  {
    :'role' => :'role',
    :'role_slug' => :'roleSlug',
    :'operation_id' => :'operationId',
    :'method' => :'method',
    :'pathname' => :'pathname',
    :'path' => :'path'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 58

def self.openapi_types
  {
    :'role' => :'String',
    :'role_slug' => :'String',
    :'operation_id' => :'String',
    :'method' => :'String',
    :'pathname' => :'String',
    :'path' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
157
158
159
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      role == o.role &&
      role_slug == o.role_slug &&
      operation_id == o.operation_id &&
      method == o.method &&
      pathname == o.pathname &&
      path == o.path
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 169

def hash
  [role, role_slug, operation_id, method, pathname, path].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
# File 'lib/mudbase/models/simulate_app_permissions_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @role.nil?
  true
end