Class: Mudbase::UsageApi

Inherits:
Object
  • Object
show all
Defined in:
lib/mudbase/api/usage_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UsageApi

Returns a new instance of UsageApi.



19
20
21
# File 'lib/mudbase/api/usage_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/mudbase/api/usage_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#usage_get_project(project_id, opts = {}) ⇒ ProjectUsageStatsResponse

Get project usage Get usage statistics for a project (API calls, storage, bandwidth, database operations). Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).

Parameters:

  • project_id (String)

    Project ID (MongoDB ObjectId) to get usage for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :period (String)

    Aggregation period for usage (day, week, or month). (default to ‘month’)

Returns:



28
29
30
31
# File 'lib/mudbase/api/usage_api.rb', line 28

def usage_get_project(project_id, opts = {})
  data, _status_code, _headers = usage_get_project_with_http_info(project_id, opts)
  data
end

#usage_get_project_with_http_info(project_id, opts = {}) ⇒ Array<(ProjectUsageStatsResponse, Integer, Hash)>

Get project usage Get usage statistics for a project (API calls, storage, bandwidth, database operations). Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).

Parameters:

  • project_id (String)

    Project ID (MongoDB ObjectId) to get usage for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :period (String)

    Aggregation period for usage (day, week, or month). (default to ‘month’)

Returns:

  • (Array<(ProjectUsageStatsResponse, Integer, Hash)>)

    ProjectUsageStatsResponse data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/mudbase/api/usage_api.rb', line 39

def usage_get_project_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsageApi.usage_get_project ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling UsageApi.usage_get_project"
  end
  allowable_values = ["day", "week", "month"]
  if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period'])
    fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/usage/projects/{projectId}'.sub('{' + 'projectId' + '}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ProjectUsageStatsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"UsageApi.usage_get_project",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsageApi#usage_get_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Get usage trends Get usage trends over time for the authenticated organization or project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :days (Integer)

    Number of days of trend data to return (default 30). (default to 30)

Returns:



97
98
99
100
# File 'lib/mudbase/api/usage_api.rb', line 97

def usage_get_trends(opts = {})
  data, _status_code, _headers = usage_get_trends_with_http_info(opts)
  data
end

Get usage trends Get usage trends over time for the authenticated organization or project. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :days (Integer)

    Number of days of trend data to return (default 30). (default to 30)

Returns:

  • (Array<(UsageTrendsResponse, Integer, Hash)>)

    UsageTrendsResponse data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/mudbase/api/usage_api.rb', line 107

def usage_get_trends_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsageApi.usage_get_trends ...'
  end
  # resource path
  local_var_path = '/api/usage/trends'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'days'] = opts[:'days'] if !opts[:'days'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UsageTrendsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"UsageApi.usage_get_trends",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsageApi#usage_get_trends\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end