Class: Mudbase::User
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::User
- Defined in:
- lib/mudbase/models/user.rb
Overview
Authenticated user profile (id, email, name, roles, project access).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#avatar ⇒ Object
Returns the value of attribute avatar.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#email ⇒ Object
Returns the value of attribute email.
-
#email_verified ⇒ Object
Returns the value of attribute email_verified.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#full_name ⇒ Object
Returns the value of attribute full_name.
-
#last_login ⇒ Object
Returns the value of attribute last_login.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#org ⇒ Object
Returns the value of attribute org.
-
#phone_verified ⇒ Object
Returns the value of attribute phone_verified.
-
#role ⇒ Object
Returns the value of attribute role.
-
#two_factor_enabled ⇒ Object
Returns the value of attribute two_factor_enabled.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/mudbase/models/user.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::User` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'avatar') self.avatar = attributes[:'avatar'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] end if attributes.key?(:'phone_verified') self.phone_verified = attributes[:'phone_verified'] end if attributes.key?(:'two_factor_enabled') self.two_factor_enabled = attributes[:'two_factor_enabled'] end if attributes.key?(:'last_login') self.last_login = attributes[:'last_login'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'org') self.org = attributes[:'org'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/user.rb', line 19 def _id @_id end |
#avatar ⇒ Object
Returns the value of attribute avatar.
29 30 31 |
# File 'lib/mudbase/models/user.rb', line 29 def avatar @avatar end |
#created_at ⇒ Object
Returns the value of attribute created_at.
41 42 43 |
# File 'lib/mudbase/models/user.rb', line 41 def created_at @created_at end |
#email ⇒ Object
Returns the value of attribute email.
21 22 23 |
# File 'lib/mudbase/models/user.rb', line 21 def email @email end |
#email_verified ⇒ Object
Returns the value of attribute email_verified.
33 34 35 |
# File 'lib/mudbase/models/user.rb', line 33 def email_verified @email_verified end |
#first_name ⇒ Object
Returns the value of attribute first_name.
23 24 25 |
# File 'lib/mudbase/models/user.rb', line 23 def first_name @first_name end |
#full_name ⇒ Object
Returns the value of attribute full_name.
27 28 29 |
# File 'lib/mudbase/models/user.rb', line 27 def full_name @full_name end |
#last_login ⇒ Object
Returns the value of attribute last_login.
39 40 41 |
# File 'lib/mudbase/models/user.rb', line 39 def last_login @last_login end |
#last_name ⇒ Object
Returns the value of attribute last_name.
25 26 27 |
# File 'lib/mudbase/models/user.rb', line 25 def last_name @last_name end |
#org ⇒ Object
Returns the value of attribute org.
45 46 47 |
# File 'lib/mudbase/models/user.rb', line 45 def org @org end |
#phone_verified ⇒ Object
Returns the value of attribute phone_verified.
35 36 37 |
# File 'lib/mudbase/models/user.rb', line 35 def phone_verified @phone_verified end |
#role ⇒ Object
Returns the value of attribute role.
31 32 33 |
# File 'lib/mudbase/models/user.rb', line 31 def role @role end |
#two_factor_enabled ⇒ Object
Returns the value of attribute two_factor_enabled.
37 38 39 |
# File 'lib/mudbase/models/user.rb', line 37 def two_factor_enabled @two_factor_enabled end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
43 44 45 |
# File 'lib/mudbase/models/user.rb', line 43 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/mudbase/models/user.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/mudbase/models/user.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mudbase/models/user.rb', line 70 def self.attribute_map { :'_id' => :'_id', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'full_name' => :'fullName', :'avatar' => :'avatar', :'role' => :'role', :'email_verified' => :'emailVerified', :'phone_verified' => :'phoneVerified', :'two_factor_enabled' => :'twoFactorEnabled', :'last_login' => :'lastLogin', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'org' => :'org' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/mudbase/models/user.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
120 121 122 123 |
# File 'lib/mudbase/models/user.rb', line 120 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/mudbase/models/user.rb', line 100 def self.openapi_types { :'_id' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'full_name' => :'String', :'avatar' => :'String', :'role' => :'String', :'email_verified' => :'Boolean', :'phone_verified' => :'Boolean', :'two_factor_enabled' => :'Boolean', :'last_login' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time', :'org' => :'OrganizationSummary' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/mudbase/models/user.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && email == o.email && first_name == o.first_name && last_name == o.last_name && full_name == o.full_name && avatar == o.avatar && role == o.role && email_verified == o.email_verified && phone_verified == o.phone_verified && two_factor_enabled == o.two_factor_enabled && last_login == o.last_login && created_at == o.created_at && updated_at == o.updated_at && org == o.org end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/mudbase/models/user.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/mudbase/models/user.rb', line 254 def hash [_id, email, first_name, last_name, full_name, avatar, role, email_verified, phone_verified, two_factor_enabled, last_login, created_at, updated_at, org].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 |
# File 'lib/mudbase/models/user.rb', line 200 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/mudbase/models/user.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 |
# File 'lib/mudbase/models/user.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' role_validator = EnumAttributeValidator.new('String', ["owner", "admin", "member", "viewer"]) return false unless role_validator.valid?(@role) true end |