Class: Mudbase::WalletBalance
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::WalletBalance
- Defined in:
- lib/mudbase/models/wallet_balance.rb
Overview
Wallet balance (address, chain, confirmed, unconfirmed, total, currency, lastUpdated).
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#chain ⇒ Object
Returns the value of attribute chain.
-
#confirmed ⇒ Object
Confirmed balance (string to handle large numbers).
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#total ⇒ Object
Total balance (string to handle large numbers).
-
#unconfirmed ⇒ Object
Unconfirmed balance (string to handle large numbers).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WalletBalance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WalletBalance
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/mudbase/models/wallet_balance.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletBalance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletBalance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'chain') self.chain = attributes[:'chain'] end if attributes.key?(:'confirmed') self.confirmed = attributes[:'confirmed'] end if attributes.key?(:'unconfirmed') self.unconfirmed = attributes[:'unconfirmed'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
19 20 21 |
# File 'lib/mudbase/models/wallet_balance.rb', line 19 def address @address end |
#chain ⇒ Object
Returns the value of attribute chain.
21 22 23 |
# File 'lib/mudbase/models/wallet_balance.rb', line 21 def chain @chain end |
#confirmed ⇒ Object
Confirmed balance (string to handle large numbers)
24 25 26 |
# File 'lib/mudbase/models/wallet_balance.rb', line 24 def confirmed @confirmed end |
#currency ⇒ Object
Returns the value of attribute currency.
32 33 34 |
# File 'lib/mudbase/models/wallet_balance.rb', line 32 def currency @currency end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
34 35 36 |
# File 'lib/mudbase/models/wallet_balance.rb', line 34 def last_updated @last_updated end |
#total ⇒ Object
Total balance (string to handle large numbers)
30 31 32 |
# File 'lib/mudbase/models/wallet_balance.rb', line 30 def total @total end |
#unconfirmed ⇒ Object
Unconfirmed balance (string to handle large numbers)
27 28 29 |
# File 'lib/mudbase/models/wallet_balance.rb', line 27 def unconfirmed @unconfirmed end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/mudbase/models/wallet_balance.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/mudbase/models/wallet_balance.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/mudbase/models/wallet_balance.rb', line 37 def self.attribute_map { :'address' => :'address', :'chain' => :'chain', :'confirmed' => :'confirmed', :'unconfirmed' => :'unconfirmed', :'total' => :'total', :'currency' => :'currency', :'last_updated' => :'lastUpdated' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/mudbase/models/wallet_balance.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/mudbase/models/wallet_balance.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mudbase/models/wallet_balance.rb', line 60 def self.openapi_types { :'address' => :'String', :'chain' => :'String', :'confirmed' => :'String', :'unconfirmed' => :'String', :'total' => :'String', :'currency' => :'String', :'last_updated' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/mudbase/models/wallet_balance.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && chain == o.chain && confirmed == o.confirmed && unconfirmed == o.unconfirmed && total == o.total && currency == o.currency && last_updated == o.last_updated end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/mudbase/models/wallet_balance.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/mudbase/models/wallet_balance.rb', line 160 def hash [address, chain, confirmed, unconfirmed, total, currency, last_updated].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 |
# File 'lib/mudbase/models/wallet_balance.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/mudbase/models/wallet_balance.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 |
# File 'lib/mudbase/models/wallet_balance.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |