Class: Mudbase::WalletEstimateGas200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::WalletEstimateGas200ResponseData
- Defined in:
- lib/mudbase/models/wallet_estimate_gas200_response_data.rb
Instance Attribute Summary collapse
-
#chain ⇒ Object
Chain id (e.g. bsc, ethereum, bitcoin).
-
#currency ⇒ Object
Native currency for the chain (ETH, BNB, MATIC, BTC, SOL, TRX, etc.).
-
#estimated_cost ⇒ Object
(EVM only) Total cost in wei (gasLimit * gasPrice).
-
#estimated_time ⇒ Object
Estimated confirmation time when available.
-
#fee_sat ⇒ Object
(UTXO only) Estimated fee in satoshis.
-
#gas_limit ⇒ Object
(EVM only) Estimated gas limit from RPC eth_estimateGas.
-
#gas_price ⇒ Object
(EVM only) Gas price in wei.
-
#gas_price_gwei ⇒ Object
(EVM only) Gas price in Gwei.
-
#lamports ⇒ Object
(Solana only) Fee in lamports.
-
#network_fee ⇒ Object
Human-readable network fee from blockchain (e.g. \“0.00063 ETH\”, \“0.00001 BTC\”).
-
#sat_per_vb ⇒ Object
(UTXO only) Satoshis per virtual byte.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WalletEstimateGas200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WalletEstimateGas200ResponseData
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletEstimateGas200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletEstimateGas200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chain') self.chain = attributes[:'chain'] end if attributes.key?(:'gas_limit') self.gas_limit = attributes[:'gas_limit'] end if attributes.key?(:'gas_price') self.gas_price = attributes[:'gas_price'] end if attributes.key?(:'gas_price_gwei') self.gas_price_gwei = attributes[:'gas_price_gwei'] end if attributes.key?(:'estimated_cost') self.estimated_cost = attributes[:'estimated_cost'] end if attributes.key?(:'network_fee') self.network_fee = attributes[:'network_fee'] end if attributes.key?(:'estimated_time') self.estimated_time = attributes[:'estimated_time'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'sat_per_vb') self.sat_per_vb = attributes[:'sat_per_vb'] end if attributes.key?(:'fee_sat') self.fee_sat = attributes[:'fee_sat'] end if attributes.key?(:'lamports') self.lamports = attributes[:'lamports'] end end |
Instance Attribute Details
#chain ⇒ Object
Chain id (e.g. bsc, ethereum, bitcoin)
19 20 21 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 19 def chain @chain end |
#currency ⇒ Object
Native currency for the chain (ETH, BNB, MATIC, BTC, SOL, TRX, etc.)
40 41 42 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 40 def currency @currency end |
#estimated_cost ⇒ Object
(EVM only) Total cost in wei (gasLimit * gasPrice)
31 32 33 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 31 def estimated_cost @estimated_cost end |
#estimated_time ⇒ Object
Estimated confirmation time when available
37 38 39 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 37 def estimated_time @estimated_time end |
#fee_sat ⇒ Object
(UTXO only) Estimated fee in satoshis
46 47 48 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 46 def fee_sat @fee_sat end |
#gas_limit ⇒ Object
(EVM only) Estimated gas limit from RPC eth_estimateGas
22 23 24 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 22 def gas_limit @gas_limit end |
#gas_price ⇒ Object
(EVM only) Gas price in wei
25 26 27 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 25 def gas_price @gas_price end |
#gas_price_gwei ⇒ Object
(EVM only) Gas price in Gwei
28 29 30 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 28 def gas_price_gwei @gas_price_gwei end |
#lamports ⇒ Object
(Solana only) Fee in lamports
49 50 51 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 49 def lamports @lamports end |
#network_fee ⇒ Object
Human-readable network fee from blockchain (e.g. \“0.00063 ETH\”, \“0.00001 BTC\”)
34 35 36 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 34 def network_fee @network_fee end |
#sat_per_vb ⇒ Object
(UTXO only) Satoshis per virtual byte
43 44 45 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 43 def sat_per_vb @sat_per_vb end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 52 def self.attribute_map { :'chain' => :'chain', :'gas_limit' => :'gasLimit', :'gas_price' => :'gasPrice', :'gas_price_gwei' => :'gasPriceGwei', :'estimated_cost' => :'estimatedCost', :'network_fee' => :'networkFee', :'estimated_time' => :'estimatedTime', :'currency' => :'currency', :'sat_per_vb' => :'satPerVb', :'fee_sat' => :'feeSat', :'lamports' => :'lamports' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 79 def self.openapi_types { :'chain' => :'String', :'gas_limit' => :'String', :'gas_price' => :'String', :'gas_price_gwei' => :'Float', :'estimated_cost' => :'String', :'network_fee' => :'String', :'estimated_time' => :'String', :'currency' => :'String', :'sat_per_vb' => :'Integer', :'fee_sat' => :'Integer', :'lamports' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && chain == o.chain && gas_limit == o.gas_limit && gas_price == o.gas_price && gas_price_gwei == o.gas_price_gwei && estimated_cost == o.estimated_cost && network_fee == o.network_fee && estimated_time == o.estimated_time && currency == o.currency && sat_per_vb == o.sat_per_vb && fee_sat == o.fee_sat && lamports == o.lamports end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 203 def hash [chain, gas_limit, gas_price, gas_price_gwei, estimated_cost, network_fee, estimated_time, currency, sat_per_vb, fee_sat, lamports].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 |
# File 'lib/mudbase/models/wallet_estimate_gas200_response_data.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |