Class: Mudbase::WalletWebhook
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::WalletWebhook
- Defined in:
- lib/mudbase/models/wallet_webhook.rb
Overview
Wallet webhook config (id, url, events, chain, address, secret, isActive).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#events ⇒ Object
Returns the value of attribute events.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#stats ⇒ Object
Returns the value of attribute stats.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WalletWebhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WalletWebhook
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WalletWebhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WalletWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'filters') self.filters = attributes[:'filters'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
19 20 21 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 19 def _id @_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
31 32 33 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 31 def created_at @created_at end |
#events ⇒ Object
Returns the value of attribute events.
23 24 25 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 23 def events @events end |
#filters ⇒ Object
Returns the value of attribute filters.
25 26 27 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 25 def filters @filters end |
#is_active ⇒ Object
Returns the value of attribute is_active.
27 28 29 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 27 def is_active @is_active end |
#stats ⇒ Object
Returns the value of attribute stats.
29 30 31 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 29 def stats @stats end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
33 34 35 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 33 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
21 22 23 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 21 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 58 def self.attribute_map { :'_id' => :'_id', :'url' => :'url', :'events' => :'events', :'filters' => :'filters', :'is_active' => :'isActive', :'stats' => :'stats', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 197 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 82 def self.openapi_types { :'_id' => :'String', :'url' => :'String', :'events' => :'Array<String>', :'filters' => :'WalletWebhookFilters', :'is_active' => :'Boolean', :'stats' => :'WalletWebhookStats', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && url == o.url && events == o.events && filters == o.filters && is_active == o.is_active && stats == o.stats && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
184 185 186 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 184 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 190 def hash [_id, url, events, filters, is_active, stats, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 |
# File 'lib/mudbase/models/wallet_webhook.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |