Class: Mudbase::WebhookLog
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Mudbase::WebhookLog
- Defined in:
- lib/mudbase/models/webhook_log.rb
Overview
One outbound delivery attempt (Mudbase HTTP client → your url). _id is what the API calls webhookId in POST /api/webhooks/trigger and POST /api/webhooks/retry/{webhookId}. The string field webhookId below is an internal correlation id (e.g. manual-<timestamp>), not the path parameter for retry.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
MongoDB id — use as
webhookIdpath param for retry. -
#attempts ⇒ Object
Returns the value of attribute attempts.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#duration ⇒ Object
Round-trip time in milliseconds.
-
#error ⇒ Object
Returns the value of attribute error.
-
#event ⇒ Object
Returns the value of attribute event.
-
#headers ⇒ Object
Outbound request headers (e.g. X-MUDBASE-Event, Content-Type).
-
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
-
#method ⇒ Object
Returns the value of attribute method.
-
#next_retry ⇒ Object
Returns the value of attribute next_retry.
-
#org ⇒ Object
Organization that owns the project.
-
#payload ⇒ Object
JSON body sent to your endpoint.
-
#project ⇒ Object
Project id this delivery belongs to.
-
#response ⇒ Object
Returns the value of attribute response.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
-
#webhook_id ⇒ Object
Internal correlation string (e.g. manual-173…), not the retry path id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookLog
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookLog
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/mudbase/models/webhook_log.rb', line 152 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WebhookLog` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WebhookLog`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'org') self.org = attributes[:'org'] end if attributes.key?(:'project') self.project = attributes[:'project'] end if attributes.key?(:'webhook_id') self.webhook_id = attributes[:'webhook_id'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'method') self.method = attributes[:'method'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'headers') self.headers = attributes[:'headers'] end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'attempts') self.attempts = attributes[:'attempts'] end if attributes.key?(:'max_attempts') self.max_attempts = attributes[:'max_attempts'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'next_retry') self.next_retry = attributes[:'next_retry'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
MongoDB id — use as webhookId path param for retry
20 21 22 |
# File 'lib/mudbase/models/webhook_log.rb', line 20 def _id @_id end |
#attempts ⇒ Object
Returns the value of attribute attempts.
50 51 52 |
# File 'lib/mudbase/models/webhook_log.rb', line 50 def attempts @attempts end |
#created_at ⇒ Object
Returns the value of attribute created_at.
58 59 60 |
# File 'lib/mudbase/models/webhook_log.rb', line 58 def created_at @created_at end |
#duration ⇒ Object
Round-trip time in milliseconds
48 49 50 |
# File 'lib/mudbase/models/webhook_log.rb', line 48 def duration @duration end |
#error ⇒ Object
Returns the value of attribute error.
54 55 56 |
# File 'lib/mudbase/models/webhook_log.rb', line 54 def error @error end |
#event ⇒ Object
Returns the value of attribute event.
35 36 37 |
# File 'lib/mudbase/models/webhook_log.rb', line 35 def event @event end |
#headers ⇒ Object
Outbound request headers (e.g. X-MUDBASE-Event, Content-Type)
43 44 45 |
# File 'lib/mudbase/models/webhook_log.rb', line 43 def headers @headers end |
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
52 53 54 |
# File 'lib/mudbase/models/webhook_log.rb', line 52 def max_attempts @max_attempts end |
#method ⇒ Object
Returns the value of attribute method.
33 34 35 |
# File 'lib/mudbase/models/webhook_log.rb', line 33 def method @method end |
#next_retry ⇒ Object
Returns the value of attribute next_retry.
56 57 58 |
# File 'lib/mudbase/models/webhook_log.rb', line 56 def next_retry @next_retry end |
#org ⇒ Object
Organization that owns the project
23 24 25 |
# File 'lib/mudbase/models/webhook_log.rb', line 23 def org @org end |
#payload ⇒ Object
JSON body sent to your endpoint
40 41 42 |
# File 'lib/mudbase/models/webhook_log.rb', line 40 def payload @payload end |
#project ⇒ Object
Project id this delivery belongs to
26 27 28 |
# File 'lib/mudbase/models/webhook_log.rb', line 26 def project @project end |
#response ⇒ Object
Returns the value of attribute response.
45 46 47 |
# File 'lib/mudbase/models/webhook_log.rb', line 45 def response @response end |
#status ⇒ Object
Returns the value of attribute status.
37 38 39 |
# File 'lib/mudbase/models/webhook_log.rb', line 37 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
60 61 62 |
# File 'lib/mudbase/models/webhook_log.rb', line 60 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
31 32 33 |
# File 'lib/mudbase/models/webhook_log.rb', line 31 def url @url end |
#webhook_id ⇒ Object
Internal correlation string (e.g. manual-173…), not the retry path id
29 30 31 |
# File 'lib/mudbase/models/webhook_log.rb', line 29 def webhook_id @webhook_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
109 110 111 |
# File 'lib/mudbase/models/webhook_log.rb', line 109 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
114 115 116 |
# File 'lib/mudbase/models/webhook_log.rb', line 114 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/mudbase/models/webhook_log.rb', line 85 def self.attribute_map { :'_id' => :'_id', :'org' => :'org', :'project' => :'project', :'webhook_id' => :'webhookId', :'url' => :'url', :'method' => :'method', :'event' => :'event', :'status' => :'status', :'payload' => :'payload', :'headers' => :'headers', :'response' => :'response', :'duration' => :'duration', :'attempts' => :'attempts', :'max_attempts' => :'maxAttempts', :'error' => :'error', :'next_retry' => :'nextRetry', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/mudbase/models/webhook_log.rb', line 318 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
143 144 145 146 147 148 |
# File 'lib/mudbase/models/webhook_log.rb', line 143 def self.openapi_nullable Set.new([ :'error', :'next_retry', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/mudbase/models/webhook_log.rb', line 119 def self.openapi_types { :'_id' => :'String', :'org' => :'String', :'project' => :'String', :'webhook_id' => :'String', :'url' => :'String', :'method' => :'String', :'event' => :'String', :'status' => :'String', :'payload' => :'Object', :'headers' => :'Object', :'response' => :'WebhookLogResponse', :'duration' => :'Integer', :'attempts' => :'Integer', :'max_attempts' => :'Integer', :'error' => :'String', :'next_retry' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/mudbase/models/webhook_log.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && org == o.org && project == o.project && webhook_id == o.webhook_id && url == o.url && method == o.method && event == o.event && status == o.status && payload == o.payload && headers == o.headers && response == o.response && duration == o.duration && attempts == o.attempts && max_attempts == o.max_attempts && error == o.error && next_retry == o.next_retry && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
305 306 307 |
# File 'lib/mudbase/models/webhook_log.rb', line 305 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/mudbase/models/webhook_log.rb', line 311 def hash [_id, org, project, webhook_id, url, method, event, status, payload, headers, response, duration, attempts, max_attempts, error, next_retry, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
241 242 243 244 245 |
# File 'lib/mudbase/models/webhook_log.rb', line 241 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/mudbase/models/webhook_log.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
249 250 251 252 253 254 255 256 |
# File 'lib/mudbase/models/webhook_log.rb', line 249 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "PATCH", "DELETE"]) return false unless method_validator.valid?(@method) status_validator = EnumAttributeValidator.new('String', ["pending", "success", "failed", "retrying"]) return false unless status_validator.valid?(@status) true end |