Class: Mudbase::WebhookLog

Inherits:
ApiModelBase show all
Defined in:
lib/mudbase/models/webhook_log.rb

Overview

Single webhook delivery log (url, method, event, status, payload, response, duration, attempts).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookLog

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/mudbase/models/webhook_log.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Mudbase::WebhookLog` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Mudbase::WebhookLog`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'response')
    self.response = attributes[:'response']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'next_retry')
    self.next_retry = attributes[:'next_retry']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



19
20
21
# File 'lib/mudbase/models/webhook_log.rb', line 19

def _id
  @_id
end

#attemptsObject

Returns the value of attribute attempts.



37
38
39
# File 'lib/mudbase/models/webhook_log.rb', line 37

def attempts
  @attempts
end

#created_atObject

Returns the value of attribute created_at.



43
44
45
# File 'lib/mudbase/models/webhook_log.rb', line 43

def created_at
  @created_at
end

#durationObject

Returns the value of attribute duration.



35
36
37
# File 'lib/mudbase/models/webhook_log.rb', line 35

def duration
  @duration
end

#errorObject

Returns the value of attribute error.



39
40
41
# File 'lib/mudbase/models/webhook_log.rb', line 39

def error
  @error
end

#eventObject

Returns the value of attribute event.



25
26
27
# File 'lib/mudbase/models/webhook_log.rb', line 25

def event
  @event
end

#methodObject

Returns the value of attribute method.



23
24
25
# File 'lib/mudbase/models/webhook_log.rb', line 23

def method
  @method
end

#next_retryObject

Returns the value of attribute next_retry.



41
42
43
# File 'lib/mudbase/models/webhook_log.rb', line 41

def next_retry
  @next_retry
end

#payloadObject

Returns the value of attribute payload.



31
32
33
# File 'lib/mudbase/models/webhook_log.rb', line 31

def payload
  @payload
end

#responseObject

Returns the value of attribute response.



33
34
35
# File 'lib/mudbase/models/webhook_log.rb', line 33

def response
  @response
end

#statusObject

Returns the value of attribute status.



27
28
29
# File 'lib/mudbase/models/webhook_log.rb', line 27

def status
  @status
end

#status_codeObject

Returns the value of attribute status_code.



29
30
31
# File 'lib/mudbase/models/webhook_log.rb', line 29

def status_code
  @status_code
end

#urlObject

Returns the value of attribute url.



21
22
23
# File 'lib/mudbase/models/webhook_log.rb', line 21

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/mudbase/models/webhook_log.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/mudbase/models/webhook_log.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/mudbase/models/webhook_log.rb', line 68

def self.attribute_map
  {
    :'_id' => :'_id',
    :'url' => :'url',
    :'method' => :'method',
    :'event' => :'event',
    :'status' => :'status',
    :'status_code' => :'statusCode',
    :'payload' => :'payload',
    :'response' => :'response',
    :'duration' => :'duration',
    :'attempts' => :'attempts',
    :'error' => :'error',
    :'next_retry' => :'nextRetry',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/mudbase/models/webhook_log.rb', line 252

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/mudbase/models/webhook_log.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/mudbase/models/webhook_log.rb', line 97

def self.openapi_types
  {
    :'_id' => :'String',
    :'url' => :'String',
    :'method' => :'String',
    :'event' => :'String',
    :'status' => :'String',
    :'status_code' => :'Integer',
    :'payload' => :'Object',
    :'response' => :'Object',
    :'duration' => :'Integer',
    :'attempts' => :'Integer',
    :'error' => :'String',
    :'next_retry' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/mudbase/models/webhook_log.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      url == o.url &&
      method == o.method &&
      event == o.event &&
      status == o.status &&
      status_code == o.status_code &&
      payload == o.payload &&
      response == o.response &&
      duration == o.duration &&
      attempts == o.attempts &&
      error == o.error &&
      next_retry == o.next_retry &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


239
240
241
# File 'lib/mudbase/models/webhook_log.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



245
246
247
# File 'lib/mudbase/models/webhook_log.rb', line 245

def hash
  [_id, url, method, event, status, status_code, payload, response, duration, attempts, error, next_retry, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
# File 'lib/mudbase/models/webhook_log.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/mudbase/models/webhook_log.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
# File 'lib/mudbase/models/webhook_log.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["success", "failed", "pending"])
  return false unless status_validator.valid?(@status)
  true
end