Class: Mudbase::WebhooksApi
- Inherits:
-
Object
- Object
- Mudbase::WebhooksApi
- Defined in:
- lib/mudbase/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#webhooks_get_stats(opts = {}) ⇒ WebhookStatsResponse
Get webhook statistics Get webhook delivery statistics including success rate, total deliveries, and breakdown by status.
-
#webhooks_get_stats_with_http_info(opts = {}) ⇒ Array<(WebhookStatsResponse, Integer, Hash)>
Get webhook statistics Get webhook delivery statistics including success rate, total deliveries, and breakdown by status.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/mudbase/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/mudbase/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#webhooks_get_stats(opts = {}) ⇒ WebhookStatsResponse
Get webhook statistics Get webhook delivery statistics including success rate, total deliveries, and breakdown by status. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
28 29 30 31 |
# File 'lib/mudbase/api/webhooks_api.rb', line 28 def webhooks_get_stats(opts = {}) data, _status_code, _headers = webhooks_get_stats_with_http_info(opts) data end |
#webhooks_get_stats_with_http_info(opts = {}) ⇒ Array<(WebhookStatsResponse, Integer, Hash)>
Get webhook statistics Get webhook delivery statistics including success rate, total deliveries, and breakdown by status. Accepts BearerToken (JWT) or ApiKeyAuth (X-API-Key).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/mudbase/api/webhooks_api.rb', line 39 def webhooks_get_stats_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_get_stats ...' end # resource path local_var_path = '/api/webhooks/stats' # query parameters query_params = opts[:query_params] || {} query_params[:'projectId'] = opts[:'project_id'] if !opts[:'project_id'].nil? query_params[:'days'] = opts[:'days'] if !opts[:'days'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookStatsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerToken'] = opts.merge( :operation => :"WebhooksApi.webhooks_get_stats", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhooks_get_stats\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |